@@ -1,6 +1,7 @@
 import interfaceTopTables from "./interface_top_tables.js";
 import hostTopTables from "./host_top_tables.js";
 import snmpInterfaceTopTables from "./snmp_interface_top_tables.js";
+import snmpInterfaceUsage from "./snmp_interface_usage_tables.js";
 import flowDeviceTopTables from "./flow_device_top_tables.js";
 import proxySnmp from "../proxies/snmp.js";
 
@@ -69,6 +70,7 @@ const sources_types_tables = {
 	interface: interfaceTopTables,
 	host: hostTopTables,
 	snmp_device: snmpInterfaceTopTables,
+	snmp_interface: snmpInterfaceUsage,
 	flow_device: flowDeviceTopTables,
 	flow_interface: flowDeviceTopTables,
 };
@@ -296,7 +298,7 @@ const sources_types = [
 	},
 	{
 		id: "profile",
-		regex_page_url: "lua\/profile_details",
+		regex_page_url: "lua\/pro\/profile_details",
 		label: i18n("page_stats.source_def.profile"),
 		query: "profile",
 		source_def_array: [{
@@ -338,7 +340,7 @@ const sources_types = [
 	},
 	{
 		id: "active_monitoring",
-		regex_page_url: "lua\/monitor\/active_monitoring_monitor.lua",
+		regex_page_url: "lua\/active_monitoring.lua",
 		label: i18n("page_stats.source_def.active_monitoring"),
 		query: "am",
 		source_def_array: [{
@@ -349,7 +351,7 @@ const sources_types = [
 		}, {
 			main_source_def: true,
 			label: i18n("page_stats.source_def.active_monitoring"),
-			sources_url: "lua/rest/v2/get/am_host/list.lua",
+			sources_url: "lua/rest/v2/get/active_monitoring/timeseries_list.lua",
 			value: "host",
 			disable_tskey: true,
 			value_map_sources_res: "am_host",
@@ -505,6 +507,50 @@ const sources_types = [
 			ui_type: ui_types.input,
 		}],
 	},
+	{
+		id: "sflow_device",
+		regex_page_url: "lua\/pro\/enterprise\/sflowdevices_stats",
+		label: i18n("page_stats.source_def.sflow_device"),
+		query: "sflowdev",
+		source_def_array: [{
+			label: i18n("page_stats.source_def.interface"),
+			sources_url: "lua/rest/v2/get/ntopng/interfaces.lua",
+			value: "ifid",
+			ui_type: ui_types.select,
+		}, {
+			main_source_def: true,
+			label: i18n("page_stats.source_def.device"),
+			regex_type: "ip",
+			value: "device",
+			value_url: "ip",
+			ui_type: ui_types.input,
+		}],
+	},
+	{
+		id: "sflow_interface",
+		regex_page_url: "lua\/pro\/enterprise\/sflowdevice_interface_details",
+		label: i18n("page_stats.source_def.sflow_interface"),
+		query: "sflowdev_port",
+		source_def_array: [{
+			label: i18n("page_stats.source_def.interface"),
+			sources_url: "lua/rest/v2/get/ntopng/interfaces.lua",
+			value: "ifid",
+			ui_type: ui_types.select,
+		}, {
+			label: i18n("page_stats.source_def.device"),
+			regex_type: "ip",
+			value: "device",
+			value_url: "ip",
+			ui_type: ui_types.input,
+		}, {
+			main_source_def: true,
+			label: i18n("page_stats.source_def.port"),
+			regex_type: "port",
+			value: "port",
+			value_url: "snmp_port_idx",
+			ui_type: ui_types.input,
+		}],
+	},
 	{
 		id: "observation_point",
 		regex_page_url: "lua\/pro\/enterprise\/observation_points",
