@@ -7,9 +7,16 @@
   e.g. functions that check if a string is null or empty
  */
 
-/* This function check if value is null, empty or 0 */
+/* This function check if value is not set (null or empty).
+ * Do not check for 0 as it may be a valid value. */
 const isEmptyOrNull = (value) => {
-  return !!(value == null || value == "" || value == 0);
+  return !!(value == null || value == "");
+}
+
+/* This function check if value is not set (null or empty).
+ * Do not check for 0 as it may be a valid value. */
+const isEmptyString = (value) => {
+  return !!(value == null || value === "");
 }
 
 /* This function check if value is null, or an empty array */
@@ -21,6 +28,7 @@ const isEmptyArrayOrNull = (value) => {
 
 const dataUtils = function () {
   return {
+    isEmptyString,
     isEmptyOrNull,
     isEmptyArrayOrNull,
   };
