@@ -5,6 +5,7 @@
 'use strict';
 
 import NtopUtils from "../ntop-utils";
+import { default as QoEUtils } from "../qoe-utils.js";
 
 
 const DataTableHandlers = function () {
@@ -634,12 +635,12 @@ export class DataTableRenders {
     }
 
     static filterize(key, value, label, tag_label, title, html, is_snmp_ip, ip) {
-        let content = `<a class='tag-filter' data-tag-key='${key}' title='${title || value}' data-tag-value='${value}' data-tag-label='${tag_label || label || value}' href='javascript:void(0)'>${html || label || value}</a>`;
+        let content = `<a class='tag-filter' data-bs-toggle='tooltip' data-bs-placement="bottom" data-tag-key='${key}' title='${title || value}' data-tag-value='${value}' data-tag-label='${tag_label || label || value}' href='javascript:void(0)'>${html || label || value}</a>`;
         if (is_snmp_ip != null) {
             if (is_snmp_ip) {
                 if (value) {
                     let url = NtopUtils.buildURL(`${http_prefix}/lua/pro/enterprise/snmp_device_details.lua?host=${value}`);
-                    content += ` <a href='${url}'data-bs-toggle='tooltip' title=''><i class='fas fa-laptop'></i></a>`;
+                    content += ` <a href='${url}' data-bs-toggle='tooltip' data-bs-placement="bottom" title=''><i class='fas fa-laptop'></i></a>`;
                 }
             } else {
                 if (ip && value) {
@@ -648,7 +649,7 @@ export class DataTableRenders {
                         value = value.split("_")[1];
                     }
                     let url = NtopUtils.buildURL(`${http_prefix}/lua/pro/enterprise/snmp_interface_details.lua?host=${ip}&snmp_port_idx=${value}`);
-                    content += ` <a href='${url}'data-bs-toggle='tooltip' title=''><i class='fas fa-laptop'></i></a>`;
+                    content += ` <a href='${url}' data-bs-toggle='tooltip' data-bs-placement="bottom" title=''><i class='fas fa-laptop'></i></a>`;
                 }
             }
         }
@@ -662,12 +663,21 @@ export class DataTableRenders {
             cell = "";
         }
         if (obj.color) cell = `<span class='font-weight-bold' style='color: ${obj.color}'>${cell}</span>`;
+        if (obj.title) cell = `<span data-bs-toggle="tooltip" data-bs-placement="bottom" title='${obj.title}'>${cell}</span>`;
         return cell;
     }
 
+    static formatValueLabelEngaged(obj, type, row, zero_is_null) {
+        let date_time = this.formatValueLabel(obj, type, row, zero_is_null)
+        if (row.is_engaged) {
+            date_time = `<i class="fa-solid fa-fire" data-bs-toggle="tooltip" data-bs-placement="top" title="${i18n('engaged_alert')}"></i> ${date_time}`
+        }
+        return date_time;
+    }
+
     static formatCategory(obj, type, row, zero_is_null) {
         if (type !== "display") return obj.value;
-        let cell = `<a class='tag-filter' data-tag-key='alert_category' data-tag-value='${obj.value}' data-tag-label='${obj.label}' href='javascript:void(0)'><i class="fa fas ${obj.icon}" title="${obj.label}"></i></a>`;
+        let cell = `<a class='tag-filter' data-tag-key='alert_category' data-tag-value='${obj.value}' data-tag-label='${obj.label}' href='javascript:void(0)'><i class="fa fas ${obj.icon}" data-bs-toggle="tooltip" data-bs-placement="bottom" title="${obj.label}"></i></a>`;
         if (zero_is_null == true && obj.value == 0) {
             cell = "";
         }
@@ -703,6 +713,18 @@ export class DataTableRenders {
         return ""
     }
 
+    static formatSRC2DSTTCPFlags(obj, type, row, zero_is_null) {
+        if (type !== "display") return obj.value;
+        let cell = `<a class='tag-filter' data-tag-key='src2dst_tcp_flags' data-tag-value='${obj.value}' data-tag-label='${obj.label}' href='javascript:void(0)'>${obj.label}</a>`;
+        return cell
+    }
+
+    static formatDST2SRCTCPFlags(obj, type, row, zero_is_null) {
+        if (type !== "display") return obj.value;
+        let cell = `<a class='tag-filter' data-tag-key='dst2src_tcp_flags' data-tag-value='${obj.value}' data-tag-label='${obj.label}' href='javascript:void(0)'>${obj.label}</a>`;
+        return cell
+    }
+
     static formatScore(obj, type, row, zero_is_null) {
         if (type !== "display") return obj.value;
         let cell = obj.label;
@@ -713,12 +735,21 @@ export class DataTableRenders {
         return `<a class='tag-filter' data-tag-key='score' title='${obj.label}' data-tag-value='${obj.value}' data-tag-label='${obj.label}' href='javascript:void(0)'>${cell}</a>`;
     }
 
+    static formatQoE(obj, type, row, zero_is_null) {
+        if (type !== "display") return obj.value;
+        let cell = obj.label;
+        if (zero_is_null == true && obj.value == 0) {
+            cell = "";
+        }
+        return `<a class='tag-filter' data-tag-key='qoe_score' title='${obj.label}' data-tag-value='${QoEUtils.GetQoEID(obj.value)}' data-tag-label='${obj.label}' href='javascript:void(0)'>${QoEUtils.QoEQualityIcon(obj.value)}</a>`;
+    }
+
     static formatMessage(obj, type, row, zero_is_null) {
         if (type !== "display") return obj.value;
 
         let cell = obj.descr;
         if (obj.shorten_descr)
-            cell = `<span title="${obj.descr}">${obj.shorten_descr}</span>`;
+            cell = `<span data-bs-toggle="tooltip" data-bs-placement="bottom" title="${obj.descr}">${obj.shorten_descr}</span>`;
 
         return cell;
     }
@@ -740,18 +771,22 @@ export class DataTableRenders {
 
     static filterize_2(key, value, label, tag_label, title, html) {
         if (value == null || (value == 0 && (label == null || label == ""))) { return ""; }
-        return `<a class='tag-filter' data-tag-key='${key}' title='${title || value}' data-tag-value='${value}' data-tag-label='${tag_label || label || value}' href='javascript:void(0)'>${html || label || value}</a>`;
+        return `<a class='tag-filter' data-bs-toggle="tooltip" data-bs-placement="bottom" data-tag-key='${key}' title='${title || value}' data-tag-value='${value}' data-tag-label='${tag_label || label || value}' href='javascript:void(0)'>${html || label || value}</a>`;
     }
 
     static getFormatGenericField(field, zero_is_null) {
         return function (obj, type, row) {
             if (type !== "display") return obj.value;
             if (zero_is_null == true && obj?.value == 0) { return ""; }
-            let html_ref = '';
-            if (obj.reference !== undefined)
-                html_ref = obj.reference
-            let label = DataTableRenders.filterize_2(field, row[field].value, row[field].label, row[field].label, row[field].label);
-            return label + ' ' + html_ref;
+            let formatted = '';
+            //if (typeof row[field] === 'object') {
+                formatted = DataTableRenders.filterize_2(field, row[field].value, row[field].label, row[field].label, row[field].label);
+                if (obj.reference !== undefined)
+                    formatted = formatted + ' ' + obj.reference;
+            //} else {
+            //    formatted = DataTableRenders.filterize_2(field, row[field], row[field], row[field], row[field]);
+            //}
+            return formatted;
         }
     }
 
@@ -818,32 +853,40 @@ export class DataTableRenders {
 
         if (row.role && row.role.value == 'attacker')
             label = label + ' ' + DataTableRenders.filterize('role', row.role.value,
-                '<i class="fas fa-skull" title="' + row.role.label + '"></i>', row.role.label);
+                '<i class="fas fa-skull" data-bs-toggle="tooltip" data-bs-placement="bottom" title="' + row.role.label + '"></i>', row.role.label);
         else if (row.role && row.role.value == 'victim')
             label = label + ' ' + DataTableRenders.filterize('role', row.role.value,
-                '<i class="fas fa-sad-tear" title="' + row.role.label + '"></i>', row.role.label);
+                '<i class="fas fa-sad-tear" data-bs-toggle="tooltip" data-bs-placement="bottom" title="' + row.role.label + '"></i>', row.role.label);
 
         if (row.role_cli_srv && row.role_cli_srv.value == 'client')
             label = label + ' ' + DataTableRenders.filterize('role_cli_srv', row.role_cli_srv.value,
-                '<i class="fas fa-long-arrow-alt-right" title="' + row.role_cli_srv.label + '"></i>', row.role_cli_srv.label);
+                '<i class="fas fa-long-arrow-alt-right" data-bs-toggle="tooltip" data-bs-placement="bottom" title="' + row.role_cli_srv.label + '"></i>', row.role_cli_srv.label);
         else if (row.role_cli_srv && row.role_cli_srv.value == 'server')
             label = label + ' ' + DataTableRenders.filterize('role_cli_srv', row.role_cli_srv.value,
-                '<i class="fas fa-long-arrow-alt-left" title="' + row.role_cli_srv.label + '"></i>', row.role_cli_srv.label);
+                '<i class="fas fa-long-arrow-alt-left" data-bs-toggle="tooltip" data-bs-placement="bottom" title="' + row.role_cli_srv.label + '"></i>', row.role_cli_srv.label);
 
         return label + ' ' + html_ref;
     }
 
-    static filterizeVlan(flow, row, key, value, label, title) {
+    static filterizeVlan(vlan, key, value, label, title) {
         let valueVlan = value;
         let labelVlan = label;
         let titleVlan = title;
-        if (flow.vlan && flow.vlan.value != 0) {
-            valueVlan = `${value}@${flow.vlan.value}`;
-            labelVlan = `${label}@${flow.vlan.label}`;
-            titleVlan = `${title}@${flow.vlan.title}`;
+        if (vlan && vlan.value != 0) {
+            valueVlan = `${value}@${vlan.value}`;
+            labelVlan = `${label}@${vlan.label}`;
+            titleVlan = `${title}@${vlan.title}`;
         }
         return DataTableRenders.filterize(key, valueVlan, labelVlan, labelVlan, titleVlan);
     }
+    
+    static formatIP(ip, type, row, zero_is_null) {
+        if (!ip) return "";
+        let title = "";
+        if (ip.label_long) title = ip.value + " [" + ip.label_long + "]";
+        let label = DataTableRenders.filterize(ip.tag_key, ip.value, ip.label, ip.label, title);
+        return label;
+    }
 
     static formatFlowTuple(flow, type, row, zero_is_null) {
         let active_ref = (flow.active_url ? `<a href="${flow.active_url}"><i class="fas fa-stream"></i></a>` : "");
@@ -851,9 +894,9 @@ export class DataTableRenders {
         if (flow.cli_ip.name) {
             let title = "";
             if (flow.cli_ip.label_long) title = flow.cli_ip.value + " [" + flow.cli_ip.label_long + "]";
-            cliLabel = DataTableRenders.filterizeVlan(flow, row, 'cli_name', flow.cli_ip.name, flow.cli_ip.label, title);
+            cliLabel = DataTableRenders.filterizeVlan(flow.vlan, 'cli_name', flow.cli_ip.name, flow.cli_ip.label, title);
         } else
-            cliLabel = DataTableRenders.filterizeVlan(flow, row, 'cli_ip', flow.cli_ip.value, flow.cli_ip.label, flow.cli_ip.label_long);
+            cliLabel = DataTableRenders.filterizeVlan(flow.vlan, 'cli_ip', flow.cli_ip.value, flow.cli_ip.label, flow.cli_ip.label_long);
 
         let cliFlagLabel = ''
 
@@ -864,7 +907,7 @@ export class DataTableRenders {
 
         let cliBlacklisted = ''
         if (flow.cli_ip.blacklisted == true)
-            cliBlacklisted = " <i class=\'fas fa-ban fa-sm\' title=\'" + i18n("hosts_stats.blacklisted") + "\'></i>"
+            cliBlacklisted = " <i class=\'fas fa-ban fa-sm\'  data-bs-toggle=\"tooltip\" data-bs-placement=\"bottom\" title=\'" + i18n("hosts_stats.blacklisted") + "\'></i>"
 
         let cliLocation = ''
         if (flow.cli_ip.location == 'multicast') {
@@ -879,9 +922,9 @@ export class DataTableRenders {
         if (flow.srv_ip.name) {
             let title = "";
             if (flow.srv_ip.label_long) title = flow.srv_ip.value + " [" + flow.srv_ip.label_long + "]";
-            srvLabel = DataTableRenders.filterizeVlan(flow, row, 'srv_name', flow.srv_ip.name, flow.srv_ip.label, title);
+            srvLabel = DataTableRenders.filterizeVlan(flow.vlan, 'srv_name', flow.srv_ip.name, flow.srv_ip.label, title);
         } else
-            srvLabel = DataTableRenders.filterizeVlan(flow, row, 'srv_ip', flow.srv_ip.value, flow.srv_ip.label, flow.srv_ip.label_long);
+            srvLabel = DataTableRenders.filterizeVlan(flow.vlan, 'srv_ip', flow.srv_ip.value, flow.srv_ip.label, flow.srv_ip.label_long);
         let srvPortLabel = ((flow.srv_port && flow.srv_port.value && flow.srv_port.value != 0) ? ":" + DataTableRenders.filterize('srv_port', flow.srv_port.value, flow.srv_port.label) : "");
 
         let srvFlagLabel = ''
@@ -891,7 +934,7 @@ export class DataTableRenders {
 
         let srvBlacklisted = ''
         if (flow.srv_ip.blacklisted == true)
-            srvBlacklisted = " <i class=\'fas fa-ban fa-sm\' title=\'" + i18n("hosts_stats.blacklisted") + "\'></i>"
+            srvBlacklisted = " <i class=\'fas fa-ban fa-sm\' data-bs-toggle=\"tooltip\" data-bs-placement=\"bottom\" title=\'" + i18n("hosts_stats.blacklisted") + "\'></i>"
 
         let srvLocation = ''
         if (flow.srv_ip.location == 'multicast') {
@@ -906,16 +949,16 @@ export class DataTableRenders {
         let srvIcons = "";
         if (row.cli_role) {
             if (row.cli_role.value == 'attacker')
-                cliIcons += DataTableRenders.filterize('role', 'attacker', '<i class="fas fa-skull" title="' + row.cli_role.label + '"></i>', row.cli_role.tag_label);
+                cliIcons += DataTableRenders.filterize('role', 'attacker', '<i class="fas fa-skull" data-bs-toggle="tooltip" data-bs-placement="bottom" title="' + row.cli_role.label + '"></i>', row.cli_role.tag_label);
             else if (row.cli_role.value == 'victim')
-                cliIcons += DataTableRenders.filterize('role', 'victim', '<i class="fas fa-sad-tear" title="' + row.cli_role.label + '"></i>', row.cli_role.tag_label);
+                cliIcons += DataTableRenders.filterize('role', 'victim', '<i class="fas fa-sad-tear" data-bs-toggle="tooltip" data-bs-placement="bottom" title="' + row.cli_role.label + '"></i>', row.cli_role.tag_label);
         }
 
         if (row.srv_role) {
             if (row.srv_role.value == 'attacker')
-                srvIcons += DataTableRenders.filterize('role', 'attacker', '<i class="fas fa-skull" title="' + row.srv_role.label + '"></i>', row.srv_role.tag_label);
+                srvIcons += DataTableRenders.filterize('role', 'attacker', '<i class="fas fa-skull" data-bs-toggle="tooltip" data-bs-placement="bottom" title="' + row.srv_role.label + '"></i>', row.srv_role.tag_label);
             else if (row.srv_role.value == 'victim')
-                srvIcons += DataTableRenders.filterize('role', 'victim', '<i class="fas fa-sad-tear" title="' + row.srv_role.label + '"></i>', row.srv_role.tag_label);
+                srvIcons += DataTableRenders.filterize('role', 'victim', '<i class="fas fa-sad-tear" data-bs-toggle="tooltip" data-bs-placement="bottom" title="' + row.srv_role.label + '"></i>', row.srv_role.tag_label);
         }
 
         return `${active_ref} ${cliLabel}${cliBlacklisted}${cliLocation}${cliFlagLabel}${cliPortLabel} ${cliIcons} ${flow.cli_ip.reference} <i class="fas fa-exchange-alt fa-lg" aria-hidden="true"></i> ${srvLabel}${srvBlacklisted}${srvLocation}${srvFlagLabel}${srvPortLabel} ${srvIcons} ${flow.srv_ip.reference}`;
