@@ -1,5 +1,5 @@
 /**
-    (C) 2022 - ntop.org
+    (C) 2022-24 - ntop.org
 */
 const types = {
     no_formatting: {
@@ -11,14 +11,14 @@ const types = {
     },
     number: {
         id: "number",
-        um: ["", "K", "M", "G", "T"],
+        um: ["", "K", "M", "B", "T"],
         step: 1000,
         decimal: null,
         scale_values: null,
     },
     full_number: {
         id: "number",
-        um: ["", "K", "M", "G", "T"],
+        um: ["", "K", "M", "B", "T"],
         step: 1000,
         decimal: null,
         scale_values: null,
@@ -37,7 +37,31 @@ const types = {
         um: ["bps", "Kbps", "Mbps", "Gbps", "Tbps", "Pbps"],
         step: 1000,
         decimal: 2,
-        scale_values: 8,        
+        scale_values: 8,
+        absolute_value: true,
+    },
+    bps_no_scale: {
+        id: "bps_no_scale",
+        um: ["bps", "Kbps", "Mbps", "Gbps", "Tbps", "Pbps"],
+        step: 1000,
+        decimal: 2,
+        scale_values: null,
+        absolute_value: true,
+    },
+    speed: {
+        id: "speed",
+        um: ["bit", "Kbit", "Mbit", "Gbit", "Tbit", "Pbit"],
+        step: 1000,
+        decimal: 0,
+        scale_values: null,
+        absolute_value: true,
+    },
+    flows: {
+        id: "flows",
+        um: ["flows", "Kflows", "Mflows", "Gflows"],
+        step: 1000,
+        decimal: 2,
+        scale_values: null,        
         absolute_value: true,
     },
     fps: {
@@ -48,6 +72,54 @@ const types = {
         scale_values: null,        
         absolute_value: true,
     },
+    fps_short: {
+        id: "fps_short",
+        um: ["fps", "Kfps", "Mfps", "Gfps"],
+        step: 1000,
+        decimal: 2,
+        scale_values: null,        
+        absolute_value: true,
+    },
+    alerts: {
+        id: "alerts",
+        um: ["alerts", "Kalerts", "Malerts", "Galerts"],
+        step: 1000,
+        decimal: 2,
+        scale_values: null,
+        absolute_value: true,
+    },
+    alertps: {
+        id: "alertps",
+        um: ["alerts/s", "Kalerts/s", "Malerts/s", "Galerts/s"],
+        step: 1000,
+        decimal: 2,
+        scale_values: null,
+        absolute_value: true,
+    },
+    hits: {
+        id: "hits",
+        um: ["hits", "Khits", "Mhits", "Ghits"],
+        step: 1000,
+        decimal: 2,
+        scale_values: null,        
+        absolute_value: true,
+    },
+    hitss: {
+        id: "hitss",
+        um: ["hits/s", "Khits/s", "Mhits/s", "Ghits/s"],
+        step: 1000,
+        decimal: 2,
+        scale_values: null,        
+        absolute_value: true,
+    },
+    packets: {
+        id: "packets",
+        um: ["packets", "Kpackets", "Mpackets", "Gpackets", "Tpackets"],
+        step: 1000,
+        decimal: 0,
+        scale_values: null,        
+        absolute_value: true,
+    },
     pps: {
         id: "pps",
         um: ["pps", "Kpps", "Mpps", "Gpps", "Tpps"],
@@ -64,11 +136,28 @@ const types = {
         scale_values: null,        
         absolute_value: true,
     },
+    drops: {
+        id: "drops",
+        um: ["dps", "Kdps", "Mdps", "Gdps", "Tdps"],
+        step: 1000,
+        decimal: 2,
+        scale_values: null,        
+        absolute_value: true,
+    },
     percentage: {
         id: "percentage",
         um: ["%"],
         step: 101,
-        decimal: 0,
+        decimal: 1,
+        scale_values: null,        
+        max_value: 100,
+        absolute_value: true,
+    },
+    ratio: {
+        id: "ratio",
+        um: [""],
+        step: 101,
+        decimal: 2,
         scale_values: null,        
         max_value: 100,
         absolute_value: true,
@@ -109,6 +198,25 @@ function getScaleFactorIndex(type, value) {
     return i;
 }
 
+function formatAccounting(amount, decimalCount = 0, decimal = ".", thousands = "'") {
+    try {
+	decimalCount = Math.abs(decimalCount);
+	decimalCount = isNaN(decimalCount) ? 2 : decimalCount;
+
+	const negativeSign = amount < 0 ? "-" : "";
+
+	let i = parseInt(amount = Math.abs(Number(amount) || 0).toFixed(decimalCount)).toString();
+	let j = (i.length > 3) ? i.length % 3 : 0;
+
+	return negativeSign +
+	    (j ? i.substr(0, j) + thousands : '') +
+	    i.substr(j).replace(/(\d{3})(?=\d)/g, "$1" + thousands) +
+	    (decimalCount ? decimal + Math.abs(amount - i).toFixed(decimalCount).slice(2) : "");
+    } catch (e) {
+	console.log(e)
+    }
+}
+
 function getFormatter(type, absoluteValue, scaleFactorIndex) {
     let typeOptions = types[type];
     if (typeOptions == null) { return null; }
@@ -159,7 +267,13 @@ function getFormatter(type, absoluteValue, scaleFactorIndex) {
             value = value / Math.pow(10, decimal);
             value = value.toFixed(decimal);
         } else {
-            value = Math.round(value);
+            if (i > 0) {
+                /* Has a decimal number due to the step */
+                value = Number(value.toFixed(1));
+            } else {
+                /* Has a decimal number */
+                value = Math.round(value);
+            }
         }
         
         if (negativeValue && !absoluteValue) { value *= -1; }
@@ -183,6 +297,7 @@ const formatterUtils = function() {
         getUnitMeasureLen,
         getFormatter,
         getScaleFactorIndex,
+	formatAccounting
     };
 }();
 
