@@ -49,19 +49,26 @@ const get_timeseries_groups_from_url = async (http_prefix, url_timeseries_groups
     return timeseries_groups;
 };
 
-const get_ts_group = (source_type, source_array, metric) => {
+const get_ts_group = (source_type, source_array, metric, customized_ts) => {
+    let ts_config = {
+        raw: true,
+        past: true, /* By default enable the past serie */
+        avg: false,
+        perc_95: false,
+    }
+
+    if(customized_ts && customized_ts.raw != null) ts_config.raw = customized_ts.raw;
+    if(customized_ts && customized_ts.past != null) ts_config.past = customized_ts.past;
+    if(customized_ts && customized_ts.avg != null) ts_config.avg = customized_ts.avg;
+    if(customized_ts && customized_ts.perc_95 != null) ts_config.perc_95 = customized_ts.perc_95;
+
     let id = get_ts_group_id(source_type, source_array, metric);
     let timeseries = [];
     for (let key in metric.timeseries) {
         let ts = metric.timeseries[key];
-        timeseries.push({
-            id: key,
-            label: ts.label,
-            raw: true,
-            past: false,
-            avg: false,
-            perc_95: false,
-        });
+        ts_config.id = key;
+        ts_config.label = ts.label;
+        timeseries.push(ts_config);
     }
     return {
         id, source_type, source_array, metric, timeseries,
@@ -132,15 +139,17 @@ function get_timeseries(timeseries_url, metric) {
     let timeseries = [];
     ts_url_array.forEach((ts_url) => {
         let values = r.exec(ts_url);
-        let id = values[1];
-        let label = metric.timeseries[id].label;
-        let raw = JSON.parse(values[2]);
-        let past = JSON.parse(values[3]);
-        let avg = JSON.parse(values[4]);
-        let perc_95 = JSON.parse(values[5]);
-        timeseries.push({
-            id, label, raw, past, avg, perc_95,
-        });
+        if(values.length > 0) {
+            let id = values[1];
+            let label = metric.timeseries[id].label;
+            let raw = JSON.parse(values[2]);
+            let past = JSON.parse(values[3]);
+            let avg = JSON.parse(values[4]);
+            let perc_95 = JSON.parse(values[5]);
+            timeseries.push({
+                id, label, raw, past, avg, perc_95,
+            });    
+        }
     });
     return timeseries;
 }
@@ -180,11 +189,7 @@ const get_source_array_from_value_array = async (http_prefix, source_type, sourc
         let source_def = source_type.source_def_array[i];
         if (source_def.sources_url || source_def.sources_function) {
             let sources = [];
-            if (source_def.sources_url) {
-                sources = await get_sources(http_prefix, source_type.id, source_def);
-            } else {
-                sources = source_def.sources_function();
-            }
+            sources = await get_sources(http_prefix, source_type.id, source_def, source_value_array);
             source = sources.find((s) => s.value == source_value);
             if (source == null) {
                 source = sources[0];
@@ -199,14 +204,24 @@ const get_source_array_from_value_array = async (http_prefix, source_type, sourc
 
 let cache_sources = {};
 
-const get_sources = async (http_prefix, id, source_def) => {
+function get_source_def_key(id, source_def, selected_source_value_array) {
     let key = `${id}_${source_def.value}`;
+    if (!source_def.refresh_on_sources_change) {
+        return key;
+    }
+    const value_array = selected_source_value_array.join("_");
+    key = `${key}_${value_array}`;
+    return key;
+}
+
+const get_sources = async (http_prefix, id, source_def, selected_source_value_array) => {
+    let key = get_source_def_key(id, source_def, selected_source_value_array);
     if (cache_sources[key] == null) {
         if (source_def.sources_url) {
             let url = `${http_prefix}/${source_def.sources_url}`;
             cache_sources[key] = ntopng_utility.http_request(url);
         } else if (source_def.sources_function) {
-            cache_sources[key] = source_def.sources_function();
+            cache_sources[key] = source_def.sources_function(selected_source_value_array);
         } else {
             return [];
         }
@@ -220,9 +235,9 @@ const get_sources = async (http_prefix, id, source_def) => {
         if (f_map_source_element == null) {
             throw `:Error: metrics-manager.js, missing sources_url_to_source ${source_def.value} key`;
         }
-        sources = sources.map((s) => f_map_source_element(s))
+        sources = sources.map((s) => f_map_source_element(s));
     }
-    return sources.sort(NtopUtils.sortAlphabetically)
+    return sources.sort(NtopUtils.sortAlphabetically);
 };
 
 function set_source_value_object_in_url(source_type, source_value_object) {
