@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can addresstribute it and/or modify
@@ -31,10 +31,10 @@ class AddressTree {
   u_int32_t numAddresses, numAddressesIPv4, numAddressesIPv6;
   ndpi_patricia_tree_t *getPatricia(char *what);
   ndpi_patricia_tree_t *ptree_v4, *ptree_v6;
-  std::map<u_int64_t, int16_t> macs;
+  std::map<u_int64_t, int64_t> macs;
   ndpi_void_fn_t free_func;
   RwLock updateLock;
-  
+
   void removePrefix(bool isV4, ndpi_prefix_t *prefix);
   static void walk(ndpi_patricia_tree_t *ptree, ndpi_void_fn3_t func,
                    void *const user_data);
@@ -53,23 +53,26 @@ class AddressTree {
   inline u_int32_t getNumAddressesIPv4() const { return (numAddressesIPv4); }
   inline u_int32_t getNumAddressesIPv6() const { return (numAddressesIPv6); }
 
+  inline bool isEmpty() { return(getNumAddresses() == 0); }
+
   inline ndpi_patricia_tree_t *getTree(bool isV4) const {
     return (isV4 ? ptree_v4 : ptree_v6);
   }
 
-  bool addAddress(const char *_net, const int16_t user_data = -1);
-  bool addAddressAndData(const char *_what, void *user_data);
+  bool addAddress(const char *_what, const int64_t user_data = -1);
+  bool addAddressAndData(const char *_what, void *user_data,
+			 bool fail_if_already_present = false);
   ndpi_patricia_node_t *addAddress(const IpAddress *const ipa);
   ndpi_patricia_node_t *addAddress(const IpAddress *const ipa, int network_bits,
                                    bool compact_after_add);
-  bool addAddresses(const char *net, const int16_t user_data = -1);
+  bool addAddresses(const char *net, const int64_t user_data = -1);
 
   void getAddresses(lua_State *vm);
 
-  int16_t findAddress(int family, void *addr,
+  int64_t findAddress(int family, void *addr,
                       u_int8_t *network_mask_bits = NULL);
-  int16_t findMac(const u_int8_t addr[]);
-  int16_t find(const char *addr, u_int8_t *network_mask_bits = NULL);
+  int64_t findMac(const u_int8_t addr[]);
+  int64_t find(const char *addr, u_int8_t *network_mask_bits = NULL);
 
   /* Return true on match, false otherwise */
   bool match(char *addr);
@@ -83,6 +86,9 @@ class AddressTree {
 
   void dump();
   void walk(ndpi_void_fn3_t func, void *const user_data);
+
+  char* serialize(char *buf, u_int buf_len);
+  bool  deserialize(char *json);
 };
 
 #endif /* _ADDRESS_TREE_H_ */
