@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -76,7 +76,7 @@ class Country : public GenericHashEntry,
   void lua(lua_State *vm, DetailsLevel details_level, bool asListElement);
 
   void serialize(json_object *obj, DetailsLevel details_level);
-  inline char *getSerializationKey(char *buf, uint bufsize) {
+  inline char *getSerializationKey(char *buf, u_int bufsize) {
     snprintf(buf, bufsize, COUNTRY_SERIALIZED_KEY, iface->get_id(),
              country_name);
     return (buf);
