@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -48,8 +48,8 @@ class Geolocation {
     return (false);
 #endif
   };
-  void getAS(IpAddress *addr, u_int32_t *asn, char **asname);
-  void getInfo(IpAddress *addr, char **continent_code, char **country_code,
+  bool getAS(IpAddress *addr, u_int32_t *asn, char **asname);
+  bool getInfo(IpAddress *addr, char **continent_code, char **country_code,
                char **city, float *latitude, float *longitude);
   static void freeInfo(char **continent_code, char **country_code, char **city);
 };
