@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -34,7 +34,6 @@ class Host : public GenericHashEntry,
   IpAddress ip;
   Mac *mac;
   char *asname, *blacklist_name;
-
   int32_t iface_index; /* Interface index on which this host has been first observed */
   u_int16_t host_services_bitmap;
   u_int16_t vlan_id;
@@ -44,9 +43,13 @@ class Host : public GenericHashEntry,
   u_int8_t num_remote_access;
   HostStats *stats, *stats_shadow;
   time_t last_stats_reset;
+#ifdef NTOPNG_PRO
+  QoEStats qoe_stats;
+#endif
   std::atomic<u_int32_t> active_alerted_flows;
   u_int8_t view_interface_mac[6];
-
+  bool is_mac_meaningful; /* True if the MAC associated is the one of the host and not of a router */
+  
   /*
     The check below makes sense for TCP as with UDP unidirectional flows
     (e.g. RTP or syslog) could be legitimate. However in general UDP flows
@@ -59,10 +62,8 @@ class Host : public GenericHashEntry,
   /* Host data: update Host::deleteHostData when adding new fields */
   struct {
     char *mdns /* name from a MDNS reply of any type */,
-        *mdns_txt /* name from a TXT MDNS reply after "nm=" field (most
-                     accurate) */
-        ,
-        *mdns_info /* name from a TXT MDNS reply */;
+      *mdns_txt, /* name from a TXT MDNS reply after "nm=" field (most accurate) */
+      *mdns_info /* name from a TXT MDNS reply */;
     char *resolved;    /* The name as resolved by ntopng DNS requests */
     char *netbios;     /* The NetBIOS name */
     char *tls;         /* The TLS SNI or the name as dissected from other
@@ -78,7 +79,7 @@ class Host : public GenericHashEntry,
   /* END Host data: */
 
   /* Counters used by host alerts */
-  AttackVictimCounter syn_flood, flow_flood, icmp_flood, dns_flood, snmp_flood, rst_scan;
+  AttackVictimCounter flow_flood, icmp_flood, dns_flood, snmp_flood, rst_scan;
 
   struct {
     u_int32_t syn_sent_last_min, synack_recvd_last_min; /* (attacker) */
@@ -91,12 +92,12 @@ class Host : public GenericHashEntry,
   } fin_scan;
 
   /* Need atomic as inc/dec done on different threads */
-  std::atomic<u_int32_t> num_active_flows_as_client, num_active_flows_as_server;
+  std::atomic<u_int32_t> num_active_flows_as_client, num_active_flows_as_server; /* All protocols */
   u_int32_t asn;
 
   struct {
     u_int32_t as_client /* this host contacted a blacklisted host */,
-        as_server /* a blacklisted host contacted me */;
+      as_server /* a blacklisted host contacted me */;
     u_int32_t checkpoint_as_client, checkpoint_as_server;
   } num_blacklisted_flows;
 
@@ -104,13 +105,18 @@ class Host : public GenericHashEntry,
   Country *country;
   VLAN *vlan;
   ObservationPoint *obs_point;
-  ndpi_bitmap *tcp_udp_contacted_ports_no_tx; /* Ports of this host that have
-                                                 been contacted by peers */
-  OperatingSystem *os; /* Pointer to an instance of operating system, used
-                          internally to handle operating system statistics    */
-  OSType os_type; /* Operating system type, equivalent to os->get_os_type(),
-                     used by operating system setters and getters */
+  ndpi_bitmap *tcp_udp_contacted_ports_no_tx; /* Ports of this host that have been contacted by peers */
 
+  /*
+    Both OS and device type are duplicated in MAC and host as
+    for a device begind a router, the device type must be on the host
+    (e.g. a laptop) otherwise the device type would be wrongly set
+    to a router
+  */
+  ndpi_os os_type, alt_os_type; /* Operating system type, equivalent to os->get_os_type(),
+				   used by operating system setters and getters */
+  DeviceType device_type;
+  
   struct {
     u_int32_t numIngressFlows, numEgressFlows;
   } unidirectionalTCPUDPFlows;
@@ -123,7 +129,7 @@ class Host : public GenericHashEntry,
 
   struct {
     u_int8_t alertTriggered : 1, hostAlreadyEvaluated : 1,
-        checkAlreadyExecutedOnce : 1, _not_used : 7;
+      checkAlreadyExecutedOnce : 1, _not_used : 7;
     u_int8_t score;
     u_int32_t skip_until_epoch;
     char *msg;
@@ -158,7 +164,6 @@ class Host : public GenericHashEntry,
   void initialize(Mac *_mac, int32_t _iface_idx,
 		  u_int16_t _vlan_id,
                   u_int16_t observation_point_id);
-  void inlineSetOS(OSType _os);
   bool statsResetRequested();
   void checkStatsReset();
 #ifdef HAVE_NEDGE
@@ -197,9 +202,7 @@ class Host : public GenericHashEntry,
   inline bool isBroadcastDomainHost() const {
     return (is_in_broadcast_domain ? true : false);
   };
-  inline bool serializeByMac() const {
-    return (isLocalHost() && iface->serializeLbdHostsAsMacs());
-  }
+  virtual bool serializeByMac() const { return(false); }
   inline bool isDHCPHost() const { return (is_dhcp_host ? true : false); };
   inline bool isCrawlerBotScannerHost() const {
     return (is_crawler_bot_scanner ? true : false);
@@ -237,32 +240,47 @@ class Host : public GenericHashEntry,
   inline bool isDhcpServer() const {
     return (host_services_bitmap & (1 << HOST_IS_DHCP_SERVER));
   }
-  void setDhcpServer(char *name);
-
+  virtual void setDhcpServer();
+  
   inline bool isDnsServer() const {
     return (host_services_bitmap & (1 << HOST_IS_DNS_SERVER));
   }
-  void setDnsServer(char *name);
+  virtual void setDnsServer();
 
   inline bool isSmtpServer() const {
     return (host_services_bitmap & (1 << HOST_IS_SMTP_SERVER));
   }
-  void setSmtpServer(char *name);
+  virtual void setSmtpServer();
 
   inline bool isImapServer() const {
     return (host_services_bitmap & (1 << HOST_IS_IMAP_SERVER));
   }
-  void setImapServer(char *name);
+  virtual void setImapServer();
 
   inline bool isPopServer() const {
     return (host_services_bitmap & (1 << HOST_IS_POP_SERVER));
   }
-  void setPopServer(char *name);
+  virtual void setPopServer();
 
   inline bool isNtpServer() const {
     return (host_services_bitmap & (1 << HOST_IS_NTP_SERVER));
   }
-  void setNtpServer(char *name);
+  virtual void setNtpServer();
+
+  inline bool isHttpServer() const {
+    return (host_services_bitmap & (1 << HOST_IS_HTTP_SERVER));
+  }
+  virtual void setHttpServer();
+
+  inline bool isSshServer() const {
+    return (host_services_bitmap & (1 << HOST_IS_SSH_SERVER));
+  }
+  virtual void setSshServer();
+
+  inline bool isRdpServer() const {
+    return (host_services_bitmap & (1 << HOST_IS_RDP_SERVER));
+  }
+  virtual void setRdpServer();
 
   inline u_int16_t getServicesMap() { return (host_services_bitmap); }
   /*
@@ -331,7 +349,10 @@ class Host : public GenericHashEntry,
     return (observationPointId);
   };
 
-  char *get_name(char *buf, u_int buf_len, bool force_resolution_if_not_found);
+  inline bool has_name_set() { return(names.server_name ? true : false); }
+
+  char* get_name(char *buf, u_int buf_len, bool force_resolution_if_not_found);
+  char* print(char *buf, u_int buf_len, bool force_resolution_if_not_found = false);
 
   inline void incSentTcp(u_int32_t ooo_pkts, u_int32_t retr_pkts,
                          u_int32_t lost_pkts, u_int32_t keep_alive_pkts) {
@@ -363,7 +384,7 @@ class Host : public GenericHashEntry,
                                     rcvd_bytes);
   }
 
-  virtual int16_t get_local_network_id() const = 0;
+  virtual int32_t get_local_network_id() const = 0;
   virtual HTTPstats *getHTTPstats() { return (NULL); };
   virtual DnsStats *getDNSstats() { return (NULL); };
   virtual ICMPstats *getICMPstats() { return (NULL); };
@@ -377,7 +398,7 @@ class Host : public GenericHashEntry,
   inline void set_ipv4(u_int32_t _ipv4) { ip.set(_ipv4); };
   inline void set_ipv6(struct ndpi_in6_addr *_ipv6) { ip.set(_ipv6); };
   inline u_int32_t key() { return (ip.key()); };
-  inline IpAddress *get_ip() { return (&ip); };
+  inline IpAddress* get_ip() { return (&ip); };
   inline bool isIPv4() const { return ip.isIPv4(); };
   inline bool isIPv6() const { return ip.isIPv6(); };
   void set_mac(Mac *m);
@@ -387,9 +408,15 @@ class Host : public GenericHashEntry,
     return (mac ? mac->get_mac() : NULL);
   }
   inline Mac *getMac() const { return (mac); }
+  virtual void setDeviceType(DeviceType devtype);
   inline DeviceType getDeviceType() const {
-    Mac *m = mac;
-    return (isBroadcastDomainHost() && m ? m->getDeviceType() : device_unknown);
+    if(device_type != device_unknown)
+      return(device_type);
+    else {
+      Mac *m = mac;
+
+      return (isBroadcastDomainHost() && m ? m->getDeviceType() : device_unknown);
+    }
   }
   char *getResolvedName(char *const buf, ssize_t buf_len);
   char *getServerName(char *const buf, ssize_t buf_len);
@@ -501,7 +528,6 @@ class Host : public GenericHashEntry,
                          ndpi_protocol_category_t category_id) const;
   void lua_get_packets(lua_State *vm) const;
   void lua_get_time(lua_State *vm) const;
-  void lua_get_syn_flood(lua_State *vm) const;
   void lua_get_flow_flood(lua_State *vm) const;
   void lua_get_services(lua_State *vm) const;
   void lua_get_syn_scan(lua_State *vm) const;
@@ -549,7 +575,7 @@ class Host : public GenericHashEntry,
   void updateFinAckAlertsCounter(time_t when, bool finack_sent);
 
   virtual void updateNetworkRTT(u_int32_t rtt_msecs) { return; }
-  inline void updateRoundTripTime(u_int32_t rtt_msecs) {
+  inline void updateRoundTripTimexo(u_int32_t rtt_msecs) {
     if (as) as->updateRoundTripTime(rtt_msecs);
     updateNetworkRTT(rtt_msecs);
   }
@@ -569,9 +595,11 @@ class Host : public GenericHashEntry,
   inline u_int16_t dns_flood_victim_hits() const {
     return dns_flood.victim_counter ? dns_flood.victim_counter->hits() : 0;
   };
+  
   inline u_int16_t dns_flood_attacker_hits() const {
     return dns_flood.attacker_counter ? dns_flood.attacker_counter->hits() : 0;
   };
+  
   inline void reset_dns_flood_hits() {
     if (dns_flood.victim_counter) dns_flood.victim_counter->reset_hits();
     if (dns_flood.attacker_counter) dns_flood.attacker_counter->reset_hits();
@@ -580,48 +608,40 @@ class Host : public GenericHashEntry,
   inline u_int16_t snmp_flood_victim_hits() const {
     return snmp_flood.victim_counter ? snmp_flood.victim_counter->hits() : 0;
   };
+
   inline u_int16_t snmp_flood_attacker_hits() const {
     return snmp_flood.attacker_counter ? snmp_flood.attacker_counter->hits()
                                        : 0;
   };
+
   inline void reset_snmp_flood_hits() {
     if (snmp_flood.victim_counter) snmp_flood.victim_counter->reset_hits();
     if (snmp_flood.attacker_counter) snmp_flood.attacker_counter->reset_hits();
   };
 
-  inline u_int16_t syn_flood_victim_hits() const {
-    return syn_flood.victim_counter ? syn_flood.victim_counter->hits() : 0;
-  };
-  inline u_int16_t syn_flood_attacker_hits() const {
-    return syn_flood.attacker_counter ? syn_flood.attacker_counter->hits() : 0;
-  };
-  inline void reset_syn_flood_hits() {
-    if (syn_flood.victim_counter) syn_flood.victim_counter->reset_hits();
-    if (syn_flood.attacker_counter) syn_flood.attacker_counter->reset_hits();
-  };
-
   inline u_int16_t flow_flood_victim_hits() const {
     return flow_flood.victim_counter ? flow_flood.victim_counter->hits() : 0;
   };
+  
   inline u_int16_t flow_flood_attacker_hits() const {
-    return flow_flood.attacker_counter ? flow_flood.attacker_counter->hits()
-                                       : 0;
+    return flow_flood.attacker_counter ? flow_flood.attacker_counter->hits() : 0;
   };
+  
   inline void reset_flow_flood_hits() {
     if (flow_flood.victim_counter) flow_flood.victim_counter->reset_hits();
     if (flow_flood.attacker_counter) flow_flood.attacker_counter->reset_hits();
   };
-
+  
   inline u_int32_t syn_scan_victim_hits() const {
     return syn_scan.syn_recvd_last_min > syn_scan.synack_sent_last_min
-               ? syn_scan.syn_recvd_last_min - syn_scan.synack_sent_last_min
-               : 0;
+      ? syn_scan.syn_recvd_last_min - syn_scan.synack_sent_last_min : 0;
   };
+  
   inline u_int32_t syn_scan_attacker_hits() const {
     return syn_scan.syn_sent_last_min > syn_scan.synack_recvd_last_min
-               ? syn_scan.syn_sent_last_min - syn_scan.synack_recvd_last_min
-               : 0;
+               ? syn_scan.syn_sent_last_min - syn_scan.synack_recvd_last_min : 0;
   };
+  
   inline void reset_syn_scan_hits() {
     syn_scan.syn_sent_last_min = syn_scan.synack_recvd_last_min =
         syn_scan.syn_recvd_last_min = syn_scan.synack_sent_last_min = 0;
@@ -629,14 +649,14 @@ class Host : public GenericHashEntry,
 
   inline u_int32_t fin_scan_victim_hits() const {
     return fin_scan.fin_recvd_last_min > fin_scan.finack_sent_last_min
-               ? fin_scan.fin_recvd_last_min - fin_scan.finack_sent_last_min
-               : 0;
+               ? fin_scan.fin_recvd_last_min - fin_scan.finack_sent_last_min : 0;
   };
+  
   inline u_int32_t fin_scan_attacker_hits() const {
     return fin_scan.fin_sent_last_min > fin_scan.finack_recvd_last_min
-               ? fin_scan.fin_sent_last_min - fin_scan.finack_recvd_last_min
-               : 0;
+               ? fin_scan.fin_sent_last_min - fin_scan.finack_recvd_last_min : 0;
   };
+  
   inline void reset_fin_scan_hits() {
     fin_scan.fin_sent_last_min = fin_scan.finack_recvd_last_min =
         fin_scan.fin_recvd_last_min = fin_scan.finack_sent_last_min = 0;
@@ -645,16 +665,20 @@ class Host : public GenericHashEntry,
   inline u_int16_t rst_scan_victim_hits() const {
     return rst_scan.victim_counter ? rst_scan.victim_counter->hits() : 0;
   };
+  
   inline u_int16_t rst_scan_attacker_hits() const {
     return rst_scan.attacker_counter ? rst_scan.attacker_counter->hits() : 0;
   };
+  
   inline void reset_rst_scan_hits() {
     if (rst_scan.victim_counter) rst_scan.victim_counter->reset_hits();
     if (rst_scan.attacker_counter) rst_scan.attacker_counter->reset_hits();
   };
 
-  void incNumFlows(time_t t, bool as_client);
-  void decNumFlows(time_t t, bool as_client);
+  void incNumFlows(time_t t, bool as_client, bool isTCP);
+  void decNumFlows(time_t t, bool as_client, bool isTCP, u_int16_t isTwhOver);
+  void incNumEstablishedTCPFlows(bool as_client);
+
   inline void incNumAlertedFlows(bool as_client) {
     active_alerted_flows++;
     if (stats) stats->incNumAlertedFlows(as_client);
@@ -690,7 +714,7 @@ class Host : public GenericHashEntry,
   virtual void addContactedDomainName(char *domain_name){};
   virtual u_int32_t getDomainNamesCardinality() { return 0; };
   virtual void resetDomainNamesCardinality(){};
-  virtual NetworkStats *getNetworkStats(int16_t networkId) { return (NULL); };
+  virtual NetworkStats *getNetworkStats(int32_t networkId) { return (NULL); };
   inline Country *getCountryStats() { return country; };
 
   bool match(const AddressTree *const tree) const { return ip.match(tree); };
@@ -762,21 +786,23 @@ class Host : public GenericHashEntry,
   void checkNameReset();
   void checkDataReset();
   void checkBroadcastDomain();
+  void updateView(IpAddress *ipa);
   bool hasAnomalies() const;
   void housekeep(time_t t); /* Virtual method, called in the datapath from
                                GenericHash::purgeIdle */
   virtual void inlineSetOSDetail(const char *detail) {}
   virtual const char *getOSDetail(char *const buf, ssize_t buf_len);
   void offlineSetTLSName(const char *n);
-  void offlineSetHTTPName(const char *n);
-  void offlineSetNetbiosName(const char *n);
+  virtual void offlineSetHTTPName(const char *n);
+  virtual void offlineSetNetbiosName(const char *n);
   void offlineSetSSDPLocation(const char *url);
-  void offlineSetMDNSInfo(char *const s);
-  void offlineSetMDNSName(const char *n);
-  void offlineSetMDNSTXTName(const char *n);
-  void offlineSetDHCPName(const char *n);
-  void setServerName(const char *n);
-  void setResolvedName(const char *resolved_name);
+  virtual void offlineSetMDNSInfo(char *const s);
+  virtual void offlineSetMDNSName(const char *n);
+  virtual void offlineSetMDNSTXTName(const char *n);
+  virtual void offlineSetDHCPName(const char *n);
+  virtual void offlineSetDhcpFingerprint(const char *fingerprint) { ; }
+  virtual void setServerName(const char *n);
+  virtual void setResolvedName(const char *resolved_name);
   virtual Fingerprint *getJA4Fingerprint()   { return (NULL); }
   virtual Fingerprint *getHASSHFingerprint() { return (NULL); }
 
@@ -793,11 +819,9 @@ class Host : public GenericHashEntry,
   bool isHostAlertDisabled(HostAlertType alert_type);
   bool isFlowAlertDisabled(FlowAlertType alert_type);
 
-  void setOS(OSType _os);
-  OSType getOS() const;
-  void incOSStats(time_t when, u_int16_t proto_id, u_int64_t sent_packets,
-                  u_int64_t sent_bytes, u_int64_t rcvd_packets,
-                  u_int64_t rcvd_bytes);
+  virtual bool setOS(ndpi_os _os, OSLearningMode mode);
+  ndpi_os getOS() const    { return os_type; }
+  ndpi_os getAltOS() const { return alt_os_type; }
 
   void incCliContactedHosts(IpAddress *peer) {
     stats->incCliContactedHosts(peer);
@@ -907,7 +931,7 @@ class Host : public GenericHashEntry,
   void setBlacklistName(char *name);
   inline void blacklistHost(char *blacklist_name) { setBlacklistName(blacklist_name); }
   inline char* getBlacklistName()                 { return(blacklist_name);           }
-  
+
   virtual void toggleRxOnlyHost(bool rx_only);
   inline bool resetHostTopSites() {
     if (stats) {
@@ -964,6 +988,11 @@ class Host : public GenericHashEntry,
   void setUnidirectionalTCPUDPNoTXEgressFlow(IpAddress *ip, u_int16_t port);
   void setUnidirectionalTCPUDPNoTXIngressFlow(IpAddress *ip, u_int16_t port);
 
+  /* Currently used only by LocalHost */
+  virtual void setAssetUpdated() { ; }
+  bool addDataToAssets(char *field, char *value) { return false; };
+  bool removeDataFromAssets(char *field) { return false; };
+
   u_int32_t getNumContactedPeersAsClientTCPUDPNoTX();
   u_int32_t getNumContactsFromPeersAsServerTCPUDPNoTX();
 
@@ -979,7 +1008,15 @@ class Host : public GenericHashEntry,
   inline int32_t getInterfaceIndex()            { return(iface_index); };
 
   virtual SPSCQueue<std::pair<u_int16_t, u_int16_t>> *getContactedServerPorts() { return (NULL);};
-  virtual char *getSerializationKey(char *buf, uint bufsize) { return (NULL); };
+  virtual char *getSerializationKey(char *buf, u_int bufsize, bool short_format = false) { return (NULL); };
+  virtual void setTCPfingerprint(char *tcp_fingerprint, ndpi_os os) { ; }
+#ifdef NTOPNG_PRO
+  void incQoEStats(QoEType qoe_type) { qoe_stats.incQoEStats(qoe_type); };
+#endif
+
+  void setnDPIOS(ndpi_os hint);
+  virtual void setMACmeaningful() { is_mac_meaningful = true; }
+  inline bool isMACmeaningful()   { return(is_mac_meaningful || isSystemHost()); }
 };
 
 #endif /* _HOST_H_ */
