@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -35,7 +35,7 @@ class HostChecksExecutor { /* One instance per ntopng Interface */
   void loadHostChecksAlerts(std::list<HostCheck *> *cb_list);
   void loadHostChecks(HostChecksLoader *fcl);
 
-  void releaseAllDisabledAlerts(Host *h);
+  void releaseAllDisabledAlerts(Host *h, time_t now);
 
  public:
   HostChecksExecutor(HostChecksLoader *fcl, NetworkInterface *_iface);
