@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2015-24 - ntop.org
+ * (C) 2015-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -72,6 +72,8 @@ class HostPools {
   u_int16_t getPool(Host *h, bool *mac_match = NULL);
   u_int16_t getPool(Mac *m);
   u_int16_t getPoolByName(const char *pool_name);
+  u_int16_t getCurrentHostPoolsNumber();
+  u_int32_t getCurrentMaxHostPoolsMembers();
 
   bool findIpPool(IpAddress *ip, u_int16_t vlan_id, u_int16_t *found_pool,
                   ndpi_patricia_node_t **found_node);
@@ -184,6 +186,7 @@ class HostPools {
                 ? routing_policy_id[pool_id]
                 : DEFAULT_ROUTING_TABLE_ID);
   }
+
 #endif
 };
 
