@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -29,7 +29,9 @@ struct ipAddress {
       multicastIP : 1, broadcastIP : 1, blacklistedIP : 1, localIP : 1;
 
   u_int8_t dnsServer : 1, dhcpServer : 1, smtpServer : 1, ntpServer : 1,
-      imapServer : 1, popServer : 1, unused : 2;
+    imapServer : 1, popServer : 1, gateway: 1,   httpServer : 1;
+  u_int8_t sshServer : 1, rdpServer : 1, unused : 6;
+  
   union {
     struct ndpi_in6_addr ipv6;
     u_int32_t ipv4; /* Host byte code */
@@ -49,6 +51,7 @@ class IpAddress {
  public:
   IpAddress();
   IpAddress(const IpAddress& ipa);
+  IpAddress(const struct ipAddress ipa);
 
   void checkIP();
   bool isEmpty() const;
@@ -62,7 +65,10 @@ class IpAddress {
   inline const struct ndpi_in6_addr* get_ipv6() const {
     return ((addr.ipVersion == 6) ? &addr.ipType.ipv6 : NULL);
   }
+
+  void fillIP(ndpi_ip_addr_t *ip_addr);
   inline const struct ipAddress* getIP() const { return (&addr); };
+  inline u_int8_t getVersion() { return(addr.ipVersion); }
   inline bool equal(u_int32_t ipv4_addr) const {
     if ((addr.ipVersion == 4) && (addr.ipType.ipv4 == ipv4_addr))
       return (true);
@@ -106,17 +112,14 @@ class IpAddress {
   void set(union usa* ip);
   void set(const char* ip);
   void reloadBlacklist(ndpi_detection_module_struct* ndpi_struct);
-  inline bool isLoopbackAddress() const { return (addr.loopbackIP); };
-  inline bool isPrivateAddress() const { return (addr.privateIP); };
+  inline bool isLoopbackAddress() const  { return (addr.loopbackIP); };
+  inline bool isPrivateAddress() const   { return (addr.privateIP); };
   inline bool isMulticastAddress() const { return (addr.multicastIP); };
   inline bool isBroadcastAddress() const { return (addr.broadcastIP); };
   inline bool isBlacklistedAddress() const { return (addr.blacklistedIP); };
-  inline bool isBroadMulticastAddress() const {
-    return (addr.broadcastIP || addr.multicastIP);
-  };
-  inline bool isNonEmptyUnicastAddress() const {
-    return (!isMulticastAddress() && !isBroadcastAddress() && !isEmpty());
-  };
+  inline bool isBroadMulticastAddress() const { return (addr.broadcastIP || addr.multicastIP); };
+  inline bool isNonEmptyUnicastAddress() const { return (!isMulticastAddress() && !isBroadcastAddress() && !isEmpty()); };
+  inline bool isPublicAddress() const{ return ((!isPrivateAddress()) && isNonEmptyUnicastAddress()); }
   inline u_int8_t getVersion() const { return (addr.ipVersion); };
   inline void setVersion(u_int8_t version) { addr.ipVersion = version; };
 
@@ -132,11 +135,20 @@ class IpAddress {
   inline void setPopServer() { addr.popServer = true; }
   inline bool isNtpServer() const { return (addr.ntpServer); }
   inline void setNtpServer() { addr.ntpServer = true; }
-
+  inline bool isHttpServer() const { return (addr.httpServer); }
+  inline void setHttpServer() { addr.httpServer = true; }
+  inline bool isSshServer() const { return (addr.sshServer); }
+  inline void setSshServer() { addr.sshServer = true; }
+  inline bool isRdpServer() const { return (addr.rdpServer); }
+  inline void setRdpServer() { addr.rdpServer = true; }
+  inline bool isGateway() const { return (addr.gateway); }
+  inline void setGateway(bool is_gateway) { addr.gateway = is_gateway; }
+  /* NOTE: update Host::updateView() when adding new services */
+  
   char* print(char* str, u_int str_len, u_int8_t bitmask = 0xFF) const;
   char* printMask(char* str, u_int str_len, bool isLocalIP);
   bool isLocalHost() const;
-  bool isLocalHost(int16_t* network_id) const;
+  bool isLocalHost(int32_t* network_id) const;
   bool isLocalInterfaceAddress();
   bool get_sockaddr(struct sockaddr** const sa, ssize_t* const sa_len) const;
 
