@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,36 +26,36 @@
 
 class LocalHost : public Host {
  protected:
-  int16_t local_network_id;
+  int32_t local_network_id;
   time_t initialization_time;
+  bool inconsistent_host_os;
   LocalHostStats *initial_ts_point;
   /* contacted_server_ports it's a buffer used by the "Server Port Detected" check */
   SPSCQueue<std::pair<u_int16_t, u_int16_t>> contacted_server_ports;
-  UsedPorts usedPorts;
-  HostFingerprints *fingerprints;
+  UsedPorts usedPorts; /* List of server+client-contacted ports */
+  ndpi_os tcp_fingerprint_host_os; /* Learnt from TCP Fingerprinting */
+  HostFingerprints *fingerprints; /* Application fingerprints */
   std::unordered_map<u_int32_t, DoHDoTStats *> doh_dot_map;
   u_int8_t router_mac[6]; /* MAC address pf the first router used (no Mac* to
                              avoid purging race conditions) */
-  u_int8_t router_mac_set : 1, drop_all_host_traffic : 1, systemHost : 1, _notused : 5;
+  u_int8_t router_mac_set : 1, drop_all_host_traffic : 1, systemHost : 1, asset_map_updated : 1, _notused : 4;
   /* LocalHost data: update LocalHost::deleteHostData when adding new fields */
-  char *os_detail;
+  char *os_detail, *tcp_fingerprint;
+  std::map<OSLearningMode, ndpi_os> os_learning; /* How OS info has been learnt */
+  std::map<std::string, std::string> asset_map; /* For generic purposes, a <string, string> pair is done */
+  struct timeval last_periodic_asset_update;
   /* END Host data: */
 
   void initialize();
   void deferredInitialization();
   void freeLocalHostData();
-  void addInactiveData();
-  void removeInactiveData();
   virtual void deleteHostData();
 
-  char *getMacBasedSerializationKey(char *redis_key, size_t size,
-                                    char *mac_key);
-  char *getIpBasedSerializationKey(char *redis_key, size_t size);
+  char *getMacBasedSerializationKey(char *redis_key, size_t size, char *mac_key, bool short_format);
+  char *getIPBasedSerializationKey(char *redis_key, size_t size, bool short_format);
   void luaDoHDot(lua_State *vm);
-#ifdef NTOPNG_PRO
-  void dumpAssetInfo();
-#endif
-
+  void syncMACMetadata(bool force_update);
+  
  public:
   LocalHost(NetworkInterface *_iface, int32_t _iface_idx,
 	    Mac *_mac, u_int16_t _u_int16_t,
@@ -66,20 +66,20 @@ class LocalHost : public Host {
   virtual ~LocalHost();
 
   virtual void set_hash_entry_state_idle();
-  virtual int16_t get_local_network_id() const { return (local_network_id); };
+  virtual int32_t get_local_network_id() const { return (local_network_id); };
   virtual bool isLocalHost() const { return (true); };
   virtual bool isLocalUnicastHost() const {
     return (!(isBroadcastHost() || isMulticastHost()));
   };
   virtual bool isSystemHost() const { return (systemHost); };
+  virtual bool serializeByMac() const { return(iface->serializeLbdHostsAsMacs() || is_dhcp_host); }
 
   virtual void updateNetworkRTT(u_int32_t rtt_msecs) {
     NetworkStats *network = iface->getNetworkStats(get_local_network_id());
     if (network) network->updateRoundTripTime(rtt_msecs);
   }
 
-  void toggleRxOnlyHost(bool rx_only);
-  virtual NetworkStats *getNetworkStats(int16_t networkId) {
+  virtual NetworkStats *getNetworkStats(int32_t networkId) {
     return (iface->getNetworkStats(networkId));
   };
   virtual u_int32_t getActiveHTTPHosts() {
@@ -131,7 +131,7 @@ class LocalHost : public Host {
   virtual void serialize(json_object *obj, DetailsLevel details_level) {
     return Host::serialize(obj, details_level);
   };
-  virtual char *getSerializationKey(char *buf, uint bufsize);
+  virtual char *getSerializationKey(char *buf, u_int bufsize, bool short_format = false);
   char *getRedisKey(char *buf, uint buf_len, bool skip_prefix = false);
 
   virtual void lua(lua_State *vm, AddressTree *ptree, bool host_details,
@@ -191,22 +191,63 @@ class LocalHost : public Host {
   inline void setContactedPort(bool isTCP, u_int16_t port,
                                ndpi_protocol *proto) {
     usedPorts.setContactedPort(isTCP, port, proto);
-  };  
+  };
   virtual inline void luaUsedPorts(lua_State *vm) { usedPorts.lua(vm, iface); };
-  virtual inline std::unordered_map<u_int16_t, ndpi_protocol> getUDPServerPorts() { return(usedPorts.getUDPServerPorts()); };
-  virtual inline std::unordered_map<u_int16_t, ndpi_protocol> getTCPServerPorts() { return(usedPorts.getTCPServerPorts()); };
+  virtual inline std::unordered_map<u_int16_t, ndpi_protocol>* getUDPServerPorts() { return(usedPorts.getUDPServerPorts()); };
+  virtual inline std::unordered_map<u_int16_t, ndpi_protocol>* getTCPServerPorts() { return(usedPorts.getTCPServerPorts()); };
 
-  virtual inline std::unordered_map<u_int16_t, ndpi_protocol> *getServerPorts(
-      bool isTCP) {
+  virtual inline std::unordered_map<u_int16_t, ndpi_protocol>* getServerPorts(bool isTCP) {
     return (usedPorts.getServerPorts(isTCP));
   };
 
-  inline Fingerprint *getJA4Fingerprint()   { return (fingerprints ? &fingerprints->ja4  : NULL); }
-  inline Fingerprint *getHASSHFingerprint() { return (fingerprints ? &fingerprints->hassh: NULL); }
+  void periodic_stats_update(const struct timeval *tv);
+  void checkGatewayInfo();
+  inline Fingerprint* getJA4Fingerprint()   { return (fingerprints ? &fingerprints->ja4  : NULL); }
+  inline Fingerprint* getHASSHFingerprint() { return (fingerprints ? &fingerprints->hassh: NULL); }
   void lua_get_fingerprints(lua_State *vm);
 
   SPSCQueue<std::pair<u_int16_t, u_int16_t>> *getContactedServerPorts() { return (&contacted_server_ports);};
 
+  void setDhcpServer();
+  void setDnsServer();
+  void setSmtpServer();
+  void setNtpServer();
+  void setImapServer();
+  void setPopServer();
+  void setHttpServer();
+  void setSshServer();
+  void setRdpServer();
+  
+  void offlineSetMDNSInfo(char *const s);
+  void offlineSetMDNSName(const char *n);
+  void offlineSetDHCPName(const char *n);
+  void offlineSetDhcpFingerprint(const char *fingerprint);
+  void offlineSetMDNSTXTName(const char *n);
+  void offlineSetNetbiosName(const char *n);
+  void offlineSetTLSName(const char *n);
+  void offlineSetHTTPName(const char *n);
+  void setServerName(const char *n);
+  void setResolvedName(const char *resolved_name);
+
+  virtual bool setOS(ndpi_os _os, OSLearningMode mode);
+  void setTCPfingerprint(char *tcp_fingerprint, ndpi_os os);
+
+  virtual inline void setAssetUpdated() { asset_map_updated = 1; }
+  void setMACmeaningful();
+  inline bool isAssetUpdated() {
+    return(asset_map_updated || (mac && mac->isAssetUpdated()));
+  }
+
+#ifdef NTOPNG_PRO
+  void loadAssetInfo();
+  void dumpAssetInfo();
+  bool addDataToAssets(char *field, char *value);
+  bool removeDataFromAssets(char *field);
+  void dumpAssetJson(ndpi_serializer *serializer);
+  void dumpAssetPortsJson(ndpi_serializer *serializer);
+#endif
+
+  void setDeviceType(DeviceType devtype);
 };
 
 #endif /* _LOCAL_HOST_H_ */
