@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -40,14 +40,12 @@ class AutonomousSystem;
 class AutonomousSystemHash;
 class ObservationPoint;
 class ObservationPointHash;
-class OperatingSystem;
 class OperatingSystemHash;
 class Country;
 class CountriesHash;
 class DB;
 class Paginator;
 class NetworkInterfaceTsPoint;
-class ViewInterface;
 class FlowAlert;
 class HostAlert;
 class FlowChecksLoader;
@@ -57,6 +55,7 @@ class HostChecksLoader;
 class HostChecksExecutor;
 
 #ifdef NTOPNG_PRO
+class ViewInterface;
 class L7Policer;
 class FlowInterfacesStats;
 class TrafficShaper;
@@ -85,6 +84,7 @@ protected:
     num_alerts_engaged_error[ALERT_ENTITY_MAX_NUM_ENTITIES],
     num_alerts_engaged_critical[ALERT_ENTITY_MAX_NUM_ENTITIES],
     num_alerts_engaged_emergency[ALERT_ENTITY_MAX_NUM_ENTITIES], flow_serial;
+  std::atomic<u_int64_t> alert_serial;
   /* Counters for active alerts. Changed by multiple concurrent threads */
   std::atomic<u_int64_t>
   num_active_alerted_flows_notice; /* Counts all flow alerts with severity
@@ -109,6 +109,10 @@ protected:
 #if defined(NTOPNG_PRO)
   PeriodicityMap *pMap;
   ServiceMap *sMap;
+  ACLFlow *acl_flow;
+#endif
+#ifdef NTOPNG_PRO
+  QoEStats qoe_stats;
 #endif
 
   UsedPorts usedPorts;
@@ -130,7 +134,6 @@ protected:
   BehaviorAnalysis *score_behavior, *traffic_tx_behavior, *traffic_rx_behavior;
 #endif
   MostVisitedList *top_sites;
-  MostVisitedList *top_os;
 
   /* Flows queues waiting to be dumped */
   SPSCQueue<Flow *> *idleFlowsToDump, *activeFlowsToDump;
@@ -164,7 +167,9 @@ protected:
   RoundTripStats *download_stats, *upload_stats;
 
   bool is_view; /* Whether this is a view interface */
+#ifdef NTOPNG_PRO
   ViewInterface *viewed_by; /* Whether this interface is 'viewed' by a ViewInterface */
+#endif
   u_int8_t viewed_interface_id; /* When this is a 'viewed' interface, this id
                                    represents a unique interface identifier
                                    inside the view */
@@ -188,7 +193,7 @@ protected:
   u_int16_t next_compq_remove_idx;
   ParsedFlow **companionQueue;
   bool ip_reassignment_alerts_enabled;
-
+  
   /* Live Capture */
   Mutex active_captures_lock;
   u_int8_t num_live_captures;
@@ -275,7 +280,7 @@ protected:
   L4Stats l4Stats;
   SyslogStats syslogStats;
   FlowHash *flows_hash; /**< Hash used to store flows information. */
-  u_int32_t last_remote_pps, last_remote_bps;
+  u_int32_t last_remote_pps, last_remote_bps, last_remote_update;
   TimeseriesExporter *influxdb_ts_exporter, *rrd_ts_exporter;
 
   TcpFlowStats tcpFlowStats;
@@ -296,9 +301,6 @@ protected:
   u_int16_t last_obs_point_id;
   ObservationPointHash *obs_hash; /**< Hash used to store Observation Point information. */
 
-  /* Operating Systems */
-  OperatingSystemHash *oses_hash; /**< Hash used to store Operating Systems information. */
-
   /* Countries */
   CountriesHash *countries_hash;
 
@@ -342,8 +344,8 @@ protected:
                 struct flowHostRetriever *retriever, u_int8_t bridge_iface_idx,
                 AddressTree *allowed_hosts, bool host_details,
                 LocationPolicy location, char *countryFilter, char *mac_filter,
-                u_int16_t vlan_id, OSType osFilter, u_int32_t asnFilter,
-                int16_t networkFilter, u_int16_t pool_filter,
+                u_int16_t vlan_id, ndpi_os osFilter, u_int32_t asnFilter,
+                int32_t networkFilter, u_int16_t pool_filter,
                 bool filtered_hosts, bool blacklisted_hosts, bool anomalousOnly,
                 bool dhcpOnly, const AddressTree *const cidr_filter,
                 u_int8_t ipver_filter, int proto_filter,
@@ -351,7 +353,6 @@ protected:
                 char *sortColumn);
   int sortASes(struct flowHostRetriever *retriever, char *sortColumn);
   int sortObsPoints(struct flowHostRetriever *retriever, char *sortColumn);
-  int sortOSes(struct flowHostRetriever *retriever, char *sortColumn);
   int sortCountries(struct flowHostRetriever *retriever, char *sortColumn);
   int sortVLANs(struct flowHostRetriever *retriever, char *sortColumn);
   int sortMacs(u_int32_t *begin_slot, bool walk_all,
@@ -380,6 +381,7 @@ protected:
   void pollQueuedeCompanionEvents();
   bool getInterfaceBooleanPref(const char *pref_key,
                                bool default_pref_value) const;
+  void setCustomName(char *alias, bool set_on_empty);
   virtual void incEthStats(bool ingressPacket, u_int16_t proto,
                            u_int32_t num_pkts, u_int32_t num_bytes,
                            u_int pkt_overhead) {
@@ -414,7 +416,8 @@ protected:
                      u_int32_t size, u_int *num, bool set_resp);
   void build_protocol_flow_stats_lua_rsp(lua_State *vm, AggregatedFlowsStats *fs,
                                          u_int32_t size, u_int *num);
-
+  bool dumpFlowOut(DB *dumper, time_t when, Flow *f);
+  
 public:
   /**
    * @brief A Constructor
@@ -433,7 +436,6 @@ public:
   bool initFlowDump(u_int8_t num_dump_interfaces);
   u_int32_t getASesHashSize();
   u_int32_t getObsHashSize();
-  u_int32_t getOSesHashSize();
   u_int32_t getCountriesHashSize();
   u_int32_t getVLANsHashSize();
   u_int32_t getMacsHashSize();
@@ -452,7 +454,6 @@ public:
 
   void checkDisaggregationMode();
   void incrVisitedWebSite(char *hostname);
-  void incrOS(char *hostname);
   inline void incScoreValue(u_int16_t score_incr, bool as_client) {
     as_client ? score_as_cli += score_incr : score_as_srv += score_incr;
   };
@@ -473,6 +474,7 @@ public:
   virtual void startPacketPolling();
   virtual void startFlowDumping();
   virtual bool isLoading() { return false; };
+  virtual bool isEnabled() { return true; };
   virtual void shutdown();
   virtual void cleanup();
   virtual char *getEndpoint(u_int8_t id) { return NULL; };
@@ -533,7 +535,7 @@ public:
     return (ndpi_get_proto_name(get_ndpi_struct(), id));
   };
   inline u_int16_t get_ndpi_proto_id(char *proto) {
-    u_int16_t _proto = ndpi_get_protocol_id(get_ndpi_struct(), proto);
+    u_int16_t _proto = ndpi_get_proto_by_name(get_ndpi_struct(), proto);
     return ndpi_map_ndpi_id_to_user_proto_id(get_ndpi_struct(), _proto);
   };
   inline int get_ndpi_category_id(char *cat) {
@@ -761,6 +763,35 @@ public:
   };
   void updateFlowPeriodicity(Flow *f);
   void updateServiceMap(Flow *f);
+
+  /* Access Control List */
+  inline bool insertIPACL(u_int8_t protocol, char *src, char *dst, char* port, u_int16_t l7_proto, bool is_allowed) {
+    if (acl_flow) return acl_flow->insertIPACL(protocol, src, dst, port, l7_proto, is_allowed);
+    return false;
+  }
+  inline bool removeIPACL(u_int8_t protocol, char *src, char *dst, char* port, u_int16_t l7_proto) {
+    if (acl_flow) return acl_flow->removeIPACL(protocol, src, dst, port, l7_proto);
+    return false;
+  }
+  inline bool insertMacACL(u_int8_t *mac, bool is_allowed) {
+    if (acl_flow) return acl_flow->insertMacACL(mac, is_allowed);
+    return false;
+  }
+  inline bool removeMacACL(u_int8_t *mac) {
+    if (acl_flow) return acl_flow->removeMacACL(mac);
+    return false;
+  }
+  inline bool findFlowACL(Flow *f, bool *is_allowed) {
+    if (acl_flow) return acl_flow->findFlowACL(f, is_allowed);
+    return false;
+  }
+  inline bool findMacACL(u_int8_t* mac, bool *is_allowed) {
+    if (acl_flow) return acl_flow->findMacACL(mac, is_allowed);
+    return false;
+  }
+  inline void getACLInfo(lua_State *vm) {
+    if (acl_flow) acl_flow->lua(vm);
+  }
 #endif
   void lua_hash_tables_stats(lua_State *vm);
   void lua_periodic_activities_stats(lua_State *vm);
@@ -772,15 +803,14 @@ public:
 			 lua_State *vm, u_int32_t *begin_slot, bool walk_all,
 			 u_int8_t bridge_iface_idx, AddressTree *allowed_hosts, bool host_details,
 			 LocationPolicy location, char *countryFilter, char *mac_filter,
-			 u_int16_t vlan_id, OSType osFilter, u_int32_t asnFilter,
-			 int16_t networkFilter, u_int16_t pool_filter, bool filtered_hosts,
+			 u_int16_t vlan_id, ndpi_os osFilter, u_int32_t asnFilter,
+			 int32_t networkFilter, u_int16_t pool_filter, bool filtered_hosts,
 			 bool blacklisted_hosts, u_int8_t ipver_filter, int proto_filter,
 			 TrafficType traffic_type_filter, u_int32_t device_ip, bool tsLua,
 			 bool anomalousOnly, bool dhcpOnly, const AddressTree *const cidr_filter,
 			 char *sortColumn, u_int32_t maxHits, u_int32_t toSkip, bool a2zSortOrder, bool useArrayFormat);
   int getActiveASList(lua_State *vm, const Paginator *p, bool diff = false);
   int getActiveObsPointsList(lua_State *vm, const Paginator *p);
-  int getActiveOSList(lua_State *vm, const Paginator *p);
   int getActiveCountriesList(lua_State *vm, const Paginator *p);
   int getActiveVLANList(lua_State *vm, char *sortColumn, u_int32_t maxHits,
                         u_int32_t toSkip, bool a2zSortOrder,
@@ -801,10 +831,10 @@ public:
                            const char *manufacturer, u_int8_t location_filter);
   int getMacsIpAddresses(lua_State *vm, int idx);
   void getFlowsStats(lua_State *vm);
-  void getNetworkStats(lua_State *vm, u_int16_t network_id,
-                       AddressTree *allowed_hosts, bool diff = false) const;
+  void getNetworkStats(lua_State *vm, u_int32_t network_id,
+                       AddressTree *allowed_hosts, bool diff = false, bool fullStats = false) const;
   void getNetworksStats(lua_State *vm, AddressTree *allowed_hosts,
-                        bool diff = false) const;
+                        bool diff = false, bool fullStats = false) const;
   int getFlows(lua_State *vm, u_int32_t *begin_slot, bool walk_all,
                AddressTree *allowed_hosts, Host *host, Host *talking_with_host,
                Host *client, Host *server, char *flow_info, Paginator *p);
@@ -861,8 +891,6 @@ public:
                                 bool is_inline_call);
   bool deleteObsPoint(u_int16_t obs_point);
   bool prepareDeleteObsPoint(u_int16_t obs_point);
-  OperatingSystem *getOS(OSType os, bool create_if_not_present,
-                         bool is_inline_call);
   Country *getCountry(const char *country_name, bool create_if_not_present,
                       bool is_inline_call);
   virtual Mac *getMac(u_int8_t _mac[6], bool create_if_not_present,
@@ -871,6 +899,7 @@ public:
                         u_int16_t observationPointId, bool is_inline_call);
   virtual Host *getHostByIP(IpAddress *ip, u_int16_t vlan_id,
                             u_int16_t observationPointId, bool is_inline_call);
+  bool isHostActive(AddressTree *allowed_hosts, char *host_ip, u_int16_t vlan_id);
   bool getHostInfo(lua_State *vm, AddressTree *allowed_hosts, char *host_ip,
                    u_int16_t vlan_id);
   void findPidFlows(lua_State *vm, u_int32_t pid);
@@ -899,6 +928,16 @@ public:
   inline void reloadHostPools() {
     if (host_pools) host_pools->reloadPools();
   }
+  inline u_int16_t getNumberHostPools() {
+    if (host_pools) 
+      return host_pools->getCurrentHostPoolsNumber();
+    return 0;
+  }
+  inline u_int32_t getNumberHostPoolsMembers() {
+    if (host_pools) 
+      return host_pools->getCurrentMaxHostPoolsMembers();
+    return 0;
+  }
 
   bool registerLiveCapture(NtopngLuaContext *const luactx, int *id);
   bool deregisterLiveCapture(NtopngLuaContext *const luactx);
@@ -959,7 +998,7 @@ public:
   int exec_csv_query(const char *sql, bool dump_in_json_format,
                      struct mg_connection *conn);
 
-  NetworkStats *getNetworkStats(u_int16_t networkId) const;
+  NetworkStats *getNetworkStats(u_int32_t networkId) const;
   void allocateStructures(bool disable_dump = false);
   void getsDPIStats(lua_State *vm);
   inline bool isDbCreated() { return (db ? db->isDbCreated() : true); };
@@ -1037,9 +1076,11 @@ public:
   virtual bool areTrafficDirectionsSupported() { return (true); };
 
   inline bool isView() const { return is_view; };
+#ifdef NTOPNG_PRO
   inline ViewInterface *viewedBy() const { return viewed_by; };
   inline u_int8_t getViewedId() const { return viewed_interface_id; };
   inline bool isViewed() const { return viewedBy() != NULL; };
+
   /*
     Method called by a view interface on all its viewed interfaces.
     The view passes to this method both its pointer and the viewed interface id,
@@ -1051,17 +1092,20 @@ public:
     viewed_by = view_iface;
     viewed_interface_id = _viewed_interface_id;
   };
-
+#else
+  inline bool isViewed() const { return(false); }
+#endif
+  
+  bool isMacActive(char *mac);
   bool getMacInfo(lua_State *vm, char *mac);
   bool resetMacStats(lua_State *vm, char *mac, bool delete_data);
   bool setMacDeviceType(char *strmac, DeviceType dtype, bool alwaysOverwrite);
   bool getASInfo(lua_State *vm, u_int32_t asn);
   bool getObsPointInfo(lua_State *vm, u_int16_t obs_point);
-  bool getOSInfo(lua_State *vm, OSType os_type);
   bool getCountryInfo(lua_State *vm, const char *country);
   bool getVLANInfo(lua_State *vm, u_int16_t vlan_id);
-  void incNumHosts(bool local, bool rxOnlyHost);
-  void decNumHosts(bool local, bool rxOnlyHost);
+  void incNumHosts(Host *host, bool rxOnlyHost);
+  void decNumHosts(Host *host, bool rxOnlyHost);
   inline void incNumL2Devices() { numL2Devices++; }
   inline void decNumL2Devices() { numL2Devices--; }
   inline u_int32_t getScalingFactor() const { return (scalingFactor); }
@@ -1200,7 +1244,7 @@ public:
   u_int32_t getNumEngagedAlerts(AlertLevelGroup alert_level_group) const;
   void luaNumEngagedAlerts(lua_State *vm) const;
   int walkActiveHosts(lua_State *vm, HostWalkMode mode, u_int32_t maxHits,
-                      int16_t networkIdFilter, bool localHostsOnly,
+                      int32_t networkIdFilter, bool localHostsOnly,
                       bool treeMapMode);
   virtual void
   flowAlertsDequeueLoop(); /* Body of the loop that dequeues flows for the
@@ -1267,7 +1311,6 @@ public:
                                ndpi_protocol_category_t protoCategory);
   bool nDPILoadIPCategory(char *what, u_int16_t id, char *list_name);
   bool nDPILoadHostnameCategory(char *what, u_int16_t id, char *list_name);
-  int nDPILoadMaliciousJA3Signatures(const char *file_path);
   int setDomainMask(const char *domain, u_int64_t domain_mask);
   int addTrustedIssuerDN(const char *dn);
   inline void setLastInterfacenDPIReload(time_t now) { last_ndpi_reload = now; }
@@ -1277,6 +1320,7 @@ public:
   }
   u_int16_t getnDPIProtoByName(const char *name);
   inline u_int32_t getNewFlowSerial() { return (flow_serial++); }
+  inline u_int64_t getNewAlertSerial() { return alert_serial.fetch_add(1, std::memory_order_relaxed); }
   bool resetHostTopSites(AddressTree *allowed_hosts, char *host_ip,
                          u_int16_t vlan_id, u_int16_t observationPointId);
   void localHostsServerPorts(lua_State *vm);
@@ -1348,12 +1392,23 @@ public:
                                                    bool *matched);
   static bool compute_info_flow_stats(GenericHashEntry *node, void *user_data,
                                       bool *matched);
+
+#ifndef HAVE_NEDGE
+  inline u_int8_t getNumProfiles() { return (flow_profiles) ? flow_profiles->getNumProfiles() : 0; }
+#endif
 #endif
   void getActiveMacs(lua_State *vm);
 
   void incnDPIStats(time_t when, u_int16_t ndpi_proto,
 		    ndpi_protocol_category_t ndpi_category,
-		    u_int32_t bytes_len, u_int32_t num_pkts);
+		    u_int32_t bytes_sent, u_int32_t bytes_rcvd, 
+        u_int32_t pkts_sent, u_int32_t pkts_rcvd);
+#ifdef NTOPNG_PRO
+  void incQoEStats(QoEType qoe_type) { qoe_stats.incQoEStats(qoe_type); };
+#endif
+  inline BroadcastDomains* getBroadcastDomains() { return(bcast_domains); }
+
+  void resetBroacastDomains();
 };
 
 #endif /* _NETWORK_INTERFACE_H_ */
