@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2015-24 - ntop.org
+ * (C) 2015-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,7 @@ class NetworkStats : public InterfaceMemberAlertableEntity,
                      public GenericTrafficElement,
                      public Score {
  private:
-  u_int16_t network_id;
+  u_int32_t network_id;
   u_int32_t numHosts;
   u_int32_t alerted_flows_as_client, alerted_flows_as_server;
   TrafficStats ingress, ingress_broadcast; /* outside -> network */
@@ -43,6 +43,7 @@ class NetworkStats : public InterfaceMemberAlertableEntity,
   u_int32_t round_trip_time;
 
 #if defined(NTOPNG_PRO)
+  QoEStats qoe_stats;
   InOutTraffic *network_matrix;
   time_t nextMinPeriodicUpdate;
 #endif
@@ -61,7 +62,7 @@ class NetworkStats : public InterfaceMemberAlertableEntity,
 #endif
 
  public:
-  NetworkStats(NetworkInterface *iface, u_int16_t _network_id);
+  NetworkStats(NetworkInterface *iface, u_int32_t _network_id);
   virtual ~NetworkStats();
 
   inline bool trafficSeen() {
@@ -108,7 +109,7 @@ class NetworkStats : public InterfaceMemberAlertableEntity,
   };
 
 #ifdef NTOPNG_PRO
-  void incTrafficBetweenNets(u_int16_t net_id, u_int32_t bytes_sent,
+  void incTrafficBetweenNets(u_int32_t net_id, u_int32_t bytes_sent,
                              u_int32_t bytes_rcvd);
   void resetTrafficBetweenNets();
 #endif
@@ -131,7 +132,7 @@ class NetworkStats : public InterfaceMemberAlertableEntity,
 
   void setNetworkId(u_int8_t id);
   bool match(AddressTree *tree);
-  void lua(lua_State *vm, bool diff = false);
+  void lua(lua_State *vm, bool diff = false, bool fullStats = true);
   bool serialize(json_object *my_object);
   void housekeepAlerts(ScriptPeriodicity p);
 
@@ -141,6 +142,9 @@ class NetworkStats : public InterfaceMemberAlertableEntity,
   void updateSynAckAlertsCounter(time_t when, bool synack_sent);
   void updateRoundTripTime(u_int32_t rtt_msecs);
   void incNumFlows(time_t t, bool as_client);
+#ifdef NTOPNG_PRO
+  void incQoEStats(QoEType qoe_type) { qoe_stats.incQoEStats(qoe_type); };
+#endif
 };
 
 #endif /* _NETWORK_STATS_H_ */
