@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -45,6 +45,7 @@ class Ntop {
   bool hostPoolsReloadInProgress;
   bool interfacesShuttedDown;
   bool offline, forced_offline;
+  bool broadcast_ip_disabled;
   Bloom *resolvedHostsBloom; /* Used by all redis class instances */
   JobQueue jobsQueue;
   AddressTree local_interface_addresses;
@@ -111,7 +112,6 @@ class Ntop {
   std::atomic<u_int32_t> num_flow_exporters;
   std::atomic<u_int32_t> num_flow_interfaces;
 #ifdef NTOPNG_PRO
-  AssetManagement am;
 #ifdef HAVE_KAFKA
   KafkaClient kafkaClient;
 #endif
@@ -129,6 +129,9 @@ class Ntop {
   char *local_network_aliases[CONST_MAX_NUM_NETWORKS];
   AddressTree local_network_tree, cloud_local_network_tree;
 
+  /* Local Autonomous Systems */
+  std::map<u_int32_t, bool> local_asn;
+
   /* Alerts */
   FlowAlertsLoader flow_alerts_loader;
 
@@ -150,13 +153,14 @@ class Ntop {
 #ifndef WIN32
   ContinuousPing *cping;
   Ping *default_ping;
+  bool ping_initialized;
   std::map<std::string /* ifname */, Ping *> ping;
 #endif
 
   /* For local network */
-  inline int16_t localNetworkLookup(int family, void *addr,
+  inline int32_t localNetworkLookup(int family, void *addr,
                                     u_int8_t *network_mask_bits = NULL);
-  inline int16_t cloudNetworkLookup(int family, void *addr,
+  inline int32_t cloudNetworkLookup(int family, void *addr,
                                     u_int8_t *network_mask_bits = NULL);
   bool addLocalNetwork(char *_net);
 
@@ -170,7 +174,7 @@ class Ntop {
   bool checkLDAPAuth(const char *user, const char *password, char *group) const;
   bool checkRadiusAuth(const char *user, const char *password, char *group) const;
   bool checkUserPassword(const char *user, const char *password, char *group,
-                         bool *localuser) const;
+                         bool *localuser, bool *redirect_to_change_pwd) const;
 
   void checkReloadFlowChecks();
   void checkReloadHostChecks();
@@ -232,7 +236,7 @@ class Ntop {
    *
    * @return The path of custom nDPI protocols file.
    */
-  inline char *getCustomnDPIProtos() { return (custom_ndpi_protos); };
+  char *getCustomnDPIProtos();
   /**
    * @brief Get the offset time.
    * @details ....
@@ -285,6 +289,7 @@ class Ntop {
    * 131.114.21.0/24,10.0.0.0/255.0.0.0 .
    */
   void setLocalNetworks(char *nets);
+
   /**
    * @brief Check if the ingress parameter is in the local networks.
    * @details Inline method.
@@ -295,13 +300,20 @@ class Ntop {
    * @param network_mask_bits It returns the number of bits of the network mask
    * @return True if the address is in the local networks, false otherwise.
    */
-  bool isLocalAddress(int family, void *addr, int16_t *network_id,
+  bool isLocalAddress(int family, void *addr, int32_t *network_id,
                       u_int8_t *network_mask_bits = NULL);
 
+  /**
+   * @brief Return true is broadcast addresses are disabled (point-to-point).
+   */
+  bool isBroadcastIPDisabled() { return broadcast_ip_disabled; };
+  void disableBroadcastIP() { broadcast_ip_disabled = true; };
+
   /**
    * @brief Start ntopng packet processing.
    */
   void start();
+
   /**
    * @brief Resolve the host name.
    * @details Use the redis database to resolve the IP address and get the host
@@ -477,6 +489,7 @@ class Ntop {
 
   inline Prefs *getPrefs() { return (prefs); };
   void initPing();
+  inline bool isPingInitialized() { return (ping_initialized);};
 #ifndef WIN32
   void lockNtopInstance();
 #endif
@@ -488,7 +501,7 @@ class Ntop {
   void setScriptsDir();
   void lua_periodic_activities_stats(NetworkInterface *iface, lua_State *vm);
   void getUsers(lua_State *vm);
-  bool getLocalNetworkAlias(lua_State *vm, u_int16_t network_id);
+  bool getLocalNetworkAlias(lua_State *vm, u_int32_t network_id);
   bool isUserAdministrator(lua_State *vm);
   void getAllowedInterface(lua_State *vm);
   void getAllowedNetworks(lua_State *vm);
@@ -503,7 +516,7 @@ class Ntop {
                                 char *group) const;
   bool checkGuiUserPassword(struct mg_connection *conn, const char *user,
                             const char *password, char *group,
-                            bool *localuser) const;
+                            bool *localuser, bool *redirect_to_change_pwd) const;
   bool isBlacklistedLogin(struct mg_connection *conn) const;
   bool checkUserInterfaces(const char *user) const;
   bool resetUserPassword(char *username, char *old_password,
@@ -523,6 +536,7 @@ class Ntop {
       u_int32_t ttl = 0 /* Forever */) const;
   bool changeUserAlertsPermission(const char *username, bool allow_alerts,
                                   u_int32_t ttl = 0 /* Forever */) const;
+  void resetUserPermissions(const char *user) const;
   bool hasCapability(lua_State *vm, UserCapabilities capability);
   bool getUserCapabilities(const char *username, bool *allow_pcap_download,
                            bool *allow_historical_flows,
@@ -554,7 +568,7 @@ class Ntop {
     return (local_interface_addresses.findAddress(family, addr) == -1 ? false
                                                                       : true);
   };
-  void getLocalNetworkIp(int16_t local_network_id, IpAddress **network_ip,
+  void getLocalNetworkIp(int32_t local_network_id, IpAddress **network_ip,
                          u_int8_t *network_prefix);
   void addLocalNetworkList(const char *network);
   void createExportInterface();
@@ -618,8 +632,7 @@ class Ntop {
   DeviceProtocolBitmask *getDeviceAllowedProtocols(DeviceType t) {
     return (&deviceProtocolPresets[t]);
   }
-  void refreshAllowedProtocolPresets(DeviceType t, bool client, lua_State *L,
-                                     int index);
+  void refreshAllowedProtocolPresets(DeviceType t, bool client, lua_State *L, int index);
   DeviceProtoStatus getDeviceAllowedProtocolStatus(DeviceType dev_type,
                                                    ndpi_protocol proto,
                                                    u_int16_t pool_id,
@@ -638,6 +651,7 @@ class Ntop {
   AlertFifoItem *recipient_dequeue(u_int16_t recipient_id);
   void recipient_stats(u_int16_t recipient_id, lua_State *vm);
   time_t recipient_last_use(u_int16_t recipient_id);
+  void inc_recipient_stats(u_int16_t recipient_id, u_int64_t delivered, u_int64_t filtered_out, u_int64_t delivery_failures);
   void recipient_delete(u_int16_t recipient_id);
   void recipient_register(u_int16_t recipient_id, AlertLevel minimum_severity,
                           Bitmap128 enabled_categories,
@@ -703,17 +717,19 @@ class Ntop {
     return getUserPasswordHashLocal(user, val, sizeof(val));
   }
 
+  u_int32_t getMaxNumLocalNetworks();
+
   /* Local network address list methods */
-  inline u_int16_t getNumLocalNetworks() {
+  inline u_int32_t getNumLocalNetworks() {
     return local_network_tree.getNumAddresses();
   };
-  inline const char *getLocalNetworkName(int16_t local_network_id) {
-    return (((u_int16_t)local_network_id < local_network_tree.getNumAddresses())
-                ? local_network_names[(u_int16_t)local_network_id]
+  inline const char *getLocalNetworkName(int32_t local_network_id) {
+    return (((u_int32_t)local_network_id < local_network_tree.getNumAddresses())
+                ? local_network_names[(u_int32_t)local_network_id]
                 : NULL);
   };
 
-  u_int16_t getLocalNetworkId(const char *network_name);
+  u_int32_t getLocalNetworkId(const char *network_name);
 
   void addLocalCloudAddress(char *str) { cloud_local_network_tree.addAddress(str); }
   
@@ -773,7 +789,6 @@ class Ntop {
                           char *list_name);
   bool nDPILoadHostnameCategory(char *what, ndpi_protocol_category_t id,
                                 char *list_name);
-  int nDPILoadMaliciousJA3Signatures(const char *file_path);
   int nDPISetDomainMask(const char *domain, u_int64_t domain_mask);
   void setLastInterfacenDPIReload(time_t now);
   bool needsnDPICleanup();
@@ -800,9 +815,6 @@ class Ntop {
   inline ClickHouseImport *getClickHouseImport() { return (clickhouseImport); }
 #endif
   inline char *getTZname() { return (myTZname); }
-#ifdef NTOPNG_PRO
-  inline AssetManagement *get_am() { return (&am); }
-#endif
   inline Mutex *get_pools_lock()      { return (&pools_lock); };
   inline u_int32_t get_current_time() { return(current_time); };
 
@@ -829,6 +841,14 @@ class Ntop {
   void initSNMPTrapCollector();
   void toggleSNMPTrapCollector(bool enable);
 #endif
+  u_int16_t getNumberHostPools();
+  u_int32_t getNumberHostPoolsMembers();
+  u_int8_t getNumberProfiles();
+  bool isInLocalASN(IpAddress *ip);
+
+  void trackAssetChange(const char *protocol, const char *action,
+			Mac *mac, IpAddress *target_ip,
+			Host *target, Flow *flow, char *note);
 };
 
 extern Ntop *ntop;
