@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -30,14 +30,14 @@ class Paginator {
   bool a2z_sort_order;
   bool detailed_results /* deprecated, use DetailsLevel instead */;
   char *sort_column, *country_filter, *host_filter, *client_filter,
-      *server_filter;
+      *server_filter, *wlan_ssid_filter;
   char *container_filter, *pod_filter;
   char *traffic_profile_filter;
   char *username_filter, *pidname_filter;
   int l7proto_filter_master_proto, l7proto_filter_app_proto;
   int l7category_filter;
   u_int16_t port_filter;
-  int16_t local_network_filter;
+  int32_t local_network_filter;
   u_int16_t vlan_id_filter;
   u_int8_t ip_version /* Either 4 or 6 */;
   u_int8_t l4_protocol;
@@ -55,7 +55,9 @@ class Paginator {
   LocationPolicy client_mode;
   LocationPolicy server_mode;
   TcpFlowStateFilter tcp_flow_state_filter;
-
+#ifdef NTOPNG_PRO
+  u_int8_t qoe_filter;
+#endif
  public:
   Paginator();
   virtual ~Paginator();
@@ -85,6 +87,14 @@ class Paginator {
     return false;
   }
 
+  inline bool wlanSSIDFilter(char **f) const {
+    if (wlan_ssid_filter) {
+      (*f) = wlan_ssid_filter;
+      return true;
+    }
+    return false;
+  }
+
   inline bool hostFilter(char **f) const {
     if (host_filter) {
       (*f) = host_filter;
@@ -184,7 +194,7 @@ class Paginator {
     return false;
   }
 
-  inline bool localNetworkFilter(int16_t *f) const {
+  inline bool localNetworkFilter(int32_t *f) const {
     if (local_network_filter <= CONST_MAX_NUM_NETWORKS) {
       (*f) = local_network_filter;
       return true;
@@ -320,6 +330,15 @@ class Paginator {
     }
     return false;
   }
+#ifdef NTOPNG_PRO
+  inline bool QoEFilter(u_int8_t *f) const {
+    if (qoe_filter != (u_int8_t)-1) {
+      (*f) = qoe_filter;
+      return true;
+    }
+    return false;
+  }
+#endif
 
   inline bool unidirectionalTraffic(bool *f) const {
     if (unidirectional_traffic != -1) {
