@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,7 +31,7 @@ extern void usage();
 extern void nDPIusage();
 
 typedef struct {
-  char *name, *description;
+  char *name, *alias, *description;
   int id;
 } InterfaceInfo;
 
@@ -41,9 +41,10 @@ class Prefs {
  private:
   u_int8_t num_deferred_interfaces_to_register;
   pcap_direction_t captureDirection;
-  char **deferred_interfaces_to_register, *cli;
+  char **deferred_interfaces_to_register, *cli, *ciphers_list, *custom_geoip_dir;
   char *http_binding_address1, *http_binding_address2;
   char *https_binding_address1, *https_binding_address2;
+  char *http_index_page;
   bool enable_client_x509_auth, reproduce_at_original_speed, disable_purge;
   char* zmq_publish_events_url, *http_log_path;
   const char *clickhouse_client, *clickhouse_cluster_name;
@@ -52,7 +53,7 @@ class Prefs {
     sniff_local_name_responses, pcap_file_purge_hosts_flows,
     categorization_enabled, resolve_all_host_ip, change_user, daemonize,
     enable_auto_logout, enable_auto_logout_at_runtime, use_promiscuous_mode,
-    enable_ixia_timestamps, enable_vss_apcon_timestamps, 
+    enable_ixia_timestamps, full_stats_enabled,
     enable_interface_name_only, enable_users_login, disable_localhost_login,
     service_license_check, enable_sql_log, enable_access_log, log_to_file,
     enable_mac_ndpi_stats, enable_activities_debug, enable_behaviour_analysis,
@@ -64,7 +65,7 @@ class Prefs {
     tls_quic_hostnaming;
   u_int32_t behaviour_analysis_learning_period;
   u_int32_t iec60870_learning_period, modbus_learning_period,
-    devices_learning_period;
+    devices_learning_period, mac_address_cache_duration, enable_assets_collection;
   u_int32_t host_port_learning_period;
 #ifdef NTOPNG_PRO
   ndpi_bitmap* modbus_allowed_function_codes;
@@ -86,7 +87,8 @@ class Prefs {
   u_int32_t other_rrd_raw_days, other_rrd_1min_days, other_rrd_1h_days,
       other_rrd_1d_days;
   u_int32_t housekeeping_frequency;
-  bool disable_alerts, enable_top_talkers, enable_active_local_hosts_cache;
+  bool disable_alerts, enable_top_talkers, enable_sites_collection, 
+      enable_active_local_hosts_cache, enable_dns_cache;
   bool enable_flow_device_port_rrd_creation,
       enable_observation_points_rrd_creation,
       enable_intranet_traffic_rrd_creation;
@@ -100,9 +102,6 @@ class Prefs {
   bool enable_zmq_encryption;
   bool flow_table_time, flow_table_probe_order;
   bool enable_broadcast_domain_too_large;
-#ifdef NTOPNG_PRO
-  bool create_labels_logfile;
-#endif
   u_int32_t max_num_secs_before_delete_alert, alert_page_refresh_rate;
   int32_t max_entity_alerts;
   u_int32_t safe_search_dns_ip, global_primary_dns_ip, global_secondary_dns_ip;
@@ -186,6 +185,13 @@ class Prefs {
   bool appliance;
 #endif
 
+  ServerConfiguration *gateway, *dns_servers, *ntp_servers, *smtp_servers, *dhcp_servers;
+
+#ifdef NTOPNG_PRO
+  AddressTree *networks_policy_configuration;
+  AddressTree *networks_policy_configuration_shadow;
+#endif
+
 #ifdef HAVE_PF_RING
   int pfring_cluster_id;
 #endif
@@ -194,14 +200,16 @@ class Prefs {
   char* test_runtime_script_path;
   char* test_post_script_path;
 
-  char* message_broker_url;
-  char* message_broker;
+  char *message_broker_url, *message_broker;
+  bool message_broker_enabled;
 #ifdef NTOPNG_PRO
   bool print_maintenance, print_license;
+  char *lic_mgr_config_file;
 #endif
   bool print_version, print_version_json;
   bool snmp_polling;
-  bool active_monitoring;
+  bool active_monitoring, network_discovery, starttls;
+  bool dump_pcap_to_clickhouse; /* Dump pcap-interface flows to ClickHouse */
 
   InterfacesSet lan_interfaces, wan_interfaces;
 
@@ -232,6 +240,7 @@ class Prefs {
   bool is_enterprise_m_edition();
   bool is_enterprise_l_edition();
   bool is_enterprise_xl_edition();
+  bool is_enterprise_xxl_edition();
 
   bool is_edr_mode() { return false; /* TODO (used to be private Cloud mode) */ };
 
@@ -282,9 +291,6 @@ class Prefs {
   inline bool are_ixia_timestamps_enabled() {
     return (enable_ixia_timestamps);
   };
-  inline bool are_vss_apcon_timestamps_enabled() {
-    return (enable_vss_apcon_timestamps);
-  };
   inline char* get_user() { return (user); };
   inline void set_user(const char* u) {
     if (user) free(user);
@@ -341,6 +347,7 @@ class Prefs {
   void getDefaultStringPrefsValue(const char* pref_key, char** buffer,
                                   const char* default_value);
   char* get_if_name(int id);
+  char* get_if_alias(int id);
   char* get_if_descr(int id);
   inline const char* get_config_file_path() { return (config_file_path); };
   inline const char* get_ndpi_proto_file_path() { return (ndpi_proto_path); };
@@ -369,6 +376,9 @@ class Prefs {
   inline const char* get_message_broker() {
     return(message_broker);
   };
+  inline bool is_message_broker_enabled() {
+    return(message_broker_enabled);
+  };
   inline char* get_export_endpoint() { return (export_endpoint); };
   inline char* get_export_zmq_encryption_key() {
     return (export_zmq_encryption_key);
@@ -388,8 +398,11 @@ class Prefs {
   inline bool do_simulate_macs() { return (simulate_macs); };
   inline bool do_insecure_tls() { return (insecure_tls); };
   inline bool do_snmp_polling() { return (snmp_polling); };
-  inline bool do_active_monitoring(){ return (active_monitoring); };
+  bool do_active_monitoring();
+  inline bool get_active_monitoring_pref() { return (active_monitoring); };
   inline bool do_tls_quic_hostnaming() { return (tls_quic_hostnaming); };
+  inline bool email_starttls_enabled()          { return (starttls); };
+  inline bool dump_pcap_to_clickhouse_enabled() { return (dump_pcap_to_clickhouse); };
   inline char* get_cpu_affinity() { return (cpu_affinity); };
   inline char* get_other_cpu_affinity() { return (other_cpu_affinity); };
 #ifdef __linux__
@@ -556,8 +569,13 @@ class Prefs {
   inline u_int32_t get_pkt_ifaces_flow_max_idle() {
     return (pkt_ifaces_flow_max_idle);
   };
-  inline bool are_top_talkers_enabled() { return (enable_top_talkers); };
-  inline bool flow_table_duration_or_last_seen() { return (flow_table_time); };
+  inline char *getHttpIndexPage() {
+    return http_index_page;
+  };
+  inline bool are_top_talkers_enabled()            { return (enable_top_talkers);      };
+  inline bool are_sites_collection_enabled()       { return (enable_sites_collection); };
+  inline bool is_dns_cache_enabled()               { return (enable_dns_cache);        };
+  inline bool flow_table_duration_or_last_seen()   { return (flow_table_time);         };
   inline bool is_active_local_host_cache_enabled() {
     return (enable_active_local_hosts_cache);
   };
@@ -696,6 +714,8 @@ class Prefs {
   inline u_int        getModbusTooManyExceptionsThreshold()        { return(modbus_too_many_exceptions); }
 #endif
   inline u_int32_t devicesLearingPeriod() { return (devices_learning_period); };
+  inline u_int32_t macAddressCacheDuration() { return (mac_address_cache_duration); };
+  inline bool isAssetsCollectionEnabled() { return (enable_assets_collection); };
   inline u_int32_t hostPortLearningPeriod() { return (host_port_learning_period); };
   inline bool are_alerts_disabled() { return (disable_alerts); };
   inline bool dontEmitFlowAlerts() {
@@ -713,7 +733,6 @@ class Prefs {
     return (clickhouse_cluster_name);
   };
 #ifdef NTOPNG_PRO
-  inline bool isLabelDumpEnabled() { return (create_labels_logfile); };
   void setModbusAllowedFunctionCodes(const char *function_codes);
 #endif
   void setIEC104AllowedTypeIDs(const char* type_ids);
@@ -723,14 +742,41 @@ class Prefs {
   char* getKafkaTopic() { return (kafka_topic); }
   char* getKafkaOptions() { return (kafka_options); }
 #endif
+  void reloadServersConfiguration();
+#ifdef NTOPNG_PRO
+  bool reloadNetworksPolicyConfiguration();
+  bool loadPolicyConfiguration(AddressTree *tree, char *key, NetworkConfigurationId id);
+  AddressTree* getNetworksPolicyConfiguration();
+#endif
+  bool isGateway(IpAddress *ip, u_int16_t vlan_id);
+  bool isDNSServer(IpAddress *ip, u_int16_t vlan_id);
+  bool isNTPServer(IpAddress *ip, u_int16_t vlan_id);
+  bool isSMTPServer(IpAddress *ip, u_int16_t vlan_id);
+  bool isDHCPServer(IpAddress *ip, u_int16_t vlan_id);
+
+  ServerConfiguration* getConfiguredGateways()    { return(gateway);      }
+  ServerConfiguration* getConfiguredDNSServers()  { return(dns_servers);  }
+  ServerConfiguration* getConfiguredNTPServers()  { return(ntp_servers);  }
+  ServerConfiguration* getConfiguredSMTPServers() { return(smtp_servers); }
+  ServerConfiguration* getConfiguredDHCPServers() { return(dhcp_servers); }
+
   inline bool useMacAddressInFlowKey()     { return (use_mac_in_flow_key);  }
-  inline bool enableFingerprintStats()     { return (fingerprint_stats);    }
+  inline bool areFingerprintStatsEnabled() { return (fingerprint_stats);    }
   inline bool doReforgeTimestamps()        { return(do_reforge_timestamps); }
   inline void enableVLANCloudToExporters() { add_vlan_tags_to_cloud_exporters = true;  }
   inline bool addVLANCloudToExporters()    { return(add_vlan_tags_to_cloud_exporters); }
   inline bool collectBlackListStats()      { return(collect_blacklist_stats);          }
   inline bool limitResourcesUsage()        { return(limited_resources_mode);           }
   inline bool failOnInvalidLicense()       { return(fail_on_invalid_license);          }
+  inline char* getCiphersList()            { return(ciphers_list);                     }
+#ifdef NTOPNG_PRO
+  inline char* getLicMgrConfigFile()       { return(lic_mgr_config_file);              }
+  inline AddressTree* getNwPolicyConfig()  { return(networks_policy_configuration);    }
+#endif
+  inline char* getCustomGeoIPDir()         { return(custom_geoip_dir);                 }
+  void setCustomGeoIPDir(char *d);
+
+  inline bool fullStatsEnabled()           { return(full_stats_enabled);               }
 };
 
 #endif /* _PREFS_H_ */
