@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -32,7 +32,7 @@
 class SNMPSession {
  public:
   struct snmp_session session;
-  void *session_ptr;
+  decltype(snmp_sess_open(NULL)) session_ptr;
 
   SNMPSession();
   ~SNMPSession();
