@@ -34,7 +34,7 @@ class BlacklistedClientContactAlert : public FlowAlert {
   }
   static u_int8_t getDefaultScore() { return SCORE_LEVEL_WARNING; };
 
-  BlacklistedClientContactAlert(FlowCheck* c, Flow* f) : FlowAlert(c, f) {};
+  BlacklistedClientContactAlert(FlowCheck* c, Flow* f) : FlowAlert(c, f) {setAlertScore(getDefaultScore());};
   ~BlacklistedClientContactAlert(){};
 
   bool autoAck() const { return true; };
