@@ -36,12 +36,17 @@ class BlacklistedCountryAlert : public FlowAlert {
   }
   static u_int8_t getDefaultScore() { return SCORE_LEVEL_ERROR; };
 
+  inline bool get_is_server() { return is_server; };
+
   BlacklistedCountryAlert(FlowCheck* c, Flow* f, bool _is_server)
       : FlowAlert(c, f) {
     is_server = _is_server;
+    setAlertScore(getDefaultScore());
   };
   ~BlacklistedCountryAlert(){};
 
+  bool autoAck() const { return false; };
+
   FlowAlertType getAlertType() const { return getClassType(); }
 
   bool isServer() { return is_server; }
