@@ -31,7 +31,7 @@ class DataExfiltrationAlert : public FlowAlert {
   }
   static u_int8_t getDefaultScore() { return SCORE_LEVEL_ERROR; };
 
-  DataExfiltrationAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  DataExfiltrationAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){setAlertScore(getDefaultScore());};
   ~DataExfiltrationAlert(){};
 
   bool autoAck() const { return false; };
