@@ -34,7 +34,7 @@ class ExternalAlertCheckAlert : public FlowAlert {
   }
   static u_int8_t getDefaultScore() { return SCORE_LEVEL_ERROR; };
 
-  ExternalAlertCheckAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  ExternalAlertCheckAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){setAlertScore(getDefaultScore());};
   ~ExternalAlertCheckAlert(){};
 
   bool autoAck() const { return false; };
