@@ -31,7 +31,7 @@ class InvalidDNSQueryAlert : public FlowAlert {
   }
   static u_int8_t getDefaultScore() { return SCORE_LEVEL_NOTICE; };
 
-  InvalidDNSQueryAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  InvalidDNSQueryAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){setAlertScore(getDefaultScore());};
   ~InvalidDNSQueryAlert(){};
 
   FlowAlertType getAlertType() const { return getClassType(); }
