@@ -31,7 +31,7 @@ class LateralMovementAlert : public FlowAlert {
   }
   static u_int8_t getDefaultScore() { return SCORE_LEVEL_WARNING; };
 
-  LateralMovementAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  LateralMovementAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){setAlertScore(getDefaultScore());};
   ~LateralMovementAlert(){};
 
   FlowAlertType getAlertType() const { return getClassType(); }
