@@ -31,7 +31,7 @@ class NedgeBlockedFlowAlert : public FlowAlert {
   }
   static u_int8_t getDefaultScore() { return SCORE_LEVEL_WARNING; };
 
-  NedgeBlockedFlowAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  NedgeBlockedFlowAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){setAlertScore(getDefaultScore());};
   ~NedgeBlockedFlowAlert(){};
 
   FlowAlertType getAlertType() const { return getClassType(); }
