@@ -32,9 +32,9 @@ class PeriodicityChangedAlert : public FlowAlert {
   static FlowAlertType getClassType() {
     return {flow_alert_periodicity_changed, alert_category_network};
   }
-  static u_int8_t getDefaultScore() { return SCORE_LEVEL_INFO; };
+  static u_int8_t getDefaultScore() { return SCORE_LEVEL_NOTICE; };
 
-  PeriodicityChangedAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  PeriodicityChangedAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){setAlertScore(getDefaultScore());};
   ~PeriodicityChangedAlert(){};
 
   FlowAlertType getAlertType() const { return getClassType(); }
