@@ -34,7 +34,7 @@ class RareDestinationAlert : public FlowAlert {
   }
   static u_int8_t getDefaultScore() { return SCORE_LEVEL_NOTICE; };
 
-  RareDestinationAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  RareDestinationAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){setAlertScore(getDefaultScore());};
   ~RareDestinationAlert(){};
 
   FlowAlertType getAlertType() const { return getClassType(); }
