@@ -32,7 +32,7 @@ class TCPConnectionNoAnswerAlert : public FlowAlert {
   }
   static u_int8_t getDefaultScore() { return SCORE_LEVEL_WARNING; };
 
-  TCPConnectionNoAnswerAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  TCPConnectionNoAnswerAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){setAlertScore(getDefaultScore());};
   ~TCPConnectionNoAnswerAlert(){};
 
   FlowAlertType getAlertType() const { return getClassType(); }
