@@ -31,7 +31,7 @@ class TCPConnectionRefusedAlert : public FlowAlert {
   }
   static u_int8_t getDefaultScore() { return SCORE_LEVEL_NOTICE; };
 
-  TCPConnectionRefusedAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){};
+  TCPConnectionRefusedAlert(FlowCheck *c, Flow *f) : FlowAlert(c, f){setAlertScore(getDefaultScore());};
   ~TCPConnectionRefusedAlert(){};
 
   FlowAlertType getAlertType() const { return getClassType(); }
