@@ -26,15 +26,13 @@
 
 class VLANBidirectionalTrafficAlert : public FlowAlert {
  private:
-  ndpi_serializer* getAlertJSON(ndpi_serializer* serializer);
-
  public:
   static FlowAlertType getClassType() {
     return {flow_alert_vlan_bidirectional_traffic, alert_category_security};
   }
   static u_int8_t getDefaultScore() { return SCORE_LEVEL_ERROR; };
 
-  VLANBidirectionalTrafficAlert(FlowCheck* c, Flow* f) : FlowAlert(c, f){};
+  VLANBidirectionalTrafficAlert(FlowCheck* c, Flow* f) : FlowAlert(c, f){setAlertScore(getDefaultScore());};
   ~VLANBidirectionalTrafficAlert(){};
   FlowAlertType getAlertType() const { return getClassType(); }
 };
