@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -30,10 +30,6 @@
 
 #include "host_checks/FlowHits.h"
 #include "host_checks/FlowFlood.h"
-#include "host_checks/SYNScan.h"
-#include "host_checks/FINScan.h"
-#include "host_checks/RSTScan.h"
-#include "host_checks/SYNFlood.h"
 #include "host_checks/ICMPFlood.h"
 
 #include "host_checks/ServerContacts.h"
@@ -43,9 +39,8 @@
 
 #include "host_checks/DangerousHost.h"
 #include "host_checks/RemoteConnection.h"
+#include "host_checks/UnexpectedGateway.h"
 #include "host_checks/DomainNamesContacts.h"
-#include "host_checks/ScanDetection.h"
-#include "host_checks/ScoreThreshold.h"
 
 #ifdef NTOPNG_PRO
 #include "host_checks/DNSFlood.h"
@@ -53,8 +48,9 @@
 #include "host_checks/ScoreAnomaly.h"
 #include "host_checks/FlowAnomaly.h"
 #include "host_checks/HostScanner.h"
-#include "host_checks/RXOnlyHostScan.h"
 #include "host_checks/ServerPortsContacts.h"
+#include "host_checks/NATDetected.h"
+#include "host_checks/ScanRealtime.h"
 #endif
 
 #endif /* _HOST_CHECKS_INCLUDES_H_ */
