@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -114,9 +114,17 @@
 #endif
 
 #define ZMQ_COMPATIBILITY_MSG_VERSION 1
-#define ZMQ_MSG_VERSION 2
-#define ZMQ_MSG_VERSION_TLV 3
+
+#define ZMQ_MSG_VERSION               4 /* struct zmq_msg_hdr_v3 */
+#define ZMQ_MSG_VERSION_TLV           3
+#define ZMQ_MSG_VERSION_OLD           2
+
+/* Keep in sync with nProbe */
+#define ZMQ_FLAG_IS_TLV        2 << 0
+#define ZMQ_FLAG_IS_COMPRESSED 2 << 1
+
 #define LOGIN_URL "/lua/login.lua"
+#define INDEX_URL "/lua/index.lua"
 #define LOCALE_URL "/lua/locale.lua"
 #define LOGOUT_URL "/lua/ntopng_logout.lua"
 #define CAPTIVE_PORTAL_URL "/lua/captive_portal.lua"
@@ -128,13 +136,13 @@
 #define HOTSPOT_DETECT_URL "/hotspot-detect.html"        /* iOS    */
 #define KINDLE_WIFISTUB_URL "/kindle-wifi/wifistub.html" /* Kindle */
 #define HOTSPOT_DETECT_LUA_URL "/lua/hotspot-detect.lua"
-#define CHANGE_PASSWORD_ULR "/lua/change_password.lua"
+#define CHANGE_PASSWORD_URL "/lua/change_password.lua"
 #define LIVE_TRAFFIC_URL "/lua/rest/v2/get/pcap/live_traffic.lua"
 #define POOL_MEMBERS_ASSOC_URL "/lua/admin/manage_pool_members.lua"
 #define REST_API_PREFIX "/lua/rest/"
 #define REST_API_PRO_PREFIX "/lua/pro/rest/"
 #define INTERFACE_DATA_URL "/lua/rest/get/interface/data.lua"
-#define MAX_PASSWORD_LEN 32 + 1      /* \0 */
+#define MAX_PASSWORD_LEN 128 + 1      /* \0 */
 #define HTTP_SESSION_DURATION 43200  // 12h
 #define HTTP_SESSION_MIDNIGHT_EXPIRATION false
 #define EXTENDED_HTTP_SESSION_DURATION 604800  // 7d
@@ -155,9 +163,11 @@
 #define VXLAN_PORT 4789
 #define CAPWAP_DATA_PORT 5247
 #define MAX_NUM_INTERFACE_HOSTS 131072
-#define MAX_NUM_VIEW_INTERFACES 8
+#define MAX_NUM_VIEW_INTERFACES 16
 
 #define LIMITED_NUM_INTERFACES 8
+#define LIMITED_NUM_ACTIVE_HOSTS 256
+#define LIMITED_NUM_ACTIVE_FLOWS (128*1024)
 #define LIMITED_NUM_HOST_POOLS \
   5 /* 3 pools plus the NO_HOST_POOL_ID plus the Jailed hosts pool */
 #define LIMITED_NUM_PROFILES 16
@@ -170,10 +180,12 @@
 
 #ifndef NTOPNG_PRO
 #define MAX_NUM_DEFINED_INTERFACES LIMITED_NUM_INTERFACES
-#define MAX_NUM_HOST_POOLS LIMITED_NUM_HOST_POOLS
-#define MAX_NUM_PROFILES LIMITED_NUM_PROFILES
-#define MAX_NUM_POOL_MEMBERS LIMITED_NUM_POOL_MEMBERS
-#define MAX_ZMQ_SUBSCRIBERS LIMITED_MAX_ZMQ_SUBSCRIBERS
+#define MAX_NUM_ACTIVE_HOSTS       LIMITED_NUM_ACTIVE_HOSTS
+#define MAX_NUM_ACTIVE_FLOWS       LIMITED_NUM_ACTIVE_FLOWS
+#define MAX_NUM_HOST_POOLS         LIMITED_NUM_HOST_POOLS
+#define MAX_NUM_PROFILES           LIMITED_NUM_PROFILES
+#define MAX_NUM_POOL_MEMBERS       LIMITED_NUM_POOL_MEMBERS
+#define MAX_ZMQ_SUBSCRIBERS        LIMITED_MAX_ZMQ_SUBSCRIBERS
 #else
 /* Max number of ZMQ endpoints that can be configured to connect to the probes
  * Note: when running as server/collector the max number of clients/subscribers
@@ -195,10 +207,11 @@
         with incomplete TWH */
 #define MAX_FLOW_IDLE 60        /* sec */
 #define MAX_LOCAL_HOST_IDLE 300 /* sec */
+#define MAX_MAC_IDLE 300 /* sec */
 #define MAX_REMOTE_HOST_IDLE 60 /* sec */
 #define MAX_HASH_ENTRY_IDLE                                               \
   60 /* sec - Generic idle time for hash entries different from hosts and \
-        flows (i.e., ASes and Macs) */
+        flows (i.e., ASes and Countries) */
 #define MAX_PROBE_IDLE_IDLE 1800 /* 30 min (Used in ZMQParserInterface.cpp) */
 #define MAX_RRD_QUEUE_LEN 200000 /* timeseries in the queue */
 #define MIN_NUM_IDLE_ENTRIES_IF 5000
@@ -211,12 +224,14 @@
 #define OTHER_RRD_1H_DAYS 100
 #define OTHER_RRD_1D_DAYS 365
 #define CONST_DEFAULT_TOP_TALKERS_ENABLED false
+#define CONST_DEFAULT_SITES_COLLECTION_ENABLED false
+#define CONST_DEFAULT_DNS_CACHE_ENABLED false
 #define PURGE_FRACTION 60 /* check 1/60 of hashes per iteration */
 #define MIN_NUM_VISITED_ENTRIES 1024
 #define MAX_NUM_QUEUED_ADDRS \
   500 /* Maximum number of queued address for resolution */
 #define MAX_NUM_QUEUED_CONTACTS 25000
-#define NTOP_COPYRIGHT "(C) 1998-24 ntop.org"
+#define NTOP_COPYRIGHT "(C) 1998-25 ntop.org"
 #define DEFAULT_PID_PATH "/var/run/ntopng.pid"
 #define SYSTEM_INTERFACE_NAME "__system__"
 #define SYSTEM_INTERFACE_ID -1
@@ -228,7 +243,6 @@
 #define DHCP_CACHE "ntopng.dhcp.%d.cache.%s"
 #define DHCP_STORM_QUEUE_NAME "ntopng.dhcp.storm.%d"
 #define ASSET_SERVICE_KEY "ntopng.asset.%d.%s" /* ifId.host */
-#define ASSET_LIST_INSERTION_KEY "ntopng.asset.device_queue.%d" /* take in sync with lua code */
 #define ASSET_HASH_CACHE_KEY "ntopng.asset.hash.cache.%d" /* take in sync with lua code */
 #define DHCP_STORM_PPS_THSHOLD 2048
 #define NTOPNG_TRACE "ntopng.trace"
@@ -255,8 +269,11 @@
 #define LOCALHOST_SERVER_PORT_BITMAP "ntopng.cache.localhost_srv_port_bitmap.%d%s" 
 #define HOST_LABEL_NAMES_KEY          "ntopng.cache.host_labels.%s"
 #define IFACE_DHCP_RANGE_KEY          "ntopng.prefs.ifid_%u.dhcp_ranges"
+#define IFACE_BROADCAST_DOMAINS_KEY   "ntopng.prefs.ifid_%u.broadcast_domains"
 #define HOST_SERIALIZED_KEY           "ntopng.serialized_hosts.ifid_%u_%s@%d"
+#define HOST_SERIALIZED_SHORT_KEY     "%u_%s@%d"
 #define MAC_SERIALIZED_KEY            "ntopng.serialized_macs.ifid_%u_%s" /* /lua/enterprise/get_inactive_macs_data.lua */
+#define MAC_SERIALIZED_SHORT_KEY      "%u_%s" /* /lua/enterprise/get_inactive_macs_data.lua */
 #define IP_MAC_ASSOCIATION            "ntopng.ip_to_mac.ifid_%u_%s@%d"
 #define HOST_PREF_MUD_RECORDING       "ntopng.prefs.iface_%d.mud.recording.%s"
 #define MUD_RECORDING_GENERAL_PURPOSE "general_purpose"
@@ -312,6 +329,7 @@
 #define CONST_STR_USER_EXPIRE NTOPNG_USER_PREFIX ".%s.expire"
 #define CONST_STR_USER_CAPABILITIES NTOPNG_USER_PREFIX ".%s.capabilities"
 #define CONST_STR_USER_API_TOKEN NTOPNG_USER_PREFIX ".%s.api_token"
+#define CONST_STR_UNKNOWN_TCP_FINGERPRINTS NTOPNG_CACHE_PREFIX ".unknown_tcp_fingerprints"
 #define CONST_ALLOWED_NETS "allowed_nets"
 #define CONST_ALLOWED_IFNAME "allowed_ifname"
 #define CONST_USER_LANGUAGE "language"
@@ -334,8 +352,9 @@
 #define CONST_INTERFACE_TYPE_DB "db"
 #define CONST_INTERFACE_TYPE_UNKNOWN "unknown"
 
-#define CONST_DEMO_MODE_DURATION 600          /* 10 min */
-#define CONST_MAX_DUMP_DURATION 300           /* 5 min */
+#define CONST_ASSETS_PERIODIC_UPDATE  60      /* 1 min  */
+#define CONST_DEMO_MODE_DURATION     600      /* 10 min */
+#define CONST_MAX_DUMP_DURATION      300      /* 5 min  */
 #define CONST_MAX_NUM_PACKETS_PER_LIVE 100000 /* live captures via HTTP */
 #define CONST_MAX_DUMP 500000000
 
@@ -362,12 +381,9 @@
   1048576 /* 1MB, use only when allocating memory in the heap */
 #define POOL_MAX_SERIALIZED_LEN 32768 /* bytes */
 #define POOL_MAX_NAME_LEN 33          /* Characters */
-#define HOST_MAX_SCORE 500
-#define FLOW_MAX_SCORE_BREAKDOWN                                         \
-  8 /* Maximum number of alerts for the flow score breadkown. Additional \
-       alerts will fall under 'other' */
 
-#define CONST_MAX_NUM_NETWORKS 1024
+#define CONST_MAX_NUM_NETWORKS 131072
+#define MAX_NUM_LOCAL_NETWORKS 1024
 #define CONST_MAX_NUM_CHECKPOINTS 4
 
 #define HOST_IS_DHCP_SERVER 0x01
@@ -376,6 +392,9 @@
 #define HOST_IS_SMTP_SERVER 0x04
 #define HOST_IS_IMAP_SERVER 0x05
 #define HOST_IS_POP_SERVER 0x06
+#define HOST_IS_HTTP_SERVER 0x07
+#define HOST_IS_SSH_SERVER 0x08
+#define HOST_IS_RDP_SERVER 0x09
 
 #define MAX_DYNAMIC_STATS_VALUES 12
 
@@ -559,7 +578,6 @@
 #define HASHKEY_IFACE_TOP_OS "ntopng.cache.top_os"
 #define HASHKEY_IFACE_TOP_OS_HOUR_KEYS_PUSHED "ntopng.cache.top_os_hour_done"
 #define HASHKEY_IFACE_TOP_OS_DAY_KEYS_PUSHED "ntopng.cache.top_os_day_done"
-#define HASHKEY_LOCALHOST_RX_ONLY "ntopng.cache.localhost_host_rx_only"
 
 #define CONST_DEFAULT_DOCS_DIR "httpdocs"
 #define CONST_DEFAULT_SCRIPTS_DIR "scripts"
@@ -569,6 +587,7 @@
 #endif
 #define CONST_DEFAULT_USERS_FILE "ntopng-users.conf"
 #define CONST_DEFAULT_INSTALL_DIR (DATA_DIR "/ntopng")
+#define CONST_LOCAL_BIN_DIR "/usr/local/bin"
 #if defined(__FreeBSD__)
 #define CONST_BIN_DIR "/usr/local/bin"
 #define CONST_SHARE_DIR "/usr/local/share"
@@ -590,7 +609,7 @@
 #define CONST_OLD_DEFAULT_NTOP_USER "nobody"
 #define CONST_DEFAULT_NTOP_USER "ntopng"
 #define CONST_TOO_EARLY "TooEarly"
-#define CONST_LABELS_LOG_FILE "labels.log"
+#define CONST_ACTIVITY_LOG_FILE "ntopng-activities.log"
 
 #define CONST_LUA_OK 1
 #define CONST_LUA_ERROR 0
@@ -600,6 +619,8 @@
                                        */
 #define CONST_MAX_NEW_FLOWS_SECOND 25 /* keep in sync with alert_utils.lua */
 #define CONST_ALERT_GRACE_PERIOD 60   /* No more than 1 alert/min */
+#define CONST_MAX_ALERT_ENGAGE_TIME (60*60*24) /* 24h (sec) */
+
 #define CONST_CONTACTED_BY "contacted_by"
 #define CONST_CONTACTS "contacted_peers" /* Peers contacted by this host */
 
@@ -649,12 +670,22 @@
   NTOPNG_PREFS_PREFIX ".snmp_polling"
 #define CONST_PREFS_ENABLE_ACTIVE_MONITORING \
   NTOPNG_PREFS_PREFIX ".active_monitoring"
+#define CONST_PREFS_ENABLE_NETWORK_DISCOVERY \
+  NTOPNG_PREFS_PREFIX ".network_discovery"
+#define CONST_PREFS_ENABLE_STARTTLS \
+  NTOPNG_PREFS_PREFIX ".starttls"
+#define CONST_PREFS_ENABLE_DUMP_PCAP_TO_CLICKHOUSE \
+  NTOPNG_PREFS_PREFIX ".dump_pcap_to_clickhouse"
 #define CONST_PREFS_ENABLE_ACCESS_LOG NTOPNG_PREFS_PREFIX ".enable_access_log"
 #define CONST_PREFS_ENABLE_SQL_LOG NTOPNG_PREFS_PREFIX ".enable_sql_log"
 #define CONST_TOP_TALKERS_ENABLED NTOPNG_PREFS_PREFIX ".host_top_sites_creation"
+#define CONST_SITES_COLLECTION_ENABLED NTOPNG_PREFS_PREFIX ".sites_collection"
+#define CONST_DNS_CACHE_ENABLED NTOPNG_PREFS_PREFIX ".dns_cache"
 #define CONST_FLOW_TABLE_TIME NTOPNG_PREFS_PREFIX ".flow_table_time"
 #define CONST_FLOW_TABLE_PROBE_ORDER \
   NTOPNG_PREFS_PREFIX ".flow_table_probe_order"
+#define CONST_INTERFACE_CUSTOM_NAME \
+  NTOPNG_PREFS_PREFIX ".ifid_%d.name"
 #define CONST_MIRRORED_TRAFFIC_PREFS \
   NTOPNG_PREFS_PREFIX ".ifid_%d.is_traffic_mirrored"
 #define CONST_SMART_RECORDING_PREFS \
@@ -718,6 +749,7 @@
 #define CONST_PREFS_DEFAULT_L7_POLICY NTOPNG_PREFS_PREFIX ".default_l7_policy"
 #define CONST_PREFS_GLOBAL_DNS_FORGING_ENABLED \
   NTOPNG_PREFS_PREFIX ".global_dns_forging"
+#define CONST_PREFS_ENABLE_FULL_STATS NTOPNG_PREFS_PREFIX ".enable_full_stats"
 #define HOST_POOL_IDS_KEY NTOPNG_PREFS_PREFIX ".host_pools.pool_ids"
 #define HOST_POOL_MEMBERS_KEY NTOPNG_PREFS_PREFIX ".host_pools.members.%s"
 #define HOST_POOL_SHAPERS_KEY NTOPNG_PREFS_PREFIX ".%u.l7_policies.%s"
@@ -749,6 +781,11 @@
   NTOPNG_PREFS_PREFIX ".behaviour_analysis_learning_status_during_learning"
 #define CONST_PREFS_BEHAVIOUR_ANALYSIS_STATUS_POST_LEARNING \
   NTOPNG_PREFS_PREFIX ".behaviour_analysis_learning_status_post_learning"
+  
+#define CONST_PREFS_HTTP_INDEX_PAGE \
+  NTOPNG_PREFS_PREFIX ".http_index_page"
+#define DEFAULT_HTTP_INDEX_PAGE \
+  ""
 
 #define CONST_PREFS_IEC60870_ANALYSIS_LEARNING_PERIOD \
   NTOPNG_PREFS_PREFIX ".iec60870_learning_period"
@@ -824,6 +861,10 @@
   NTOPNG_PREFS_PREFIX ".is_active_local_host_cache_enabled"
 #define CONST_RUNTIME_ACTIVE_LOCAL_HOSTS_CACHE_INTERVAL \
   NTOPNG_PREFS_PREFIX ".active_local_host_cache_interval"
+#define CONST_RUNTIME_ENABLE_ASSETS_COLLECTION \
+  NTOPNG_PREFS_PREFIX ".enable_assets_collection"
+#define CONST_RUNTIME_MAC_ADDRESS_CACHE_DURATION \
+  NTOPNG_PREFS_PREFIX ".mac_address_cache_duration"
 #define CONST_RUNTIME_PREFS_LOG_TO_FILE NTOPNG_PREFS_PREFIX ".log_to_file"
 #define CONST_RUNTIME_PREFS_HOUSEKEEPING_FREQ \
   NTOPNG_PREFS_PREFIX ".housekeeping_freq"
@@ -885,6 +926,8 @@
   ".alert_exclusions" /* Keep in sync with hosts_control.lua */
 
 #define CONST_MAX_ALERT_MSG_QUEUE_LEN 8192
+#define CONST_MAX_INACTIVE_HOSTS_MAC_QUEUE_LEN 32768
+
 #define CONST_MAX_ES_MSG_QUEUE_LEN 8192
 #define CONST_MAX_MYSQL_QUEUE_LEN 8192
 #define CONST_MAX_NUM_READ_ALERTS 32
@@ -1096,10 +1139,12 @@
 
 /* MESSAGE BROKER CONSTS */
 
-#define CONST_PREFS_MESSAGE_BROKER_URL \
-  NTOPNG_PREFS_PREFIX ".message_broker_url"
+#define CONST_PREFS_MESSAGE_BROKER_URL NTOPNG_PREFS_PREFIX ".message_broker_url"
 #define DEFAULT_MESSAGE_BROKER_URL "0.0.0.0:4222"
 
+#define CONST_PREFS_MESSAGE_BROKER_ENABLED NTOPNG_PREFS_PREFIX ".toggle_message_broker"
+#define DEFAULT_MESSAGE_BROKER_ENABLED false
+
 #define BROKER_RPC_CALL_DEFAULT_TIMEOUT_MS (u_int64_t)10000
 #define BROKER_RPC_CALL_MAX_RSP_LEN (u_int64_t)256
 
@@ -1159,8 +1204,7 @@
 #define STATS_UPDATE_SCRIPT_PATH "stats_update.lua"
 
 #define STARTUP_SCRIPT_PATH "startup.lua"
-#define BOOT_SCRIPT_PATH \
-  "boot.lua" /* Executed as root before networking is setup */
+#define BOOT_SCRIPT_PATH    "boot.lua" /* Executed as root before networking is setup */
 #define SHUTDOWN_SCRIPT_PATH "shutdown.lua"
 
 #define HOUSEKEEPING_SCRIPT_PATH "housekeeping.lua"
@@ -1175,6 +1219,7 @@
 #define FIVE_MINUTES_SCRIPT_DIR "5minute"
 #define HOURLY_SCRIPT_DIR "hourly"
 #define DAILY_SCRIPT_DIR "daily"
+#define MONTHLY_SCRIPT_DIR "monthly"
 
 #define MACS_DISCONNECTION                                                \
   "ntopng.cache.checks.ifid_%d.macs_disconnected" /* Sync with checks.lua \
@@ -1199,6 +1244,8 @@
 #define GRE_HEADER_KEY 0x2000      /* 32 bit */
 #define GRE_HEADER_SEQ_NUM 0x1000  /* 32 bit */
 
+#define PREF_FORWARDER_DEBUG NTOPNG_PREFS_PREFIX ".forwarder_debug"
+
 #define HOST_LOW_GOODPUT_THRESHOLD \
   25 /* No more than X low goodput flows per host */
 
@@ -1221,7 +1268,8 @@
 #define PREF_LDAP_USER_GROUP NTOPNG_PREFS_PREFIX ".ldap.user_group"
 #define PREF_LDAP_ADMIN_GROUP NTOPNG_PREFS_PREFIX ".ldap.admin_group"
 #define PREF_LDAP_FOLLOW_REFERRALS NTOPNG_PREFS_PREFIX ".ldap.follow_referrals"
-#define PREF_LDAP_DEBUG NTOPNG_PREFS_PREFIX ".ldap.debug"
+#define PREF_LDAP_EXT_USER_CAP NTOPNG_PREFS_PREFIX ".ldap.ext_user_cap"
+#define PREF_LDAP_DEBUG NTOPNG_PREFS_PREFIX ".ldap_debug"
 #ifdef HAVE_LDAP
 #define MAX_LDAP_LEN \
   256 /* Keep it in sync with lua preferences file prefs.lua */
@@ -1350,6 +1398,8 @@
 */
 #define DROP_HOST_POOL_HOST_IN_JAIL "ntopng.cache.jail.time.%s"
 
+#define LOCALHOST_ASSET_CACHE_HASH_KEY "ntopng.cache.localhost_asset_cache"
+
 /*
   A redis key keeping the pool associated to an host that is currently in the
   jail. This key is used to restore the host in the proper pool after it has
@@ -1375,18 +1425,19 @@ extern NtopngLuaContext* getUserdata(struct lua_State *vm);
 #define MAX_CHECKPOINT_COMPRESSION_BUFFER_SIZE 1024
 
 /* Keep in sync with nProbe */
-#define MAX_ZMQ_FLOW_BUF 16384
+#define MAX_ZMQ_FLOW_BUF                 131072
 #define DEFAULT_ZMQ_TCP_KEEPALIVE        1 /* Keepalive ON */
 #define DEFAULT_ZMQ_TCP_KEEPALIVE_IDLE  30 /* Keepalive after 30 seconds */
 #define DEFAULT_ZMQ_TCP_KEEPALIVE_CNT    3 /* Keepalive send 3 probes */
 #define DEFAULT_ZMQ_TCP_KEEPALIVE_INTVL  3 /* Keepalive probes sent every 3 seconds */
 
-#define NTOPNG_MAX_NUM_SNMP_DEVICES_ENT_M  16
-#define NTOPNG_MAX_NUM_SNMP_DEVICES_ENT_L  32
-#define NTOPNG_MAX_NUM_SNMP_DEVICES_ENT_XL 128
+#define NTOPNG_MAX_NUM_SNMP_DEVICES_NEDGE     8
+#define NTOPNG_MAX_NUM_SNMP_DEVICES_ENT_M    16
+#define NTOPNG_MAX_NUM_SNMP_DEVICES_ENT_L    32
+#define NTOPNG_MAX_NUM_SNMP_DEVICES_ENT_XL  128
+#define NTOPNG_MAX_NUM_SNMP_DEVICES_ENT_XXL 512
 
-#define MIN_NUM_ASYNC_SNMP_ENGINES         NTOPNG_MAX_NUM_SNMP_DEVICES_ENT_M
-#define MAX_NUM_ASYNC_SNMP_ENGINES         NTOPNG_MAX_NUM_SNMP_DEVICES_ENT_XL
+#define MAX_NUM_ASYNC_SNMP_ENGINES         NTOPNG_MAX_NUM_SNMP_DEVICES_ENT_XXL
 
 #if defined(NTOPNG_PRO) && defined(HAVE_LIBSNMP)
 #define HAVE_SNMP_TRAP
@@ -1577,6 +1628,8 @@ extern NtopngLuaContext* getUserdata(struct lua_State *vm);
   "ntopng.checks.modbus_invalid_transition_enabled"
 #define CHECKS_MODBUS_TOO_MANY_EXCEPTIONS \
   "ntopng.checks.modbus_too_many_exceptions"
+#define CHECKS_MODBUS_UNEXPECTED_FUNCTION_CODE \
+  "ntopng.checks.modbus_unexpected_function_code_enabled"
 
 #define CUSTOM_FLOW_NDPI_SCRIPT \
   "scripts/callbacks/checks/flows/custom_flow_protocol_detected_script.lua"
@@ -1585,7 +1638,8 @@ extern NtopngLuaContext* getUserdata(struct lua_State *vm);
 #define CUSTOM_FLOW_END_SCRIPT \
   "scripts/callbacks/checks/flows/custom_flow_end_script.lua"
 
-#define OFFLINE_LOCAL_HOSTS_KEY "ntopng.hosts.offline.ifid_%d"
+#define OFFLINE_LOCAL_HOSTS_MACS_QUEUE_NAME "ntopng.assets_hosts_macs.queue.ifid_%d"
+
 #define EXPORTERS_EXCEEDED_LIMITS_KEY "ntopng.limits.exporters"
 
 #define MAX_NUM_PCAP_INTERFACES 8
@@ -1593,6 +1647,30 @@ extern NtopngLuaContext* getUserdata(struct lua_State *vm);
 #define NO_VLAN (u_int16_t)-1
 #define NO_IN_IF_INDEX (u_int32_t)-1
 #define NO_OUT_IF_INDEX (u_int32_t)-1
+
+#define CONST_DEFAULT_TLS_CIPHERS "HIGH:!aNULL:!MD5:!RC4"
+#define CONST_ZMQ_PAYLOAD_LEN     131072 /* 128k max ZMQ message size */
+
+#define CONST_GATEWAY_CONFIGURATION_REDIS_KEY "ntopng.prefs.nw_config_gateway_list"
+#define CONST_DNS_SERVER_CONFIGURATION_REDIS_KEY "ntopng.prefs.nw_config_dns_list"
+#define CONST_NTP_SERVER_CONFIGURATION_REDIS_KEY "ntopng.prefs.nw_config_ntp_list"
+#define CONST_DHCP_SERVER_CONFIGURATION_REDIS_KEY "ntopng.prefs.nw_config_dhcp_list"
+#define CONST_SMTP_SERVER_CONFIGURATION_REDIS_KEY "ntopng.prefs.nw_config_smtp_list"
+
+#ifdef NTOPNG_PRO
+#define CONST_LOCAL_DEVICES_NETWORKS_CONFIGURATION_REDIS_KEY     "ntopng.prefs.nw_policy_local_devices"
+#define CONST_CORPORATE_DEVICES_NETWORKS_CONFIGURATION_REDIS_KEY "ntopng.prefs.nw_policy_corporate_devices"
+#define CONST_WHITELISTED_NETWORKS_CONFIGURATION_REDIS_KEY       "ntopng.prefs.nw_policy_whitelisted_networks"
+#endif
+
+#define NTOP_QOE_MAX        100
+#define NTOP_QOE_UNKNOWN    255
+#define NTOP_QOE_EXCELLENT   90
+#define NTOP_QOE_GOOD        75
+#define NTOP_QOE_FAIR        65
+#define NTOP_QOE_DEGRADED    50
+#define NTOP_QOE_POOR        30
+
 /******************************************************************************/
 
 #endif /* _NTOP_DEFINES_H_ */
