@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -124,6 +124,7 @@
 #define EXPORTER_IPV4_ADDRESS 130
 #define EXPORTER_IPV6_ADDRESS 131
 #define FLOW_END_REASON 136
+#define WLAN_SSID 147
 #define FLOW_ID 148
 #define FLOW_START_SEC 150
 #define FLOW_END_SEC 151
@@ -160,11 +161,13 @@
 #define PACKETS_OBSERVED 318
 #define PACKETS_SELECTED 319
 #define SELECTOR_NAME 335
+#define WTP_MAC_ADDRESS 367
 #define SRC_FRAGMENTS NTOP_BASE_ID + 80
 #define DST_FRAGMENTS NTOP_BASE_ID + 81
 #define SRC_AS_MAP NTOP_BASE_ID + 443
 #define DST_AS_MAP NTOP_BASE_ID + 444
 #define NPROBE_IPV4_ADDRESS NTOP_BASE_ID + 471 /* Exported only via ZMQ */
+#define NPROBE_IPV6_ADDRESS NTOP_BASE_ID + 472 /* Exported only via ZMQ */
 /* NTOP_BASE_ID+82 ->87  Available (deprecated) */
 #define CLIENT_TCP_FLAGS NTOP_BASE_ID + 78
 #define SERVER_TCP_FLAGS NTOP_BASE_ID + 79
@@ -196,6 +199,7 @@
 #define L7_PROTO_NAME NTOP_BASE_ID + 119
 #define L7_INFO NTOP_BASE_ID + 539
 #define L7_CONFIDENCE NTOP_BASE_ID + 560
+#define L7_DETAILS NTOP_BASE_ID+593 /* nDPI JSON */
 #define DOWNSTREAM_TUNNEL_ID NTOP_BASE_ID + 120
 #define FLOW_USER_NAME NTOP_BASE_ID + 121
 #define NPROBE_INSTANCE_NAME NTOP_BASE_ID + 122
@@ -238,6 +242,9 @@
 #define DOWNSTREAM_SESSION_ID NTOP_BASE_ID + 447
 #define TLS_SERVER_NAME NTOP_BASE_ID + 188
 #define BITTORRENT_HASH NTOP_BASE_ID + 189
+#define QOE_SRC_TO_DST  NTOP_BASE_ID + 594
+#define QOE_DST_TO_SRC  NTOP_BASE_ID + 595
+#define L7_OS_HINT      NTOP_BASE_ID+596
 #define TLS_CIPHER NTOP_BASE_ID + 493
 #define SSL_UNSAFE_CIPHER NTOP_BASE_ID + 494
 #define L7_PROTO_RISK NTOP_BASE_ID + 509
