@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -221,6 +221,7 @@ using namespace std;
 #include "MDNS.h"
 #include "AddressTree.h"
 #include "VLANAddressTree.h"
+#include "ServerConfiguration.h"
 #include "BroadcastDomains.h"
 #include "Cardinality.h"
 #include "PeerStats.h"
@@ -261,6 +262,7 @@ using namespace std;
 #include "HWCounter.h"
 #include "RSICounter.h"
 #ifdef NTOPNG_PRO
+#include "QoEStats.h"
 #include "BehaviorAnalysis.h"
 #endif
 #include "ThroughputStats.h"
@@ -377,6 +379,7 @@ using namespace std;
 #include "PeriodicityHash.h"
 #include "ServiceMap.h"
 #include "PeriodicityMap.h"
+#include "ACLFlow.h"
 #endif
 #include "PortDetails.h"
 #include "HostsPorts.h"
@@ -390,8 +393,11 @@ using namespace std;
 #include "NtopngLuaContext.h"
 #ifndef HAVE_NEDGE
 #include "PcapInterface.h"
+#include "sFlowPktInterface.h"
 #endif
+#if defined(NTOPNG_PRO) 
 #include "ViewInterface.h"
+#endif
 #ifdef HAVE_PF_RING
 #include "PF_RINGInterface.h"
 #endif
@@ -456,12 +462,13 @@ using namespace std;
 #include "VLAN.h"
 #include "AutonomousSystem.h"
 #include "ObservationPoint.h"
-#include "OperatingSystem.h"
 #include "Country.h"
 #include "MacStats.h"
 #include "Mac.h"
 #include "PartializableFlowTrafficStats.h"
+#if defined(NTOPNG_PRO) 
 #include "ViewInterfaceFlowStats.h"
+#endif
 #include "FlowTrafficStats.h"
 #include "HostStats.h"
 #include "HostChecksStatus.h"
@@ -472,7 +479,7 @@ using namespace std;
 #include "LocalHost.h"
 #include "RemoteHost.h"
 #ifdef NTOPNG_PRO
-#include "AssetManagement.h"
+#include "FlowRTP.h"
 #include "ModbusStats.h"
 #include "MessageBroker.h"
 #include "NatsBroker.h"
@@ -483,7 +490,6 @@ using namespace std;
 #include "VLANHash.h"
 #include "AutonomousSystemHash.h"
 #include "ObservationPointHash.h"
-#include "OperatingSystemHash.h"
 #include "CountriesHash.h"
 #include "HostHash.h"
 #include "ThreadedActivityStats.h"
