@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -269,6 +269,13 @@ struct zmq_msg_hdr_v2 {
   u_int32_t msg_id, source_id;
 };
 
+struct zmq_msg_hdr_v3 {
+  char url[16];
+  u_int8_t version /* 4 */, flags;
+  u_int32_t uncompressed_size, compressed_size;
+  u_int32_t msg_id, source_id;
+};
+
 typedef struct {
   char *endpoint;
   void *socket;
@@ -452,7 +459,7 @@ typedef enum {
   flow_alert_ndpi_tls_certificate_selfsigned = 28,
   flow_alert_ndpi_binary_application_transfer = 29,
   flow_alert_ndpi_known_proto_on_non_std_port = 30,
-  flow_alert_noutused_8 = 31,
+  flow_alert_notused_8 = 31,
   flow_alert_unexpected_dhcp_server = 32,
   flow_alert_unexpected_dns_server = 33,
   flow_alert_unexpected_smtp_server = 34,
@@ -500,7 +507,7 @@ typedef enum {
   flow_alert_ndpi_anonymous_subscriber = 76,
   flow_alert_unidirectional_traffic = 77,
   flow_alert_ndpi_desktop_or_file_sharing_session = 78,
-  flow_alert_ndpi_malicious_ja3 = 79,
+  flow_alert_ndpi_malicious_fingerprint = 79,
   flow_alert_ndpi_malicious_sha1_certificate = 80,
   flow_alert_ndpi_tls_uncommon_alpn = 81,
   flow_alert_ndpi_tls_suspicious_extension = 82,
@@ -523,7 +530,11 @@ typedef enum {
   flow_alert_ndpi_binary_data_transfer = 99,
   flow_alert_tcp_flow_reset = 100,
   flow_alert_ndpi_probing_attempt = 101,
-  
+  flow_alert_access_control_list = 102,
+  flow_alert_host_policy = 103,
+  flow_alert_qoe_degraded = 104,
+  flow_alert_ndpi_obfuscated_traffic = 105,
+
   MAX_DEFINED_FLOW_ALERT_TYPE, /* Leave it as last member */
 
   MAX_FLOW_ALERT_TYPE =
@@ -550,31 +561,33 @@ typedef enum {
   host_alert_dns_server_contacts = 2,
   host_alert_ntp_server_contacts = 3,
   host_alert_flow_flood = 4,
-  host_alert_syn_scan = 5,
+  host_alert_notused_1 = 5,
   host_alert_syn_flood = 6,
   host_alert_domain_names_contacts = 7,
-  host_alert_notused_1 = 8,
-  host_alert_notused_2 = 9,
+  host_alert_unexpected_gateway = 8,
+  host_alert_nat_detected = 9,
   host_alert_flows_anomaly = 10,
   host_alert_score_anomaly = 11,
   host_alert_remote_connection = 12,
   host_alert_host_log = 13,
   host_alert_dangerous_host = 14,
-  host_alert_notused_3 = 15,
+  host_alert_scan_realtime = 15,
   host_alert_countries_contacts = 16,
-  host_alert_score_threshold = 17,
+  host_alert_notused_2 = 17,
   host_alert_icmp_flood = 18,
-  host_alert_notused_4 = 19,
-  host_alert_scan_detected = 20,
-  host_alert_fin_scan = 21,
+  host_alert_notused_3 = 19,
+  host_alert_notused_4 = 20,
+  host_alert_notused_5 = 21,
   host_alert_dns_flood = 22,
   host_alert_snmp_flood = 23,
   host_alert_custom_lua_script = 24,
-  host_alert_rst_scan = 25,
+  host_alert_notused_6 = 25,
   host_alert_traffic_volume = 26,
   host_alert_external_script = 27, /* Triggered from Lua (see rest/v2/trigger/host/alert.lua) */
   host_alert_host_scanner = 28,
   host_alert_server_ports_contacts = 29,
+  host_alert_suspicious_domain_scan = 30, /* Triggered from Lua */
+  host_alert_scan = 31, /* Triggered from Lua */
 
   MAX_DEFINED_HOST_ALERT_TYPE, /* Leave it as last member */
   MAX_HOST_ALERT_TYPE = 32     /* Constrained by HostAlertBitmap */
@@ -599,7 +612,6 @@ typedef enum {
   host_check_http_replies_requests_ratio = 0,
   host_check_dns_replies_requests_ratio,
   host_check_syn_flood,
-  host_check_syn_scan,
   host_check_flow_flood,
   host_check_ntp_server_contacts,
   host_check_smtp_server_contacts,
@@ -613,19 +625,18 @@ typedef enum {
   host_check_domain_names_contacts,
   host_check_score_threshold,
   host_check_icmp_flood,
-  host_check_scan_detection,
+  host_check_nat_detected,
   host_check_mac_reassociation,
-  host_check_fin_scan,
   host_check_dns_flood,
   host_check_snmp_flood,
   host_check_custom_lua_script,
-  host_check_rst_scan,
   host_check_traffic_volume, /* Dummy check (see
                                 ntop_interface_update_ip_reassignment) */
   host_check_external_script,
   host_check_host_scanner,
-  host_check_rx_only_host_scan,
   host_check_server_ports_contacts,
+  host_check_unexpected_gateway,
+  host_check_scan_realtime,
 
   NUM_DEFINED_HOST_CHECKS, /* Leave it as last member */
 } HostCheckID;
@@ -680,6 +691,7 @@ typedef enum {
   column_in_index,
   column_out_index,
   column_key,
+  column_qoe,
   /* Hosts */
   column_ip,
   column_alerts,
@@ -751,7 +763,6 @@ typedef enum {
   walker_ases,
   walker_countries,
   walker_vlans,
-  walker_oses,
   walker_obs
 } WalkerType;
 
@@ -922,20 +933,13 @@ typedef enum {
   interface_type_DB_VIEW
 } InterfaceType;
 
-/* Update Flow::dissectHTTP when extending the type below */
-/* Keep in sync with discover.os2label */
 typedef enum {
-  os_unknown = 0,
-  os_linux,
-  os_windows,
-  os_macos,
-  os_ios,
-  os_android,
-  os_laserjet,
-  os_apple_airport,
-  os_max_os, /* Keep as last element */
-  os_any
-} OSType;
+  os_learning_unknown = 0,
+  os_learning_tcp_fingerprint,
+  os_learning_http_user_agent,
+  os_learning_user_set_via_lua,
+  os_learning_dhcp
+} OSLearningMode;
 
 /* Keep in sync with hosts_map_utils.lua */
 typedef enum {
@@ -1057,6 +1061,7 @@ typedef struct _ntop_if_t {
   /* PF_RING related fields */
   char *module;
   int license;
+  int ifindex;
   _ntop_if_t *next;
 } ntop_if_t;
 
@@ -1104,7 +1109,7 @@ typedef struct _MapsFilters {
   u_int16_t host_pool_id;
   u_int16_t port;
   u_int16_t ndpi_proto;
-  int16_t network_id;
+  int32_t network_id;
   u_int32_t first_seen;
   ServiceAcceptance status;
   char host_to_search[32];
@@ -1192,10 +1197,62 @@ typedef enum {
 } MinorConnectionStates;
 
 typedef enum {
-  MAJOR_NO_STATE = 0, 
+  MAJOR_NO_STATE = 0,
   ATTEMPTED,
   ESTABLISHED,
   CLOSED = 3
 } MajorConnectionStates;
-  
+
+typedef enum {
+  unknown_network_id = 0,
+  restricted_host_network_id,
+  core_host_network_id,
+  whitelisted_host_network_id
+} NetworkConfigurationId;
+
+typedef enum {
+  policy_reason_unknown = 0,
+  restricted_client_connected_public_ip_not_whitelisted,
+  restricted_client_connected_to_core_host,
+  core_host_connected_to_non_whitelisted_server
+} HostPolicyAlertReason;
+
+typedef struct {
+  u_int16_t max_rtt, ideal_rtt, max_jitter, ideal_jitter;
+} QoELimits;
+
+/* Keep in sync with flow_consts.drop_reason in flow_consts.lua */
+typedef enum {
+  DROP_REASON_UNKNOWN = 0,
+  DROP_REASON_USER_ACTION,
+  DROP_REASON_PROBE_VERDICT,
+  DROP_REASON_BLACKLISTED_FLOW,
+  DROP_REASON_QUOTA_EXCEEDED,
+  DROP_REASON_DROP_CLI,
+  DROP_REASON_DROP_SRV,
+  DROP_REASON_CLI2SRV_SHAPER,
+  DROP_REASON_SRV2CLI_SHAPER,
+  DROP_REASON_DEV_NOT_ALLOW_PROTO_CLI,
+  DROP_REASON_DEV_NOT_ALLOW_PROTO_SRV
+} DropReason;
+
+
+typedef enum {
+  qoe_unknown = 0,
+  qoe_poor,
+  qoe_degraded,
+  qoe_fair,
+  qoe_good,
+  qoe_excellent
+} QoEType;
+
+typedef enum
+{
+  scan_alert_scan_detention = 0,
+  scan_alert_rx_only,
+  scan_alert_syn,
+  scan_alert_fin,
+  scan_alert_rst
+} ScanAlertType;
+
 #endif /* _NTOP_TYPEDEFS_H_ */
