@@ -1,14 +1,17 @@
 --
--- (C) 2013-23 - ntop.org
+-- (C) 2013-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
+package.path = dirs.installdir .. "/scripts/lua/modules/vulnerability_scan/?.lua;" .. package.path
+
 require "lua_utils"
 local discover = require "discover_utils"
 local custom_column_utils = require "custom_column_utils"
 local format_utils = require "format_utils"
 local json = require "dkjson"
+local vs_utils = require "vs_utils"
 local have_nedge = ntop.isnEdge()
 
 sendHTTPContentTypeHeader('text/json')
@@ -38,7 +41,6 @@ local pool         = _GET["pool"]
 local country      = _GET["country"]
 local os_          = tonumber(_GET["os"])
 local mac          = _GET["mac"]
-local top_hidden   = ternary(_GET["top_hidden"] == "1", true, nil)
 
 function update_host_name(h)
    if(h["name"] == nil) then
@@ -128,6 +130,8 @@ elseif mode == "remote_no_tcp_tx" then
    hosts_retrv_function = interface.getRemoteHostsInfoNoTXTCP
 elseif mode == "broadcast_domain" then
    hosts_retrv_function = interface.getBroadcastDomainHostsInfo
+elseif mode == "broadcast_multicast" then
+   hosts_retrv_function = interface.getBroadcastMulticastHostsInfo
 elseif mode == "filtered" then
    filtered_hosts = true
 elseif mode == "blacklisted" then
@@ -141,7 +145,8 @@ local hosts_stats = hosts_retrv_function(false, sortColumn, perPage, to_skip, sO
 					 tonumber(network), mac,
 					 tonumber(pool), tonumber(ipversion),
 					 tonumber(protocol), traffic_type_filter,
-					 filtered_hosts, blacklisted_hosts, top_hidden, anomalous, dhcp_hosts, cidr, device_ip)
+					 filtered_hosts, blacklisted_hosts,
+					 anomalous, dhcp_hosts, cidr, device_ip)
 
 if(hosts_stats == nil) then total = 0 else total = hosts_stats["numHosts"] end
 hosts_stats = hosts_stats["hosts"]
@@ -210,11 +215,19 @@ if(hosts_stats ~= nil) then
 	 vals[hosts_stats[key]["queries.rcvd"]+postfix] = key
       elseif(sortColumn == "column_ip") then
 	 vals[hosts_stats[key]["iphex"]..postfix] = key
+      elseif(sortColumn == "column_num_vulnerabilities") then
+         if(host_vs_details.num_vulnerabilities_found ~= nil) then
+            vals[host_vs_details.num_vulnerabilities_found..postfix] = key
+         else
+            vals["0"..postfix] = key
+         end
       elseif custom_column_utils.isCustomColumn(sortColumn) then
 	 custom_column_key, custom_column_format = custom_column_utils.label2criteriakey(sortColumn)
 	 local val = custom_column_utils.hostStatsToColumnValue(hosts_stats[key], custom_column_key, false)
+
+	 if(val == nil) then val = 0 end -- Just to avoid invalid table values
 	 
-	 if tonumber(val) then
+	 if(tonumber(val)) then
 	    vals[val + postfix] = key
 	 else
 	    vals[val..postfix] = key
@@ -239,7 +252,15 @@ for _key, _value in pairsByKeys(vals, funct) do
    local record = {}
    local key = vals[_key]
    local value = hosts_stats[key]
+   local host_vulnerabilities = vs_utils.retrieve_host(value["ip"])
 
+   if (host_vulnerabilities and 
+         host_vulnerabilities.num_vulnerabilities_found ~= nil and 
+         host_vulnerabilities.num_vulnerabilities_found > 0) then
+      record["column_num_vulnerabilities"] = format_high_num_value_for_tables(
+         { value = host_vulnerabilities.num_vulnerabilities_found }, "value")
+   end
+   
    local symkey = hostinfo2jqueryid(hosts_stats[key])
    record["key"] = symkey
 
@@ -365,11 +386,16 @@ for _key, _value in pairsByKeys(vals, funct) do
       record["column_num_dropped_flows"] = (value["flows.dropped"] or 0)
    end
 
-   local sent2rcvd = round((value["bytes.sent"] * 100) / (value["bytes.sent"]+value["bytes.rcvd"]), 0)
-   if(sent2rcvd == nil) then sent2rcvd = 0 end
    record["column_score"] = format_high_num_value_for_tables(value, "score") 
-   record["column_breakdown"] = "<div class='progress'><div class='progress-bar bg-warning' style='width: "
+   record["column_breakdown"] = ""
+
+   local total_bytes = value["bytes.sent"]+value["bytes.rcvd"]
+   local sent2rcvd = 0
+   if total_bytes > 0 then
+     sent2rcvd = round((value["bytes.sent"] * 100) / total_bytes, 0) or 0
+     record["column_breakdown"] = "<div class='progress'><div class='progress-bar bg-warning' style='width: "
 	     .. sent2rcvd .."%;'>Sent</div><div class='progress-bar bg-success' style='width: " .. (100-sent2rcvd) .. "%;'>Rcvd</div></div>"
+   end
 
    local _, custom_column_key = custom_column_utils.getCustomColumnName()
    record["column_"..custom_column_key] = custom_column_utils.hostStatsToColumnValue(value, custom_column_key, true)
@@ -392,5 +418,4 @@ result["currentPage"] = currentPage
 result["totalRows"] = total
 result["data"] = formatted_res
 result["sort"] = {{sortColumn, sortOrder}}
-
 print(json.encode(result))
