@@ -1,5 +1,5 @@
 --
--- (C) 2013-18 - ntop.org
+-- (C) 2013-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -31,7 +31,7 @@ local function getTopTalkersFromJSONDirection(table, wantedDir, add_vlan)
 
       for i2,hostpair in pairs(vlan["hosts"]) do
 	 -- hostpair is { "senders": [...], "receivers": [...] }
-	 
+
 	 local direction = hostpair[wantedDir]
 	 if direction == nil then direction = {} end
 	 for _, host in pairs(direction) do
@@ -113,6 +113,10 @@ local function getHistoricalTopTalkers(ifid, ifname, epoch, add_vlan)
    return getTopTalkersFromJSON(res, add_vlan)
 end
 
-epoch = epoch+60 -- we return the minute before the event as epochs are stored in the DB 'past' the time period
-top = getHistoricalTopTalkers(ifid, ifname, epoch, add_vlan)
-print(top)
+if top_talkers_utils.areTopEnabled(ifid) then
+   epoch = epoch+60 -- we return the minute before the event as epochs are stored in the DB 'past' the time period
+   top = getHistoricalTopTalkers(ifid, ifname, epoch, add_vlan)
+   print(top)
+else
+   print("{}")
+end
