@@ -1,5 +1,5 @@
 --
--- (C) 2013-23 - ntop.org
+-- (C) 2013-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -53,7 +53,9 @@ if isAdministrator() then
       ntop.setMacDeviceType(mac, devtype, true --[[ overwrite ]])
 
       pool_id = _POST["pool"]
-      host_pools_instance:bind_member(mac, tonumber(pool_id))
+      if pool_id then
+         host_pools_instance:bind_member(mac, tonumber(pool_id))
+      end
    end
 end
 
@@ -77,7 +79,7 @@ if(vlanId == nil) then vlanId = 0 end
 sendHTTPContentTypeHeader('text/html')
 
 
-page_utils.set_active_menu_entry(page_utils.menu_entries.devices)
+page_utils.print_header_and_set_active_menu_entry(page_utils.menu_entries.devices)
 
 dofile(dirs.installdir .. "/scripts/lua/inc/menu.lua")
 
@@ -100,11 +102,11 @@ end
 
 local mac_info = interface.getMacInfo(mac)
 
--- tprint(mac_info)
+-- tprint(mac_info.dhcp_fingerprint)
 
 local only_historical = (mac_info == nil) and (page == "historical")
 local serialize_by_mac = ntop.getPref(string.format("ntopng.prefs.ifid_" .. ifId .. ".serialize_local_broadcast_hosts_as_macs")) == "1"
-
+local historical_flow_link = ntop.getHttpPrefix() .. "/lua/pro/db_search.lua?ifid=" .. ifId .. "&mac=" .. mac .. ";eq"
 if(mac_info == nil) and not only_historical then
    print('<div class=\"alert alert-danger\"><i class="fas fa-exclamation-triangle fa-lg fa-ntopng-warning"></i>'..' '..i18n("mac_details.mac_cannot_be_found_message",{mac=mac}))
    print("</div>")
@@ -142,6 +144,13 @@ page_utils.print_navbar(title, url,
 			      page_name = "historical",
 			      label = "<i class='fas fa-lg fa-chart-area'></i>",
 			   },
+			   {
+			      hidden = not ntop.isClickHouseEnabled(),
+			      active = page == "db_search",
+			      page_name = "db_search",
+			      label = "<i class=\"fas fa-search-plus\" title='" .. i18n("db_explorer.historical_data_explorer") .. "'\"></i>",
+			      url = historical_flow_link
+			   },
 			   {
 			      hidden = not isAdministrator() or interface.isPcapDumpInterface(),
 			      active = page == "config",
@@ -152,7 +161,6 @@ page_utils.print_navbar(title, url,
 )
 
 if((page == "overview") or (page == nil)) then
-
    print("<table class=\"table table-bordered table-striped\">\n")
    print("<tr><th width=35%>"..i18n("mac_address").."</th><td> "..mac)
 
@@ -163,11 +171,10 @@ if((page == "overview") or (page == nil)) then
    end
 
    if mac_info["num_hosts"] > 0 then
-      print(" [ <A HREF=\"".. ntop.getHttpPrefix().."/lua/hosts_stats.lua?mac="..mac.."\">"..i18n("details.show_hosts").."</A> ]")
+      print("<br>[ <A HREF=\"".. ntop.getHttpPrefix().."/lua/hosts_stats.lua?mac="..mac.."\">"..i18n("details.show_hosts").."</A> ]")
    end
    
    print("</td>")
-
    print("<td>")
 
    print(discover.devtype2icon(mac_info.devtype) .. " ")
@@ -237,9 +244,11 @@ if((page == "overview") or (page == nil)) then
       print("</td><td></td></tr>\n")
    end
 
-   if(mac_info.fingerprint ~= "") then
-    print("<tr><th><A HREF=https://en.wikipedia.org/wiki/Device_fingerprint>DHCP Fingerprint</A> "..'<i class="fas fa-hand-o-up fa-lg" aria-hidden="true"></i>'
-	     .."</th><td colspan=2>"..mac_info.fingerprint.."</td></tr>\n")
+   if((mac_info.dhcp_fingerprint ~= nil) and (mac_info.dhcp_fingerprint ~= "")) then
+      print("<tr><th><A HREF=https://en.wikipedia.org/wiki/Device_fingerprint>DHCP Fingerprint</A> "..'<i class="fas fa-hand-o-up fa-lg" aria-hidden="true"></i>'
+	    .."</th><td colspan=2>"..mac_info.dhcp_fingerprint)
+      print_copy_button('dhcp_fingerprint', mac_info.dhcp_fingerprint)
+      print("</td></tr>\n")
    end
 
    if have_nedge then
