@@ -1,5 +1,5 @@
 --
--- (C) 2019-22 - ntop.org
+-- (C) 2019-24 - ntop.org
 --
 
 -- ##############################################
@@ -39,12 +39,19 @@ end
 -- #######################################################
 
 function multi_threshold_cross:describeConfig(hooks_conf)
-  local configured_threshold = hooks_conf.all.script_conf
+  local configured_threshold = {}
+  for _, configuration in pairs(hooks_conf or {}) do
+    if (configuration) and (table.len(configuration) > 0) then
+      configured_threshold = configuration.script_conf
+      break
+    end
+  end
+  
   local msg = ''
 
   for field, value in pairs(configured_threshold) do
      if(value.threshold ~= nil) then
-	msg = msg .. i18n(field) .. ": " .. value.threshold .. "%, "
+	      msg = msg .. i18n(field) .. ": " .. value.threshold .. "%, "
      end
   end
 
