@@ -70,67 +70,67 @@ end
 -- Migrate an old configuration format with a single lan item 
 -- for routing mode to a generic array compatible with bridge mode
 function system_config:_migrate_config(config)
-  for mode_name, mode_conf in pairs(config.globals.available_modes) do
-    if mode_conf["interfaces"] then
-      if mode_conf["interfaces"]["lan"] and
-         type(mode_conf["interfaces"]["lan"]) == "string" then
-        config.globals.available_modes[mode_name]["interfaces"]["lan"] = { 
-          config.globals.available_modes[mode_name]["interfaces"]["lan"]
-        }
+   for mode_name, mode_conf in pairs(config.globals.available_modes) do
+      if mode_conf["interfaces"] then
+         if mode_conf["interfaces"]["lan"] and
+            type(mode_conf["interfaces"]["lan"]) == "string" then
+            config.globals.available_modes[mode_name]["interfaces"]["lan"] = { 
+               config.globals.available_modes[mode_name]["interfaces"]["lan"]
+            }
+         end
+         if mode_conf["interfaces"]["wan"] and
+            type(mode_conf["interfaces"]["wan"]) == "string" then
+            config.globals.available_modes[mode_name]["interfaces"]["wan"] = { 
+               config.globals.available_modes[mode_name]["interfaces"]["wan"]
+            }
+         end
       end
-      if mode_conf["interfaces"]["wan"] and
-         type(mode_conf["interfaces"]["wan"]) == "string" then
-        config.globals.available_modes[mode_name]["interfaces"]["wan"] = { 
-          config.globals.available_modes[mode_name]["interfaces"]["wan"]
-        }
-      end
-    end
-  end
+   end
 
-  return config
+   return config
 end
 
 -- ##############################################
 
 -- Loads temporary configuration
 function system_config:_load_config(fname, guess)
-  local dirs = ntop.getDirs()
-  local config
+   local dirs = ntop.getDirs()
+   local config
 
-  local f = io.open(fname, "r")
+   local f = io.open(fname, "r")
 
-  if f ~= nil then
-    config = json.decode((f:read "*a"))
+   if f ~= nil then
+      config = json.decode((f:read "*a"))
 
-    if not config then
-       traceError(TRACE_ERROR,
-		  TRACE_CONSOLE,
-		  "Error while parsing configuration file " .. fname)
-    end
-    f:close()
-  elseif guess then
-    -- Load stock configuration if it exists
-    if ntop.exists(STOCK_CONF_FILE) then
-      traceError(TRACE_WARNING, TRACE_CONSOLE, "Installing stock configuration file " .. STOCK_CONF_FILE)
-      sys_utils.execShellCmd("mkdir -p " .. dirs.workingdir)
-      sys_utils.execShellCmd("cp " .. STOCK_CONF_FILE .. " " .. CONF_FILE)
-
-      return self:_load_config(fname, false)
-    else
-      config = self:_guess_config()
-
-      if dumpConfig(CONF_FILE, config) then
-        traceError(TRACE_NORMAL, TRACE_CONSOLE,
-                "Cannot open system configuration file " .. fname .. ", populating with defaults")
+      if not config then
+         traceError(TRACE_ERROR,
+                    TRACE_CONSOLE,
+                    "Error while parsing configuration file " .. fname)
       end
-    end
-  end
+      f:close()
+   elseif guess then
+      -- Load stock configuration if it exists
+      if ntop.exists(STOCK_CONF_FILE) then
+         traceError(TRACE_WARNING, TRACE_CONSOLE, "Installing stock configuration file " .. STOCK_CONF_FILE)
+         sys_utils.execShellCmd("mkdir -p " .. dirs.workingdir)
+         sys_utils.execShellCmd("cp " .. STOCK_CONF_FILE .. " " .. CONF_FILE)
 
-  sys_utils.setRealExec(config.globals and not config.globals.fake_exec)
+         return self:_load_config(fname, false)
+      else
+         config = self:_guess_config()
 
-  config = self:_migrate_config(config)
+         if dumpConfig(CONF_FILE, config) then
+            traceError(TRACE_NORMAL, TRACE_CONSOLE,
+                       "Cannot open system configuration file " .. fname .. ", populating with defaults")
+         end
+      end
+   end
 
-  return config
+   sys_utils.setRealExec(config.globals and not config.globals.fake_exec)
+
+   config = self:_migrate_config(config)
+
+   return config
 end
 
 -- ##############################################
@@ -159,18 +159,17 @@ end
 -- ##############################################
 
 function system_config:getConfHandler()
-  package.path = dirs.installdir .. "/scripts/lua/modules/conf_handlers/?.lua;" .. package.path
+   package.path = dirs.installdir .. "/scripts/lua/modules/conf_handlers/?.lua;" .. package.path
 
-  local info = ntop.getInfo(false)
-  local os = info.OS
-  local config_target = "network_ifaces"
+   local info = ntop.getInfo(false)
+   local os = info.OS
+   local config_target = "netplan"
 
-  if string.find(os, "Ubuntu 18%.") ~= nil or 
-     string.find(os, "Ubuntu 20%.") ~= nil then
-    config_target = "netplan"
-  end
+   if string.find(os, "Ubuntu 16%.") then
+      config_target = "network_ifaces"
+   end
 
-  return require(config_target)
+   return require(config_target)
 end
 
 -- ##############################################
@@ -223,7 +222,7 @@ end
 
 -- Returns the available modes
 function system_config:getAvailableModes()
-  return self.config.globals.available_modes
+   return self.config.globals.available_modes
 end
 
 -- ##############################################
@@ -231,14 +230,14 @@ end
 -- Returns the current operating mode
 -- nf_config and appliance_config override this
 function system_config:getOperatingMode()
-  return self.config.globals.operating_mode
+   return self.config.globals.operating_mode
 end
 
 -- ##############################################
 
 -- NOTE: do not use this, use the getOperatingMode instead
 function system_config:_getConfiguredOperatingMode()
-  return self.config.globals.operating_mode
+   return self.config.globals.operating_mode
 end
 
 -- ##############################################
@@ -265,14 +264,14 @@ end
 -- ##############################################
 
 function system_config.isFirstStart()
-  return ntop.exists(CONF_FILE_RELOAD) or ntop.getPref("ntopng.prefs.nedge_start") ~= "1"
+   return ntop.exists(CONF_FILE_RELOAD) or ntop.getPref("ntopng.prefs.nedge_start") ~= "1"
 end
 
 function system_config.setFirstStart(first_start)
-  ntop.setPref("ntopng.prefs.nedge_start", ternary(first_start, "0", "1"))
-  if not first_start and ntop.exists(CONF_FILE_RELOAD) then
-    os.remove(CONF_FILE_RELOAD)
-  end
+   ntop.setPref("ntopng.prefs.nedge_start", ternary(first_start, "0", "1"))
+   if not first_start and ntop.exists(CONF_FILE_RELOAD) then
+      os.remove(CONF_FILE_RELOAD)
+   end
 end
 
 -- ##############################################
@@ -290,24 +289,43 @@ end
 -- ##############################################
 
 function system_config:getUnusedInterfaces()
-  local mode = self:getOperatingMode()
-  if mode then
-    return self.config.globals.available_modes[mode].interfaces.unused or {}
-  else
-    return {}
-  end
+   local mode = self:getOperatingMode()
+   if mode then
+      return self.config.globals.available_modes[mode].interfaces.unused or {}
+   else
+      return {}
+   end
+end
+
+-- Get the WAN interfaces, based on the current operating mode
+function system_config:getWanInterfaces()
+   local mode = self:getOperatingMode()
+
+   return self.config.globals.available_modes[mode].interfaces.wan
+end
+
+-- Get the LAN interfaces, based on the current operating mode
+function system_config:getLanInterfaces()
+   local mode = self:getOperatingMode()
+
+   if mode == "bridging" then
+      return {self.config.globals.available_modes.bridging.name}
+   else
+      return self.config.globals.available_modes[mode].interfaces.lan
+   end
+end
+
+-- Get the first (if many) LAN interface, based on the current operating mode
+function system_config:getFirstLanInterface()
+   local lan_interfaces = self:getLanInterfaces()
+   return lan_interfaces[1]
 end
 
 -- Get the LAN interface, based on the current operating mode
 -- TODO when multiple LAN interfaces will be fully supported, this function will be removed
 function system_config:getLanInterface()
-  local mode = self:getOperatingMode()
-
-  if mode == "bridging" then
-    return self.config.globals.available_modes.bridging.name
-  else
-    return self.config.globals.available_modes[mode].interfaces.lan[1]
-  end
+   local lan_interfaces = self:getLanInterfaces()
+   return lan_interfaces[1]
 end
 
 -- Get all the interfaces, along with their roles
@@ -427,7 +445,7 @@ local function isInterfaceUp(ifname)
 end
 
 -- returns all the IP addresses associated to one interface
-function system_config.getAllInterfaceAddresses(ifname)
+function system_config.getInterfaceAddresses(ifname)
   local res = sys_utils.execShellCmd("ip addr show ".. ifname .." | grep -Po 'inet \\K[\\d.]+/[\\d]+'")
   local rv = {}
 
@@ -451,7 +469,7 @@ end
 -- available excluding the recovery IP
 function system_config:getInterfaceAddress(ifname)
   local recovery_conf = self:getLanRecoveryIpConfig()
-  local addresses = system_config.getAllInterfaceAddresses(ifname)
+  local addresses = system_config.getInterfaceAddresses(ifname)
 
   for _, addr in ipairs(addresses) do
     if addr.ip ~= recovery_conf.ip then
@@ -463,21 +481,35 @@ function system_config:getInterfaceAddress(ifname)
 end
 
 -- Get the LAN address, based on the current operating mode
-function system_config:getLocalIpv4Address(iface)
-  if not iface then
-     iface = self:getLanInterface()
-  end
-  local address = self:getInterfaceAddress(iface)
+function system_config:getLocalIpv4Addresses(ifname)
+  local ifaces = {}
+  local addresses = {}
 
-  if isEmptyString(address) then
-    if not self:isBridgeOverVLANTrunkEnabled() then
-      traceError(TRACE_WARNING, TRACE_CONSOLE, "Cannot get interface " .. iface .. " address")
+  if ifname then
+     ifaces = {ifname}
+  else
+     ifaces = self:getLanInterfaces()
+  end
+
+  for _, iface in ipairs(ifaces) do
+    local address = self:getInterfaceAddress(iface)
+    if not isEmptyString(address) then
+      table.insert(addresses, address)
     end
-    -- This is possibly wrong (e.g. in transparent bridge)
-    address = self.config.interfaces.configuration[iface].network.ip or "192.168.1.1"
   end
 
-  return address
+  if #addresses == 0 then
+    if not self:isBridgeOverVLANTrunkEnabled() then
+      traceError(TRACE_WARNING, TRACE_CONSOLE, "Cannot get local IP addresses")
+    end
+    if ifname and self.config.interfaces.configuration[ifname] then
+      -- This is possibly wrong (e.g. in transparent bridge)
+      local address = self.config.interfaces.configuration[ifname].network.ip or "192.168.1.1"
+      table.insert(addresses, address)
+    end
+  end
+
+  return addresses
 end
 
 -- ##############################################
@@ -527,26 +559,35 @@ end
 
 -- ##############################################
 
+-- Settings that do not require a reboot or self restart
+local runtime_sections = {
+    dhcp_server = 1,
+    shapers = 1,
+    gateways = 1,
+    routing = 1,
+    date_time = 1,
+    disabled_wans = 1,
+}
+
+-- Settings that require just a self restart
+local self_restart_sections = {
+    static_routes = 1,
+    captive_portal = 1,
+    policy = 1,
+    repeaters = 1,
+    port_forwarding = 1,
+}
+
 local function isRebootRequired(changed_sections)
    -- Always reboot on first start
    if system_config.isFirstStart() then
       return true
    end
 
-   local non_reboot_sections = {
-      dhcp_server = 1,
-      date_time = 1,
-      gateways = 1,
-      static_routes = 1,
-      routing = 1,
-      disabled_wans = 1,
-      shapers = 1,
-      port_forwarding = 1,
-   }
-
    for section in pairs(changed_sections) do
-      if non_reboot_sections[section] == nil then
-	 return true
+      if not runtime_sections[section] and
+         not self_restart_sections[section] then
+         return true -- reboot required
       end
    end
 
@@ -562,13 +603,10 @@ end
 -- ##############################################
 
 local function isSelfRestartRequired(changed_sections)
-   local self_restart_sections = {
-      static_routes = 1,
-   }
 
    for section in pairs(changed_sections) do
       if self_restart_sections[section] then
-	 return true
+         return true -- self restart required
       end
    end
 
@@ -618,35 +656,35 @@ function system_config:_handleChangedCommonSections(changed_sections, is_rebooti
      -- drift calculation must go before timezone/ntp changes as they will change the time making it invalid
      local drift
      if self.config.date_time.custom_date_set_req then
-	drift = os.time(os.date("!*t", os.time())) - (self.config.date_time.custom_date_set_req or 0)
-	self.config.date_time.custom_date_set_req = nil
+        drift = os.time(os.date("!*t", os.time())) - (self.config.date_time.custom_date_set_req or 0)
+        self.config.date_time.custom_date_set_req = nil
      end
 
      if self.config.date_time.timezone then
-	local system_timezone = tz_utils.TimeZone()
-	if self.config.date_time.timezone ~= system_timezone then
-	   sys_utils.execCmd("timedatectl set-timezone "..self.config.date_time.timezone)
-	   ntop.tzset()
-	end
+        local system_timezone = tz_utils.TimeZone()
+        if self.config.date_time.timezone ~= system_timezone then
+           sys_utils.execCmd("timedatectl set-timezone "..self.config.date_time.timezone)
+           ntop.tzset()
+        end
      end
      if self.config.date_time.ntp_sync.enabled then
-	sys_utils.execCmd("timedatectl set-ntp yes")
+        sys_utils.execCmd("timedatectl set-ntp yes")
      else
-	sys_utils.execCmd("timedatectl set-ntp no")
+        sys_utils.execCmd("timedatectl set-ntp no")
 
-	if self.config.date_time.custom_date then
-	   -- do not specify any timezone here as it is safe to take the one set for the system
-	   local custom_epoch = makeTimeStamp(self.config.date_time.custom_date)
-	   if drift then
-	      custom_epoch = custom_epoch + drift
-	   end
-	   -- use a format that timedatectl likes
-	   local timedatectl_fmt = os.date("%y-%m-%d %X", tonumber(custom_epoch))
-	   if timedatectl_fmt then
-	      sys_utils.execCmd('timedatectl set-time "'..timedatectl_fmt..'"')
-	   end
-	end
-	self.config.date_time.custom_date = nil
+        if self.config.date_time.custom_date then
+           -- do not specify any timezone here as it is safe to take the one set for the system
+           local custom_epoch = makeTimeStamp(self.config.date_time.custom_date)
+           if drift then
+              custom_epoch = custom_epoch + drift
+           end
+           -- use a format that timedatectl likes
+           local timedatectl_fmt = os.date("%y-%m-%d %X", tonumber(custom_epoch))
+           if timedatectl_fmt then
+              sys_utils.execCmd('timedatectl set-time "'..timedatectl_fmt..'"')
+           end
+        end
+        self.config.date_time.custom_date = nil
      end
   end
 end
@@ -666,6 +704,7 @@ function system_config:applyChanges()
 
   if is_rebooting then
     self:writeSystemFiles()
+    -- tprint("Reboot! (debug mode - reboot is disabled)")
     sys_utils.rebootSystem()
   elseif is_self_restarting then
     sys_utils.restartSelf()
@@ -674,18 +713,40 @@ end
 
 -- ##############################################
 
+function system_config:_getNetworkInterfaceConfig(iface, if_type)
+  local network_config = self.config.interfaces.configuration 
+
+  local if_config = network_config[iface]
+  if not if_config then
+    return {}
+  end
+
+  if if_type and if_type == 'lan' then
+    -- LAN interfaces are nor supposed to have gateway/nameserver
+    -- removing before dumping the interface/netplan configuration
+    -- in case they have been detected from an old configuration
+    if if_config.network and if_config.network.gateway then
+      if_config.network.gateway = nil
+    end
+    if if_config.network and if_config.network.nameservers then
+       if_config.network.nameservers = nil
+    end
+  end
+
+  return if_config
+end
+
 function system_config:_writeNetworkInterfaceConfig(f, iface, network_conf, bridge_ifaces)
   local dns_config = self:getDnsConfig()
   self.conf_handler.writeNetworkInterfaceConfig(f, iface, network_conf, dns_config, bridge_ifaces)
 end
 
 function system_config:_writeBridgeModeNetworkConfig(f)
-  local network_config = self.config.interfaces.configuration
   local mode_config = self.config.globals.available_modes["bridging"]
+  local br_name = mode_config.name
+  local br_config = self:_getNetworkInterfaceConfig(br_name)
 
   if ntop.isIoTBridge() then
-    local br_name = mode_config.name
-    local br_config = network_config[br_name]
 
     package.path = dirs.installdir .. "/scripts/lua/modules/conf_handlers/?.lua;" .. package.path
     local wireless = require("wireless")
@@ -719,51 +780,51 @@ function system_config:_writeBridgeModeNetworkConfig(f)
     end
 
     -- Bridge interface
-    local br_name = mode_config.name
-    local br_config = network_config[br_name]
     self:_writeNetworkInterfaceConfig(f, br_name, br_config.network, bridge_ifaces)
   end
 end
 
 function system_config:_writeRoutingModeNetworkConfig(f)
-  local network_config = self.config.interfaces.configuration
   local mode_config = self.config.globals.available_modes["routing"].interfaces
 
   -- Lan interface
   for _, iface in ipairs(mode_config.lan) do
-    self:_writeNetworkInterfaceConfig(f, iface, network_config[iface].network)
+    local if_config = self:_getNetworkInterfaceConfig(iface, 'lan')
+    self:_writeNetworkInterfaceConfig(f, iface, if_config.network)
   end
 
   -- Wan interfaces
   for _, iface in ipairs(mode_config.wan) do
-    self:_writeNetworkInterfaceConfig(f, iface, network_config[iface].network)
+    local if_config = self:_getNetworkInterfaceConfig(iface, 'wan')
+    self:_writeNetworkInterfaceConfig(f, iface, if_config.network)
   end
 end
 
 function system_config:_writeSinglePortModeInterfaces(f)
-  local network_config = self.config.interfaces.configuration
   local mode_config = self.config.globals.available_modes["single_port_router"]
 
   -- Lan interface
-  local lan_iface = self:getLanInterface()
-  self:_writeNetworkInterfaceConfig(f, lan_iface, network_config[lan_iface].network)
+  local lan_iface = self:getFirstLanInterface()
+  local lan_if_config = self:_getNetworkInterfaceConfig(lan_iface, 'lan')
+  self:_writeNetworkInterfaceConfig(f, lan_iface, lan_if_config.network)
 
   -- Wan interface
   local wan_iface = mode_config.interfaces.wan[1]
-  self:_writeNetworkInterfaceConfig(f, wan_iface, network_config[wan_iface].network)
+  local wan_if_config = self:_getNetworkInterfaceConfig(wan_iface, 'wan')
+  self:_writeNetworkInterfaceConfig(f, wan_iface, wan_if_config.network)
 end
 
 function system_config:_writePassiveModeNetworkConfig(f)
-  local network_config = self.config.interfaces.configuration
   local mode_config = self.config.globals.available_modes["passive"]
 
   -- Lan interface
   local lan_iface = mode_config.interfaces.lan[1]
-  self:_writeNetworkInterfaceConfig(f, lan_iface, network_config[lan_iface].network)
+  local lan_if_config = self:_getNetworkInterfaceConfig(lan_iface, 'lan')
+  self:_writeNetworkInterfaceConfig(f, lan_iface, lan_if_config.network)
 end
 
 function system_config:_getRecoveryInterface()
-  return self:getLanInterface() .. ":2"
+  return self:getFirstLanInterface() .. ":2"
 end
 
 function system_config:_writeNetworkInterfaces()
@@ -801,7 +862,10 @@ function system_config:writeSystemFiles()
   end
 
   self:_writeNetworkInterfaces()
-  system_config.setFirstStart(false)
+  
+  if system_config.isFirstStart() then
+    system_config.setFirstStart(false)
+  end
 end
 
 -- ##############################################
@@ -812,7 +876,7 @@ function system_config:isBridgeOverVLANTrunkEnabled()
   if mode == "bridging" then
      local bridge = self.config.globals.available_modes.bridging.name
      if self:getInterfaceMode(bridge) == "vlan_trunk" then
-	return true
+        return true
      end
   end
 
@@ -862,6 +926,14 @@ end
 
 -- Returns true if the interface is currently up and running
 local function isInterfaceLinkUp(ifname)
+
+  -- Check if vlan
+  local devnamevlan = string.split(ifname, "%.")
+  if devnamevlan and devnamevlan[1] then
+     ifname = devnamevlan[1]
+     -- vlan = devnamevlan[2] 
+  end
+
   local opstatus = sys_utils.execShellCmd("cat /sys/class/net/" .. ifname .. "/operstate 2>/dev/null")
   return starts(opstatus, "up")
 end
@@ -944,6 +1016,24 @@ end
 
 -- ##############################################
 
+function system_config:getInterfaceAlias(if_name, if_alias)
+  if self.config.interfaces.configuration[if_name] and
+     self.config.interfaces.configuration[if_name].alias then
+    return self.config.interfaces.configuration[if_name].alias
+  end
+  return if_name
+end
+
+function system_config:setInterfaceAlias(if_name, if_alias)
+  if self.config.interfaces.configuration[if_name] then
+    self.config.interfaces.configuration[if_name].alias = if_alias
+    return true
+  end
+  return false
+end
+
+-- ##############################################
+
 function system_config:setInterfaceMode(iface, mode)
   local net_config = self.config.interfaces.configuration[iface]
 
@@ -981,6 +1071,17 @@ end
 
 -- ##############################################
 
+function system_config:_enableDisableSmcrouteService(enable_smcroute)
+  local smcroute_service_utils = require "smcroute_service_utils"
+  if (enable_smcroute) then
+    smcroute_service_utils.startSmcrouteService()
+  else
+    smcroute_service_utils.stopSmcrouteService()
+  end
+end
+
+-- ##############################################
+
 function system_config.findDnsPreset(preset_name)
   require("prefs_utils")
 
@@ -1029,6 +1130,16 @@ end
 
 -- ##############################################
 
+function system_config:isMDNSRepeaterEnabled()
+  return self.config.globals.mdns_repeater
+end
+
+function system_config:setMDNSRepeaterEnabled(enabled)
+  self.config.globals.mdns_repeater = ternary(enabled, true, false)
+end
+
+-- ##############################################
+
 -- NOTE: can't rely on the main routing table when having multiple gateways!
 function system_config._interface_get_default_gateway(iface)
   local res = sys_utils.execShellCmd("ip route show | grep \"^default via\" | grep \"" .. iface .. "\"")
@@ -1077,10 +1188,10 @@ function system_config._split_dev_names(c, delimiter)
       local devs = split(cmd, "\n")
 
       if(delimiter == nil) then
-	 local rv = {}
+         local rv = {}
          for idx, dev in pairs(devs) do
-	   if not isEmptyString(dev) and allowedDevName(dev) then
-	      rv[#rv + 1] = dev
+           if not isEmptyString(dev) and allowedDevName(dev) then
+              rv[#rv + 1] = dev
            end
          end
 
@@ -1088,21 +1199,21 @@ function system_config._split_dev_names(c, delimiter)
       end
 
       for _,a in pairs(devs) do
-	 local p = split(a, delimiter)
+         local p = split(a, delimiter)
 
-	 if(p ~= nil) then
-	    local name = p[1]
-	    local addr = p[2]
+         if(p ~= nil) then
+            local name = p[1]
+            local addr = p[2]
 
-	    if(addr and name) then
-	       name = trimSpace(name)
-	       addr = trimSpace(addr)
+            if(addr and name) then
+               name = trimSpace(name)
+               addr = trimSpace(addr)
 
-	       if allowedDevName(name) then
-		  ret[name] = addr:gsub("%s+", "")
-	       end
-	    end
-	 end
+               if allowedDevName(name) then
+                  ret[name] = addr:gsub("%s+", "")
+               end
+            end
+         end
       end
    end
 
@@ -1217,11 +1328,14 @@ end
 
 -- Verify that we are the only to manage the network interfaces
 function system_config:verifyNetworkInterfaces()
+  local lan_ifaces_names = self:getLanInterfaces()
   local lan_ifaces = self:getPhysicalLanInterfaces()
   local wan_ifaces = self:getPhysicalWanInterfaces()
-  local lan_iface = self:getLanInterface()
-  local ifaces = {[lan_iface] = 1}
+  local ifaces = {}
 
+  for _, iface in ipairs(lan_ifaces_names) do
+    ifaces[iface] = 1
+  end
   for _, iface in pairs(lan_ifaces) do
     ifaces[iface] = 1
   end
