@@ -1,5 +1,5 @@
 --
--- (C) 2013-23 - ntop.org
+-- (C) 2013-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -16,30 +16,29 @@ local host = _GET["host"]
 local scan_type = _GET["scan_type"]
 local delete_all_scan_hosts = _GET["delete_all_scan_hosts"]
 
+tprint(host)
+tprint(scan_type)
+tprint(delete_all_scan_hosts)
+tprint("--------")
+
 if not delete_all_scan_hosts then
-    if isEmptyString(host) or isEmptyString(scan_type) then
-        rest_utils.answer(rest_utils.consts.err.bad_content)
-    end
+if isEmptyString(host) or isEmptyString(scan_type) then
+    rest_utils.answer(rest_utils.consts.err.bad_content)
 end
-
-
-local function delete_host_to_scan(ip, scan_type) 
-    return vs_utils.delete_host_to_scan(ip, scan_type, false) 
-end
-
-local function delete_all_hosts_to_scan()
-    return vs_utils.delete_host_to_scan(nil, nil, true) 
 end
 
 local del_result = 0
-if not delete_all_scan_hosts then
-    del_result = delete_host_to_scan(host,scan_type)
+
+if delete_all_scan_hosts then
+-- Delete all hosts to scan
+del_result = vs_utils.delete_host_to_scan(nil, nil, true)
 else 
-    del_result = delete_all_hosts_to_scan()
+-- Only delete a host and a scan type
+del_result = vs_utils.delete_host_to_scan(host, scan_type, false)
 end
 
 if del_result then
-    rest_utils.answer(rest_utils.consts.success.ok)
+rest_utils.answer(rest_utils.consts.success.ok)
 else
-    rest_utils.answer(rest_utils.consts.err.internal_error)
+rest_utils.answer(rest_utils.consts.err.internal_error)
 end
