@@ -1,5 +1,5 @@
 --
--- (C) 2013-21 - ntop.org
+-- (C) 2013-24 - ntop.org
 --
 local dirs = ntop.getDirs()
 package.path = dirs.installdir .. "/scripts/lua/modules/?.lua;" .. package.path
@@ -20,14 +20,27 @@ local rc = rest_utils.consts.success.ok
 local res = {}
 
 local ifid = _GET["ifid"]
-local format = _GET["format"] or "json"
+local format = _GET["format"]
 local epoch_begin = _GET["epoch_begin"]
 local epoch_end = _GET["epoch_end"]
-local no_html = (format == "txt")
+local telemetry = toboolean(_GET["telemetry"])
+
+local no_html = false
 local download = false
 
-if ntop.isClickHouseEnabled() and no_html then
-    download = true
+if not format then
+   -- GUI request - return formatted json
+   format = "json"
+else
+   -- txt or (plain) json - return unformatted data
+   no_html = true
+   if format == "txt" then
+      if ntop.isClickHouseEnabled() then
+         download = true
+      end
+   else
+      format = "json"
+   end
 end
 
 if not auth.has_capability(auth.capabilities.alerts) then
@@ -52,14 +65,24 @@ if ((epoch_begin ~= nil) and (epoch_end ~= nil)) then
     end
 end
 
-if not download then
-    local alerts, recordsFiltered, info = flow_alert_store:select_request(nil, "*")
 
-    for _, _value in ipairs(alerts or {}) do
-        res[#res + 1] = flow_alert_store:format_record(_value, no_html)
+
+if not download then
+
+    -- telemetry == true retrieves all the alerts in the selected temporal range
+    local alerts, recordsFiltered, info = flow_alert_store:select_request(nil, "*", download, false, telemetry)
+
+    if (telemetry == true) then
+        for _, _value in ipairs(alerts or {}) do
+            res[#res + 1] = flow_alert_store:format_record_telemetry(_value)
+        end
+    else
+        for _, _value in ipairs(alerts or {}) do
+            res[#res + 1] = flow_alert_store:format_record(_value, no_html)
+        end
     end
 
-    if no_html then
+    if format == "txt" then
         res = flow_alert_store:to_csv(res)
         rest_utils.vanilla_payload_response(rc, res, "text/csv")
     else
