@@ -1,5 +1,5 @@
 --
--- (C) 2013-23 - ntop.org
+-- (C) 2013-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -23,12 +23,16 @@ local res = {}
 local interfaces = interface.getIfNames()
 
 for ifid, ifname in pairs(interfaces) do
-  local custom_name = shortenCollapse(getHumanReadableInterfaceName(ifname))
+  interface.select(ifname)
+  local custom_name = getHumanReadableInterfaceName(ifname)
 
   res[#res + 1] = {
     ifid = tonumber(ifid),
     ifname = ifname,
-    name = custom_name
+    name = custom_name,
+    is_packet_interface = interface.isPacketInterface(),
+    is_pcap_interface = interface.isPcapDumpInterface(),
+    is_zmq_interface = interface.isZMQInterface()
   }
 end
 
