@@ -1,5 +1,5 @@
 --
--- (C) 2013-23 - ntop.org
+-- (C) 2013-24 - ntop.org
 --
 
 local dirs = ntop.getDirs()
@@ -13,6 +13,7 @@ local internals_utils = require "internals_utils"
 local cpu_utils = require("cpu_utils")
 local ts_utils = require "ts_utils"
 local graph_utils = require("graph_utils")
+local format_utils = require("format_utils")
 
 local ts_creation = script_manager.systemTimeseriesEnabled()
 
@@ -38,7 +39,7 @@ page_utils.print_navbar(title, url,
 			      label = "<i class=\"fas fa-home fa-lg\"></i>",
 			   },
 			   {
-			      hidden = not ts_creation,
+			      hidden = not ts_creation or not ntop.isLinux(),
 			      active = page == "historical",
 			      page_name = "historical",
 			      label = "<i class='fas fa-lg fa-chart-area'></i>",
@@ -48,6 +49,12 @@ page_utils.print_navbar(title, url,
 			      page_name = "internals",
 			      label = "<i class=\"fas fa-lg fa-wrench\"></i>",
 			   },
+			   {
+			      hidden = not info.ntopcloud,
+			      active = page == "ntopcloud",
+			      page_name = "ntopcloud",
+			      label = "<i class=\"fas fa-lg fa-cloud\"></i>",
+			   },
 			}
 )
 
@@ -88,8 +95,8 @@ if(page == "overview") then
    if system_host_stats["mem_total"] ~= nil then
     local ram_used = system_host_stats["mem_used"]
     local ram_used_ratio = i18n("ram_used") .. ": " .. tostring(round((ram_used / system_host_stats["mem_total"]) * 100 * 100) / 100) .. "%";
-    local ram_available = i18n("ram_available") .. ": " .. bytesToSize((system_host_stats["mem_total"] - ram_used) * 1024)
-    local ram_total = i18n("ram_total") .. ": " .. bytesToSize(system_host_stats["mem_total"] * 1024)
+    local ram_available = i18n("ram_available") .. ": " .. format_utils.bytesToSize((system_host_stats["mem_total"] - ram_used) * 1024)
+    local ram_total = i18n("ram_total") .. ": " .. format_utils.bytesToSize(system_host_stats["mem_total"] * 1024)
 
     print("<tr><th nowrap>"..i18n("about.ram_memory").."</th><td><span id='ram-used'>" .. ram_used_ratio .. " / " .. ram_available .. " / " .. ram_total .. "</span></td></tr>\n")
    end
@@ -99,9 +106,10 @@ if(page == "overview") then
    if(info.pid ~= nil) then
       print("<tr><th nowrap>PID (Process ID)</th><td>"..info.pid.."</td></tr>\n")
    end
+
    if system_host_stats["mem_ntopng_resident"] ~= nil then
       local chart_available = ts_utils.exists("process:resident_memory", {ifid = getSystemInterfaceId()})
-      print("<tr><th nowrap>"..i18n("about.ram_memory").." "..ternary(chart_available, "<A HREF='"..url.."&page=historical&ts_schema=process:resident_memory'><i class='fas fa-chart-area fa-sm'></i></A>", "").."</th><td><span id='ram-process-used'>" .. i18n("ram_used") .. ": " .. bytesToSize(system_host_stats["mem_ntopng_resident"] * 1024) .. "</span></td></tr>\n")
+      print("<tr><th nowrap>"..i18n("about.ram_memory").." "..ternary(chart_available, "<A HREF='"..url.."&page=historical&ts_schema=process:resident_memory'><i class='fas fa-chart-area fa-sm'></i></A>", "").."</th><td><span id='ram-process-used'>" .. i18n("ram_used") .. ": " .. format_utils.bytesToSize(system_host_stats["mem_ntopng_resident"] * 1024) .. "</span></td></tr>\n")
    end
 
    if areAlertsEnabled() then
@@ -118,7 +126,16 @@ if(page == "overview") then
    print("</td></tr>")
 
    if not info.oem then
-      print("<tr><th nowrap>"..i18n("about.last_log").."</th><td><div class='scrollable-log'><code>\n")
+      print("<tr><th nowrap>"..i18n("about.last_log"))
+
+      if not ntop.isWindows() and not ntop.isFreeBSD() then
+         local days = 1
+         print(" <A HREF='" .. ntop.getHttpPrefix() .. "/lua/rest/v2/get/system/logs.lua?days="..days.."'><i class='fas fa-download fa-sm' title='" .. i18n("download_days", { days = days }) .. "'></i></a>")
+      end
+
+      print("</th>")
+      print("<td><div class='scrollable-log'><code>\n")
+
       for i=0,32 do
          msg = ntop.listIndexCache("ntopng.trace", i)
          if(msg ~= nil) then
@@ -174,6 +191,39 @@ elseif(page == "historical" and ts_creation) then
    graph_utils.drawNewGraphs({ ifid = interface.getId()})
 elseif page == "internals" then
    internals_utils.printInternals(getSystemInterfaceId(), false --[[ hash tables ]], true --[[ periodic activities ]], true --[[ checks]], true --[[ queues --]])
+elseif page == "ntopcloud" then
+   local cloud = info.ntopcloud
+
+   if(cloud ~= nil) then
+      local stats = cloud.stats
+      
+      print [[
+      <div class='table-responsive-lg table-responsive-md'>
+      <table class="table table-bordered table-striped">
+      ]]
+   
+      print("<tr><th>Account Id</th><td nowrap>".. cloud.account_id .."</td></tr>\n")
+      print("<tr><th>Instance Name</th><td nowrap>".. cloud.my_topic .."</td></tr>\n")
+      print("<tr><th>Cloud Node</th><td nowrap>".. cloud.ntopcloud.server .." [")
+      if(cloud.ntopcloud.use_tls) then print("TLS") else print("PlainText") end print("]")
+      if(cloud.ntopcloud.connected) then
+	 print(' <span class="badge text-bg-success">'..i18n("connected")..'</span>')
+      else
+	 print(' <span class="badge text-bg-warning">'..i18n("disconnected")..'</span>')
+      end
+      print("</td></tr>\n")
+      print("<tr><th colspan=2>Connections</th></tr>\n")
+      print("<tr><th>First Connected</th><td nowrap>".. format_utils.formatEpoch(stats.first_connect) .."</td></tr>\n")
+      print("<tr><th>Last Connected</th><td nowrap>".. format_utils.formatEpoch(stats.last_connect) .." [".. secondsToTime(os.time() - stats.last_connect).." "..i18n("details.ago").."]</td></tr>\n")
+      print("<tr><th colspan=2>Message Statistics</th></tr>\n")
+      print("<tr><th>Connect</th><td nowrap>".. format_utils.formatValue(stats.num_connect) .."</td></tr>\n")
+      print("<tr><th>Disconnect</th><td nowrap>".. format_utils.formatValue(stats.num_disconnect) .."</td></tr>\n")
+      print("<tr><th>Ping</th><td nowrap>".. format_utils.formatValue(stats.num_ping) .."</td></tr>\n")
+      print("<tr><th>Subscribe</th><td nowrap>".. format_utils.formatValue(stats.num_subscribe) .."</td></tr>\n")
+      print("<tr><th>Errors</th><td nowrap>".. format_utils.formatValue(stats.num_errors) .."</td></tr>\n")
+      
+      print("</table>\n")
+   end
 end
 
 -- #######################################################
