@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -44,10 +44,19 @@ void CategoryCounter::lua(NetworkInterface *iface, lua_State *vm,
       iface->get_ndpi_category_name((ndpi_protocol_category_t)category_id);
 
   if (!tsLua) {
+    u_int64_t bytes_total = bytes.getTotal();
     lua_newtable(vm);
 
+    if (bytes_total > INT64_MAX) {
+      ntop->getTrace()->traceEvent(TRACE_ERROR, "bytes (%llu/%llu/%llu) for category %s (%d) exceeds "
+                                   "max (%llu) allowed for ts",
+                                   bytes_total, bytes.getSent(), bytes.getRcvd(),
+                                   name, (int) category_id, INT64_MAX);
+      bytes_total = INT64_MAX;
+    }
+
     lua_push_uint64_table_entry(vm, "category", category_id);
-    lua_push_uint64_table_entry(vm, "bytes", bytes.getTotal());
+    lua_push_uint64_table_entry(vm, "bytes", bytes_total);
     lua_push_uint64_table_entry(vm, "bytes.sent", bytes.getSent());
     lua_push_uint64_table_entry(vm, "bytes.rcvd", bytes.getRcvd());
     lua_push_uint64_table_entry(vm, "duration", duration);
