@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -76,13 +76,19 @@ FlowAlertsLoader::FlowAlertsLoader() {
                 LateralMovementAlert::getDefaultScore());
   registerAlert(PeriodicityChangedAlert::getClassType(),
                 PeriodicityChangedAlert::getDefaultScore());
+#endif
+#if defined(NTOPNG_PRO)
+  registerAlert(AccessControlListAlert::getClassType(),
+                AccessControlListAlert::getDefaultScore());
 #endif
   registerAlert(LongLivedFlowAlert::getClassType(),
                 LongLivedFlowAlert::getDefaultScore());
   registerAlert(LowGoodputFlowAlert::getClassType(),
                 LowGoodputFlowAlert::getDefaultScore());
+#if defined(HAVE_NEDGE)
   registerAlert(NedgeBlockedFlowAlert::getClassType(),
                 NedgeBlockedFlowAlert::getDefaultScore());
+#endif
   registerAlert(NotPurgedAlert::getClassType(),
                 NotPurgedAlert::getDefaultScore());
   registerAlert(RareDestinationAlert::getClassType(),
@@ -127,6 +133,10 @@ FlowAlertsLoader::FlowAlertsLoader() {
                 BlacklistedServerContactAlert::getDefaultScore());
   registerAlert(TCPFlowResetAlert::getClassType(), 
                 TCPFlowResetAlert::getDefaultScore());
+  registerAlert(HostPolicyAlert::getClassType(),
+                HostPolicyAlert::getDefaultScore());
+  registerAlert(QoEDegradedAlert::getClassType(),
+                QoEDegradedAlert::getDefaultScore());
 }
 
 /* **************************************************** */
