@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -33,23 +33,42 @@ FlowHash::FlowHash(NetworkInterface *_iface, u_int _num_hashes,
 
 static u_int16_t max_num_loops = 0;
 
-Flow *FlowHash::find(Mac *src_mac, Mac *dst_mac, IpAddress *src_ip,
+Flow* FlowHash::find(Mac *src_mac, Mac *dst_mac, IpAddress *src_ip,
                      IpAddress *dst_ip, u_int16_t src_port, u_int16_t dst_port,
                      u_int16_t vlanId, u_int16_t observation_point_id,
                      u_int32_t private_flow_id, u_int8_t protocol,
                      const ICMPinfo *const icmp_info, bool *src2dst_direction,
                      bool is_inline_call, Flow **unswapped_flow) {
-  u_int32_t hash = ((src_ip->key() + dst_ip->key() + (icmp_info ? icmp_info->key() : 0) +
-		     private_flow_id + src_port + dst_port + vlanId + protocol) %
-		    num_hashes);
-  Flow *head = (Flow *)table[hash];
+  u_int32_t hash;
+  Flow *head;
   u_int16_t num_loops = 0;
 
+  hash = src_ip->key() + dst_ip->key() +
+    (icmp_info ? icmp_info->key() : 0) +
+    private_flow_id +
+    src_port + dst_port + vlanId +  protocol;
+
+#ifdef USE_MAC_IN_KEY_WITH_DHCP
+  if((src_ip->key() == 0) && (dst_ip->key() == 0xFFFFFFFF)) {
+    /* Add the MAC address of the source host (dst_mac is not necessary as it's FF:FF:FF:FF:FF:FF) */
+    if(src_mac != NULL) hash += src_mac->key();
+  }
+#endif
+
+  hash %= num_hashes;
+
+  head = (Flow *)table[hash];
+
   *unswapped_flow = NULL;
 
 #if 0
-  ntop->getTrace()->traceEvent(TRACE_NORMAL, "%u:%u / %u:%u [icmp: %u][key: %u][icmp info key: %u][head: 0x%x]",
-			       src_ip->key(), src_port, dst_ip->key(), dst_port, icmp_info ? 1 : 0, hash, icmp_info ? icmp_info->key() : 0, head);
+  ntop->getTrace()->traceEvent(TRACE_NORMAL, "[%s] %u:%u / %u:%u [icmp key: %u]"
+			       "[priv flow id: %u][vlan: %u][protocol: %u]"
+			       "[hash: %u][head: 0x%x]",
+			       iface->get_name(),
+			       src_ip->key(), ntohs(src_port), dst_ip->key(), ntohs(dst_port),
+			       icmp_info ? icmp_info->key() : 0,
+			       private_flow_id, vlanId, protocol, hash, head);
 #endif
 
   if (!head) return (NULL);
@@ -62,8 +81,7 @@ Flow *FlowHash::find(Mac *src_mac, Mac *dst_mac, IpAddress *src_ip,
                     vlanId, observation_point_id, private_flow_id, protocol,
                     icmp_info, src2dst_direction)) {
       if (num_loops > max_num_loops) {
-        ntop->getTrace()->traceEvent(
-            TRACE_INFO, "DEBUG: [Num loops: %u][hashId: %u]", num_loops, hash);
+        ntop->getTrace()->traceEvent(TRACE_INFO, "DEBUG: [Num loops: %u][hashId: %u]", num_loops, hash);
         max_num_loops = num_loops;
       }
 
@@ -83,8 +101,7 @@ Flow *FlowHash::find(Mac *src_mac, Mac *dst_mac, IpAddress *src_ip,
   }
 
   if (num_loops > max_num_loops) {
-    ntop->getTrace()->traceEvent(
-        TRACE_INFO, "DEBUG: [Num loops: %u][hashId: %u]", num_loops, hash);
+    ntop->getTrace()->traceEvent(TRACE_INFO, "DEBUG: [Num loops: %u][hashId: %u]", num_loops, hash);
     max_num_loops = num_loops;
   }
 
