@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,51 +31,49 @@
 /* *************************************** */
 
 Geolocation::Geolocation() {
+  bool mmdbs_asn_ok = false, mmdbs_city_ok = false;
+  char *custom_dir = ntop->getPrefs()->getCustomGeoIPDir();
+  
   if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+
+  if(custom_dir == NULL) custom_dir = (char*)".";
   
 #ifdef HAVE_MAXMINDDB
   char docs_path[MAX_PATH];
   const char *lookup_paths[] = {
+    custom_dir,
 #ifndef WIN32
-    "/var/lib/GeoIP",  // `geoipupdate` default install dir on Ubuntu 16,18 and
-                       // Debian 10,9
-    "/usr/share/GeoIP",  // `geoipupdate` default install dir on Ubuntu 14 and
-                         // Centos 7,8
+    "/var/lib/GeoIP",    // `geoipupdate` default install dir on Ubuntu 16,18 and Debian 10,9
+    "/usr/share/GeoIP",  // `geoipupdate` default install dir on Ubuntu 14 and Centos 7,8
 #if defined(__FreeBSD__)
-    "/usr/local/share/ntopng/httpdocs/geoip/",  // ntopng-data default install
-                                                // dir
+    "/usr/local/share/ntopng/httpdocs/geoip/",  // ntopng-data default install dir
 #else
     "/usr/share/ntopng/httpdocs/geoip/",  // ntopng-data default install dir
 #endif
 #endif
     docs_path
   };
-  bool mmdbs_asn_ok = false, mmdbs_city_ok = false;
 
   mmdbs_ok = false;
 
-  snprintf(docs_path, sizeof(docs_path), "%s/geoip",
-           ntop->getPrefs()->get_docs_dir());
+  snprintf(docs_path, sizeof(docs_path), "%s/geoip", ntop->getPrefs()->get_docs_dir());
   ntop->fixPath(docs_path);
 
-  for (u_int i = 0;
-       i < sizeof(lookup_paths) / sizeof(lookup_paths[0]) && !mmdbs_ok; i++) {
+  for (u_int i = 0; i < sizeof(lookup_paths) / sizeof(lookup_paths[0]) && !mmdbs_ok; i++) {
     DIR *dirp;
     struct dirent *dp;
 
     /* Let's try with MaxMind files DBs:
      * https://dev.maxmind.com/geoip/geoipupdate/ */
     if (!mmdbs_asn_ok)
-      mmdbs_asn_ok =
-          loadGeoDB(lookup_paths[i], "GeoLite2-ASN.mmdb", &geo_ip_asn_mmdb);
+      mmdbs_asn_ok = loadGeoDB(lookup_paths[i], "GeoLite2-ASN.mmdb", &geo_ip_asn_mmdb);
+
     if (!mmdbs_city_ok)
-      mmdbs_city_ok =
-          loadGeoDB(lookup_paths[i], "GeoLite2-City.mmdb", &geo_ip_city_mmdb);
+      mmdbs_city_ok = loadGeoDB(lookup_paths[i], "GeoLite2-City.mmdb", &geo_ip_city_mmdb);
 
     if (mmdbs_asn_ok && mmdbs_city_ok) {
-      ntop->getTrace()->traceEvent(
-          TRACE_NORMAL,
-          "Using geolocation provided by MaxMind (https://maxmind.com)");
+      ntop->getTrace()->traceEvent(TRACE_NORMAL,
+				   "Using geolocation provided by MaxMind (https://maxmind.com)");
       mmdbs_ok = true;
       break;
     }
@@ -192,9 +190,10 @@ Geolocation::~Geolocation() {
 
 /* *************************************** */
 
-void Geolocation::getAS(IpAddress *addr, u_int32_t *asn, char **asname) {
+bool Geolocation::getAS(IpAddress *addr, u_int32_t *asn, char **asname) {
   if (asn) *asn = 0;
   if (asname) *asname = NULL;
+  bool ret = false; 
 
 #ifdef HAVE_MAXMINDDB
   sockaddr *sa = NULL;
@@ -203,7 +202,7 @@ void Geolocation::getAS(IpAddress *addr, u_int32_t *asn, char **asname) {
   MMDB_lookup_result_s result;
   MMDB_entry_data_s entry_data;
 
-  if (!mmdbs_ok) return;
+  if (!mmdbs_ok) return(false);
 
   if (addr && addr->get_sockaddr(&sa, &sa_len)) {
     result = MMDB_lookup_sockaddr(&geo_ip_asn_mmdb, sa, &mmdb_error);
@@ -234,23 +233,24 @@ void Geolocation::getAS(IpAddress *addr, u_int32_t *asn, char **asname) {
           }
         }
       }
+
+      ret = true;
     } else
       ntop->getTrace()->traceEvent(TRACE_ERROR, "Lookup failed [%s]",
                                    MMDB_strerror(mmdb_error));
-
-    free(sa);
   }
+  if (sa) free(sa);
 #endif
 
-  return;
+  return ret;
 }
 
 /* *************************************** */
 
-void Geolocation::getInfo(IpAddress *addr, char **continent_code,
+bool Geolocation::getInfo(IpAddress *addr, char **continent_code,
                           char **country_code, char **city, float *latitude,
                           float *longitude) {
-  if ((!addr) || (addr->getVersion() == 0)) return;
+  if ((!addr) || (addr->getVersion() == 0)) return(false);
 
   if (continent_code) *continent_code = strdup((char *)UNKNOWN_CONTINENT);
   if (country_code) *country_code = strdup((char *)UNKNOWN_COUNTRY);
@@ -258,12 +258,14 @@ void Geolocation::getInfo(IpAddress *addr, char **continent_code,
   if (latitude) *latitude = 0;
   if (longitude) *longitude = 0;
 
+  bool ret = false;
+
 #ifdef HAVE_MAXMINDDB
   sockaddr *sa = NULL;
   ssize_t sa_len;
   char *cdata;
 
-  if (!mmdbs_ok) return;
+  if (!mmdbs_ok) return(false);
 
   if (addr && addr->get_sockaddr(&sa, &sa_len)) {
     int mmdb_error, status;
@@ -335,7 +337,7 @@ void Geolocation::getInfo(IpAddress *addr, char **continent_code,
       }
     }
 
-    free(sa);
+    ret = true;
   } else {
     char buf[64];
 
@@ -345,9 +347,10 @@ void Geolocation::getInfo(IpAddress *addr, char **continent_code,
         addr ? addr : 0, addr ? addr->print(buf, sizeof(buf)) : "",
         addr ? addr->getVersion() : 0);
   }
+  if (sa) free(sa);
 #endif
 
-  return;
+  return ret;
 }
 
 /* *************************************** */
