@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2015-24 - ntop.org
+ * (C) 2015-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -567,6 +567,33 @@ bool HostPools::findIpPool(IpAddress *ip, u_int16_t vlan_id,
 
 /* *************************************** */
 
+u_int16_t HostPools::getCurrentHostPoolsNumber() {
+  HostPoolStats *hps;
+  u_int16_t pools_number = 0;
+  for (int i = 0; i < MAX_NUM_HOST_POOLS; i++) {
+    if((hps = stats[i])) {
+      pools_number = pools_number + 1;
+    }
+  }
+  return pools_number;
+}
+
+/* *************************************** */
+
+u_int32_t HostPools::getCurrentMaxHostPoolsMembers() {
+  HostPoolStats *hps;
+  u_int32_t max_members_number = 0;
+  /* Starting from 1, because 0 is the default host pool */
+  for (int i = 1; i < MAX_NUM_HOST_POOLS; i++) {
+    if((hps = stats[i])) {
+      max_members_number += getNumPoolHosts(i);
+    }
+  }
+  return max_members_number;
+}
+
+/* *************************************** */
+
 u_int16_t HostPools::getPool(Host *h, bool *mac_match) {
   u_int16_t pool_id;
   ndpi_patricia_node_t *node;
@@ -616,4 +643,4 @@ u_int16_t HostPools::getPoolByName(const char *pool_name) {
   }
 
   return NO_HOST_POOL_ID;
-}
+}
\ No newline at end of file
