@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -41,6 +41,13 @@ IpAddress::IpAddress(const IpAddress &ipa) {
 
 /* ******************************************* */
 
+IpAddress::IpAddress(const struct ipAddress ipa) {
+  memcpy(&addr, &ipa, sizeof(ipa));
+  compute_key();
+}
+
+/* ******************************************* */
+
 void IpAddress::set(const char *const sym_addr) {
   if (sym_addr == NULL) return;
 
@@ -77,12 +84,12 @@ void IpAddress::set(union usa *ip) {
 void IpAddress::reloadBlacklist(ndpi_detection_module_struct *ndpi_struct) {
   char ipbuf[64];
   char *ip_str = print(ipbuf, sizeof(ipbuf));
-  ndpi_protocol_category_t category;
+  u_int16_t id;
   
   if(ndpi_get_custom_category_match(ndpi_struct,
 				    ip_str, strlen(ip_str),
-				    &category) == 0) {
-    category = (ndpi_protocol_category_t)(category & 0xFF); /* See Ntop::nDPILoadHostnameCategory */
+				    (ndpi_protocol_category_t*)&id) == 0) {
+    ndpi_protocol_category_t category = (ndpi_protocol_category_t)(((u_int16_t)id) & 0xFF); /* See Ntop::nDPILoadHostnameCategory */
     
     if(category == CUSTOM_CATEGORY_MALWARE)
       addr.blacklistedIP = true;
@@ -110,7 +117,7 @@ bool IpAddress::isEmpty() const {
 
 void IpAddress::checkIP() {
   u_int32_t a;
-  int16_t local_network_id;
+  int32_t local_network_id;
   u_int32_t nmask;
   u_int8_t nmask_bits;
 
@@ -156,7 +163,8 @@ void IpAddress::checkIP() {
     else if (ntop->isLocalAddress(AF_INET, &addr.ipType.ipv4, &local_network_id,
                                   &nmask_bits)) {
       addr.localIP = true;
-      if (nmask_bits > 0 &&
+      if (!ntop->isBroadcastIPDisabled() &&
+          nmask_bits > 0 &&
           nmask_bits < 31) { /* /0 no mask, /32 is just an host, /31 is a
                                 point-to-point */
         nmask = ~((1 << (32 - nmask_bits)) - 1);
@@ -287,7 +295,7 @@ bool IpAddress::isLocalHost() const {
 
 /* ******************************************* */
 
-bool IpAddress::isLocalHost(int16_t *network_id) const {
+bool IpAddress::isLocalHost(int32_t *network_id) const {
   bool local = false;
 
   if (addr.multicastIP || addr.broadcastIP) return (true);
@@ -452,3 +460,14 @@ void IpAddress::dump() {
   ntop->getTrace()->traceEvent(TRACE_NORMAL, "%s [Local: %s][SystemHost: %s]",
                                print(buf, sizeof(buf)), local, system);
 }
+
+/* ****************************** */
+
+void IpAddress::fillIP(ndpi_ip_addr_t *ip_addr) {
+  memset(ip_addr, 0, sizeof(ndpi_ip_addr_t));
+
+  if(addr.ipVersion == 4)
+    ip_addr->ipv4 = addr.ipType.ipv4;
+  else
+    memcpy(&ip_addr->ipv6, get_ipv6(), sizeof(struct ndpi_in6_addr));
+}
