@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,12 +23,16 @@
 
 /* *************************************** */
 
-LocalHost::LocalHost(NetworkInterface *_iface, int32_t _iface_idx,
-		     Mac *_mac, u_int16_t _vlanId,
-                     u_int16_t _observation_point_id, IpAddress *_ip)
+LocalHost::LocalHost(NetworkInterface *_iface, int32_t _iface_idx, Mac *_mac,
+                     u_int16_t _vlanId, u_int16_t _observation_point_id,
+                     IpAddress *_ip)
   : Host(_iface, _iface_idx, _mac, _vlanId, _observation_point_id, _ip),
-    contacted_server_ports(CONST_MAX_NUM_QUEUED_PORTS, "localhost-serverportsproto"), usedPorts(this) {
-  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+    contacted_server_ports(CONST_MAX_NUM_QUEUED_PORTS, "localhost-serverportsproto"),
+    usedPorts(this) {
+  tcp_fingerprint = NULL;
+
+  if (trace_new_delete)
+    ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
 
 #ifdef LOCALHOST_DEBUG
   char buf[48];
@@ -42,31 +46,39 @@ LocalHost::LocalHost(NetworkInterface *_iface, int32_t _iface_idx,
 /* *************************************** */
 
 LocalHost::LocalHost(NetworkInterface *_iface, int32_t _iface_idx,
-		     char *ipAddress, u_int16_t _vlanId,
-		     u_int16_t _observation_point_id)
+                     char *ipAddress, u_int16_t _vlanId,
+                     u_int16_t _observation_point_id)
   : Host(_iface, _iface_idx, ipAddress, _vlanId, _observation_point_id),
-  contacted_server_ports(CONST_MAX_NUM_QUEUED_PORTS, "localhost-serverportsproto"), usedPorts(this) {
-  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+    contacted_server_ports(CONST_MAX_NUM_QUEUED_PORTS, "localhost-serverportsproto"),
+    usedPorts(this) {
+  if (trace_new_delete)
+    ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
   initialize();
 }
 
 /* *************************************** */
 
 LocalHost::~LocalHost() {
-  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
-  addInactiveData();
+  if (trace_new_delete)
+    ntop->getTrace()->traceEvent(TRACE_NORMAL, "[delete] %s", __FILE__);
+
+#ifdef NTOPNG_PRO
+  dumpAssetInfo();
+#endif
+
   if (initial_ts_point) delete (initial_ts_point);
   freeLocalHostData();
+
   /* Decrease number of active hosts */
-  if(isUnicastHost())
-    iface->decNumHosts(isLocalHost(), is_rx_only);
+  iface->decNumHosts(this, is_rx_only);
+  asset_map.clear();
 }
 
 /* *************************************** */
 
 void LocalHost::set_hash_entry_state_idle() {
-  if (ntop->getPrefs()->is_active_local_host_cache_enabled() &&
-      (!ip.isEmpty())) {
+  if (ntop->getPrefs()->is_active_local_host_cache_enabled()
+      && (!ip.isEmpty())) {
     Mac *mac = getMac();
 
     checkStatsReset();
@@ -89,7 +101,7 @@ void LocalHost::set_hash_entry_state_idle() {
   }
 
   /* Only increase the number of host if it's a unicast host */
-  if(isUnicastHost()) {
+  if (isUnicastHost()) {
     if (NetworkStats *ns = iface->getNetworkStats(local_network_id))
       ns->decNumHosts();
   }
@@ -99,23 +111,24 @@ void LocalHost::set_hash_entry_state_idle() {
 
 /* *************************************** */
 
-/* NOTE: Host::initialize will be called by the constructor after the Host initializator */
+/* NOTE: Host::initialize will be called by the constructor after the Host initialization */
 void LocalHost::initialize() {
   char buf[64], host[96], rsp[256];
+  BroadcastDomains *bd = iface->getBroadcastDomains();
+
   stats = allocateStats();
-  updateHostPool(true /* inline with packet processing */,
-                 true /* first inc */);
+  updateHostPool(true /* inline with packet processing */, true /* first inc */);
 
   local_network_id = -1;
   os_detail = NULL;
+  asset_map_updated = false;
 
   ip.isLocalHost(&local_network_id);
-
+  inconsistent_host_os = false;
   systemHost = ip.isLocalInterfaceAddress();
 
   /* Clone the initial point. It will be written to the timeseries DB to
-   * address the first point problem
-   * (https://github.com/ntop/ntopng/issues/2184). */
+   * address the first point problem (https://github.com/ntop/ntopng/issues/2184). */
   initial_ts_point = new (std::nothrow) LocalHostStats(*(LocalHostStats *)stats);
   initialization_time = time(NULL);
 
@@ -123,15 +136,13 @@ void LocalHost::initialize() {
   snprintf(host, sizeof(host), "%s@%u", strIP, vlan_id);
 
   if (ntop->getPrefs()->is_dns_resolution_enabled()) {
-    if (isBroadcastHost() || isMulticastHost() ||
-        (isIPv6() &&
-         ((strncmp(strIP, "ff0", 3) == 0) || (strncmp(strIP, "fe80", 4) == 0))))
+    if (isBroadcastHost() || isMulticastHost()
+	|| (isIPv6() && ((strncmp(strIP, "ff0", 3) == 0) || (strncmp(strIP, "fe80", 4) == 0))))
       ;
     else {
       ntop->getRedis()->getAddress(strIP, rsp, sizeof(rsp), true);
 
-      if(rsp[0] != '\0')
-        setResolvedName(rsp);
+      if (rsp[0] != '\0') setResolvedName(rsp);
     }
   }
 
@@ -139,14 +150,14 @@ void LocalHost::initialize() {
   updateHostTrafficPolicy(host);
   INTERFACE_PROFILING_SUB_SECTION_EXIT(iface, 18);
 
-  /* Only increase the number of host if it's a unicast host */
-  if(isUnicastHost()) {
+  /* Only increase the hosts number if it's a unicast host */
+  if (isUnicastHost()) {
     if (NetworkStats *ns = iface->getNetworkStats(local_network_id))
       ns->incNumHosts();
-
-    iface->incNumHosts(true /* isLocalHost() */, true /* Initialization: bytes are 0, considered RX only */);
   }
 
+  iface->incNumHosts(this, true /* Initialization: bytes are 0, considered RX only */);
+
 #ifdef LOCALHOST_DEBUG
   ntop->getTrace()->traceEvent(TRACE_NORMAL, "%s is %s [%p]",
                                ip.print(buf, sizeof(buf)),
@@ -159,124 +170,120 @@ void LocalHost::initialize() {
   drop_all_host_traffic = 0;
 #endif
 
-  if (ntop->getPrefs()->enableFingerprintStats())
+  if (ntop->getPrefs()->areFingerprintStatsEnabled())
     fingerprints = new (std::nothrow) HostFingerprints();
   else
     fingerprints = NULL;
 
+  tcp_fingerprint_host_os = ndpi_os_unknown;
+
+  syncMACMetadata(true);
+  gettimeofday(&last_periodic_asset_update, NULL);
+
+  if(bd) {
+    if(bd->isLocalBroadcastDomainHost(this, true)
+       || iface->getInterfaceNetworks()->match(&ip, ip.isIPv4() ? 32 : 128))
+      setMACmeaningful();
+  }
 
 #ifdef NTOPNG_PRO
-  if ((!(isBroadcastHost() || isMulticastHost()))
-      && ntop->getPrefs()->is_enterprise_xl_edition()
-      && (ntop->getPrefs()->isAssetInventoryEnabled() || ntop->getPrefs()->isNetBoxEnabled()))
-    dumpAssetInfo();
+  loadAssetInfo();
 #endif
-
 }
 
 /* *************************************** */
 
 void LocalHost::deferredInitialization() {
-  removeInactiveData();
   Host::deferredInitialization();
 }
 
 /* *************************************** */
 
-void LocalHost::addInactiveData() {
-  /* Remove the key from the hash, used to get the offline hosts */
-  /* Exclude the multicast/broadcast addresses */
-  if(!ntop->getRedis() || !isLocalUnicastHost())
-    return;
-
-  /* Exclude local-link fe80::/10, marked as private */
-  if(isIPv6() && isPrivateHost())
-    return;
-
-  char buf[64], *json_str = NULL;
-  ndpi_serializer host_json;
-  u_int32_t json_str_len = 0;
+void LocalHost::syncMACMetadata(bool force_update) {
   Mac *cur_mac = getMac();
 
-  /* In case the MAC is NULL or the MAC is a special */
-  /* address or a broadcast address do not include it */
-  if(!cur_mac || cur_mac->isSpecialMac() || cur_mac->isBroadcast())
-    return;
+  if(cur_mac && (force_update || cur_mac->isAssetUpdated())) {
+    if(cur_mac->getDHCPNamePtr())
+      offlineSetDHCPName(cur_mac->getDHCPNamePtr());
 
-#if 0
-  ntop->getTrace()->traceEvent(TRACE_NORMAL,
-    "Adding Host %s to inactive hosts Interace %d, with MAC: %s",
-    ip.print(buf, sizeof(buf)),
-    iface->get_id(),
-    cur_mac->print(buf, sizeof(buf)));
+    if(cur_mac->getDeviceOS() != ndpi_os_unknown)
+      setOS(cur_mac->getDeviceOS(), os_learning_dhcp);
+  }
+}
+
+/* *************************************** */
+
+void LocalHost::periodic_stats_update(const struct timeval *tv) {
+  checkGatewayInfo();
+  syncMACMetadata(false);
+
+#ifdef NTOPNG_PRO
+  /* If at least CONST_ASSETS_PERIODIC_UPDATE are past and the map was updated, dump the info */
+  float diff = Utils::msTimevalDiff(tv, &last_periodic_asset_update) / 1000; /* in Sec */
+  Mac *cur_mac = getMac();
+
+  if(cur_mac) asset_map_updated |= cur_mac->isAssetUpdated();
+
+  if ((diff > CONST_ASSETS_PERIODIC_UPDATE) && asset_map_updated) {
+    memcpy(&last_periodic_asset_update, tv, sizeof(last_periodic_asset_update));
+    dumpAssetInfo();
+  }
 #endif
 
-  ndpi_init_serializer(&host_json, ndpi_serialization_format_json);
-  ndpi_serialize_string_string(&host_json, "ip", ip.print(buf, sizeof(buf)));
-
-  ndpi_serialize_string_uint64(&host_json, "first_seen", get_first_seen());
-  ndpi_serialize_string_uint64(&host_json, "last_seen",  get_last_seen());
-
-  if(cur_mac) {
-    ndpi_serialize_string_uint32(&host_json, "device_type", getDeviceType());
-    ndpi_serialize_string_string(&host_json, "mac", cur_mac->print(buf, sizeof(buf)));
-  }
-
-  ndpi_serialize_string_uint32(&host_json, "vlan", (u_int16_t) get_vlan_id());
-  ndpi_serialize_string_uint32(&host_json, "network", (u_int16_t) get_local_network_id());
-  ndpi_serialize_string_string(&host_json, "name", get_name(buf, sizeof(buf), false));
-
-
-
-  json_str = ndpi_serializer_get_buffer(&host_json, &json_str_len);
-  if ((json_str != NULL) && (json_str_len > 0)) {
-    char key[128], redis_key[64];
-    snprintf(redis_key, sizeof(redis_key), OFFLINE_LOCAL_HOSTS_KEY, iface->get_id());
-    ntop->getRedis()->hashSet(redis_key, getSerializationKey(key, sizeof(key)), json_str);
-  }
-
-  ndpi_term_serializer(&host_json);
+  Host::periodic_stats_update(tv);
 }
 
 /* *************************************** */
 
-void LocalHost::removeInactiveData() {
-  char key[128], redis_key[64];
-
-  /* Remove the key from the hash, used to get the offline hosts */
-  if(!ntop->getRedis() || !isLocalUnicastHost())
-    return;
-
-  snprintf(redis_key, sizeof(redis_key), OFFLINE_LOCAL_HOSTS_KEY, iface->get_id());
-  ntop->getRedis()->hashDel(redis_key, getSerializationKey(key, sizeof(key)));
+void LocalHost::checkGatewayInfo() {
+  if (mac) {
+    //#define DEBUG_GATEWAY 1
+    bool is_gateway = mac->getDeviceType() == device_networking;
+#ifdef DEBUG_GATEWAY
+    char buf[64];
+    ntop->getTrace()->traceEvent(TRACE_NORMAL,
+                                 "Checking device type [IP: %s] [Type: %d]",
+                                 ip.print(buf, sizeof(buf)), device_networking);
+#endif
+    if (is_gateway) {
+      ip.setGateway(true);
+#ifdef DEBUG_GATEWAY
+      ntop->getTrace()->traceEvent(TRACE_NORMAL, "Gateway detected [IP: %s]",
+                                   ip.print(buf, sizeof(buf)));
+#endif
+    } else {
+      ip.setGateway(false);
+    }
+  }
 }
 
 /* *************************************** */
 
-char *LocalHost::getSerializationKey(char *redis_key, uint bufsize) {
+char* LocalHost::getSerializationKey(char *redis_key, u_int bufsize, bool short_format) {
   Mac *mac = getMac();
 
-  if (mac && serializeByMac()) {
+  if (mac && (is_in_broadcast_domain || serializeByMac())) {
     char mac_buf[128];
 
     get_mac_based_tskey(mac, mac_buf, sizeof(mac_buf));
 
-    return (getMacBasedSerializationKey(redis_key, bufsize, mac_buf));
+    return(getMacBasedSerializationKey(redis_key, bufsize, mac_buf, short_format));
   }
 
-  return (getIpBasedSerializationKey(redis_key, bufsize));
+  return(getIPBasedSerializationKey(redis_key, bufsize, short_format));
 }
 
 /* *************************************** */
 
-char *LocalHost::getRedisKey(char *buf, uint buf_len, bool skip_prefix) {
+char* LocalHost::getRedisKey(char *buf, uint buf_len, bool skip_prefix) {
   Mac *mac = getMac();
 
-  if (mac && serializeByMac()) {
+  if (mac && (is_in_broadcast_domain || serializeByMac())) {
     get_mac_based_tskey(mac, buf, buf_len, skip_prefix);
-    return (buf);
+    
+    return(buf);
   } else
-    return (get_hostkey(buf, buf_len, false));
+    return(get_hostkey(buf, buf_len, false));
 }
 
 /* *************************************** */
@@ -325,8 +332,7 @@ void LocalHost::lua_contacts_stats(lua_State *vm) const {
   lua_push_uint32_table_entry(vm, "imap", stats->getIMAPContactCardinality());
   lua_push_uint32_table_entry(vm, "pop", stats->getPOPContactCardinality());
   lua_push_uint32_table_entry(vm, "ntp", stats->getNTPContactCardinality());
-  lua_push_uint32_table_entry(vm, "domain_names",
-                              stats->getDomainNamesCardinality());
+  lua_push_uint32_table_entry(vm, "domain_names", stats->getDomainNamesCardinality());
 
   lua_pushstring(vm, "server_contacts");
   lua_insert(vm, -2);
@@ -376,9 +382,33 @@ void LocalHost::lua(lua_State *vm, AddressTree *ptree, bool host_details,
   if (router_mac_set) {
     char router_buf[24];
 
-    lua_push_str_table_entry(
-        vm, "router",
-        Utils::formatMac(router_mac, router_buf, sizeof(router_buf)));
+    lua_push_str_table_entry(vm, "router",
+			     Utils::formatMac(router_mac, router_buf, sizeof(router_buf)));
+  }
+
+  if(inconsistent_host_os)
+    lua_push_bool_table_entry(vm, "inconsistent_host_os", true);
+
+  if(tcp_fingerprint_host_os != ndpi_os_unknown) {
+    lua_newtable(vm);
+    lua_push_str_table_entry(vm, "os", ndpi_print_os_hint(tcp_fingerprint_host_os));
+    lua_pushstring(vm, "fingerprint");
+    lua_insert(vm, -2);
+    lua_settable(vm, -3);
+  }
+
+  if(os_learning.size() > 0) {
+    lua_newtable(vm);
+
+    /* Theoretically we should lock here */
+    for(std::map<OSLearningMode, ndpi_os>::iterator it = os_learning.begin(); it != os_learning.end(); it++) {
+      lua_push_str_table_entry(vm, Utils::learningMode2str(it->first), Utils::OS2Str(it->second));
+    }
+
+    lua_pushstring(vm, "os_learning");
+    lua_insert(vm, -2);
+    lua_settable(vm, -3);
+
   }
 
   /* Add new entries before this line! */
@@ -406,14 +436,21 @@ void LocalHost::inlineSetOSDetail(const char *_os_detail) {
       || (mac->getDeviceType() == device_networking))
     return;
 
-  if (os_detail || !_os_detail) return; /* Already set */
+  if (os_detail || !_os_detail)
+    return; /* Already set */
 
   if ((os_detail = strdup(_os_detail))) {
-    // TODO set mac device type
-    ;
-    DeviceType devtype = Utils::getDeviceTypeFromOsDetail(os_detail);
+    ndpi_os hint;
 
-    if (devtype != device_unknown) mac->setDeviceType(devtype);
+    // TODO set mac device type
+    DeviceType devtype = Utils::getDeviceTypeFromOsDetail(os_detail, &hint);
+
+    if (devtype != device_unknown) {
+      if(getDeviceType() == device_unknown)
+	setDeviceType(devtype);
+
+      mac->setDeviceType(devtype);
+    }
   }
 }
 
@@ -498,12 +535,14 @@ void LocalHost::freeLocalHostData() {
     os_detail = NULL;
   }
 
+  if(tcp_fingerprint)
+    free(tcp_fingerprint);
+
   for (std::unordered_map<u_int32_t, DoHDoTStats *>::iterator it = doh_dot_map.begin();
        it != doh_dot_map.end(); ++it)
     delete it->second;
 
-  if(fingerprints)
-    delete fingerprints;
+  if (fingerprints) delete fingerprints;
 }
 
 /* *************************************** */
@@ -521,20 +560,20 @@ void LocalHost::deleteHostData() {
 /* *************************************** */
 
 char *LocalHost::getMacBasedSerializationKey(char *redis_key, size_t size,
-                                             char *mac_key) {
+                                             char *mac_key, bool short_format) {
   /* Serialize both IP and MAC for static hosts */
-  snprintf(redis_key, size, HOST_BY_MAC_SERIALIZED_KEY, iface->get_id(),
+  snprintf(redis_key, size, short_format ? MAC_SERIALIZED_SHORT_KEY : HOST_BY_MAC_SERIALIZED_KEY, iface->get_id(),
            mac_key);
 
-  return (redis_key);
+  return(redis_key);
 }
 
 /* *************************************** */
 
-char *LocalHost::getIpBasedSerializationKey(char *redis_key, size_t size) {
+char *LocalHost::getIPBasedSerializationKey(char *redis_key, size_t size, bool short_format) {
   char buf[CONST_MAX_LEN_REDIS_KEY];
 
-  snprintf(redis_key, size, HOST_SERIALIZED_KEY, iface->get_id(),
+  snprintf(redis_key, size, short_format ? HOST_SERIALIZED_SHORT_KEY : HOST_SERIALIZED_KEY, iface->get_id(),
            ip.print(buf, sizeof(buf)), vlan_id);
 
   return redis_key;
@@ -561,7 +600,7 @@ void LocalHost::incDohDoTUses(Host *host) {
   if (it == doh_dot_map.end()) {
     if (doh_dot_map.size() < 8 /* Max # entries */) {
       DoHDoTStats *doh_dot =
-          new (nothrow) DoHDoTStats(*(host->get_ip()), host->get_vlan_id());
+	new (nothrow) DoHDoTStats(*(host->get_ip()), host->get_vlan_id());
 
       if (doh_dot) {
         doh_dot->incUses();
@@ -586,7 +625,7 @@ void LocalHost::luaDoHDot(lua_State *vm) {
   m.lock(__FILE__, __LINE__);
 
   for (std::unordered_map<u_int32_t, DoHDoTStats *>::iterator it =
-           doh_dot_map.begin();
+	 doh_dot_map.begin();
        it != doh_dot_map.end(); ++it) {
     lua_newtable(vm);
 
@@ -610,58 +649,32 @@ void LocalHost::luaDoHDot(lua_State *vm) {
 void LocalHost::setRouterMac(Mac *gw) {
   if (!router_mac_set) {
     memcpy(router_mac, gw->get_mac(), 6), router_mac_set = true;
-
-#ifdef NTOPNG_PRO
-    ntop->get_am()->addClientGateway(this, gw, get_first_seen());
-#endif
-  }
-}
-
-/* *************************************** */
-
-void LocalHost::toggleRxOnlyHost(bool rx_only) {
-  Host::toggleRxOnlyHost(rx_only);
-
-  if (isLocalUnicastHost()) {
-    char hostbuf[64], *member;
-
-    member = get_hostkey(hostbuf, sizeof(hostbuf));
-
-    if (is_rx_only) {
-      /* Add this host to the hash of RX-only local hosts */
-      char seenbuf[16];
-
-      snprintf(seenbuf, sizeof(seenbuf), "%u", (u_int32_t)get_last_seen());
-      ntop->getRedis()->hashSet(HASHKEY_LOCALHOST_RX_ONLY, member, seenbuf);
-    } else {
-      /* Delete the key in case it was present */
-      ntop->getRedis()->hashDel(HASHKEY_LOCALHOST_RX_ONLY, member);
-    }
   }
 }
 
 /* ***************************************************** */
 
-void LocalHost::setServerPort(bool isTCP, u_int16_t port, ndpi_protocol *proto, time_t when) {
+void LocalHost::setServerPort(bool isTCP, u_int16_t port, ndpi_protocol *proto,
+                              time_t when) {
   bool set_port_status = usedPorts.setServerPort(isTCP, port, proto);
 
-  if (set_port_status
-      && ntop->getPrefs()->is_enterprise_l_edition()) {
+  if (set_port_status && ntop->getPrefs()->is_enterprise_l_edition()) {
     /* If the port is set for the first time set_port_status == true */
     u_int32_t learning_period = ntop->getPrefs()->hostPortLearningPeriod();
 
     if (when - get_first_seen() > learning_period) {
       if (!contacted_server_ports.isFull()) {
-	/* ntop->getTrace()->traceEvent(TRACE_NORMAL, "*** port %u ***", port); */
-        contacted_server_ports.enqueue({port, proto->app_protocol}, true);
+        /* ntop->getTrace()->traceEvent(TRACE_NORMAL, "*** port %u ***", port);
+         */
+        contacted_server_ports.enqueue({port, proto->proto.app_protocol}, true);
       } else {
-	char ip_buf[64];
+        char ip_buf[64];
 
-        ntop->getTrace()->traceEvent(TRACE_INFO,
+        ntop->getTrace()->traceEvent(
+				     TRACE_INFO,
 				     "Server port %s:%d contacted but not reported: exceeded max number",
 				     printMask(ip_buf, sizeof(ip_buf)), port);
       }
-
     }
   }
 }
@@ -669,56 +682,226 @@ void LocalHost::setServerPort(bool isTCP, u_int16_t port, ndpi_protocol *proto,
 /* ***************************************************** */
 
 void LocalHost::lua_get_fingerprints(lua_State *vm) {
-  if(fingerprints) {
+  if (fingerprints) {
     fingerprints->ja4.lua("ja4_fingerprint", vm);
     fingerprints->hassh.lua("hassh_fingerprint", vm);
   }
+
+  if(tcp_fingerprint != NULL)
+    lua_push_str_table_entry(vm, "tcp_fingerprint", tcp_fingerprint);
+}
+
+/* *************************************** */
+
+void LocalHost::setDhcpServer() {
+  Host::setDhcpServer();
+  addDataToAssets((char *) "dhcp_server", (char *) "true");
+}
+
+/* *************************************** */
+
+void LocalHost::setDnsServer() {
+  Host::setDnsServer();
+  addDataToAssets((char *) "dns_server", (char *) "true");
+}
+
+/* *************************************** */
+
+void LocalHost::setSmtpServer() {
+  Host::setSmtpServer();
+  addDataToAssets((char *) "smtp_server", (char *) "true");
+}
+
+/* *************************************** */
+
+void LocalHost::setNtpServer() {
+  Host::setNtpServer();
+  addDataToAssets((char *) "ntp_server", (char *) "true");
+}
+
+/* *************************************** */
+
+void LocalHost::setImapServer() {
+  Host::setImapServer();
+  addDataToAssets((char *) "imap_server", (char *) "true");
+}
+
+/* *************************************** */
+
+void LocalHost::setPopServer() {
+  Host::setPopServer();
+  addDataToAssets((char *) "pop_server", (char *) "true");
+}
+
+/* *************************************** */
+
+void LocalHost::setHttpServer() {
+  Host::setHttpServer();
+  addDataToAssets((char *) "http_server", (char *) "true");
+}
+
+/* *************************************** */
+
+void LocalHost::setSshServer() {
+  Host::setSshServer();
+  addDataToAssets((char *) "ssh_server", (char *) "true");
+}
+
+/* *************************************** */
+
+void LocalHost::setRdpServer() {
+  Host::setRdpServer();
+  addDataToAssets((char *) "rdp_server", (char *) "true");
+}
+
+/* *************************************** */
+
+void LocalHost::offlineSetMDNSInfo(char *const str) {
+  Host::offlineSetMDNSInfo(str);
+}
+
+/* *************************************** */
+
+void LocalHost::offlineSetMDNSName(const char *mdns_n) {
+  Host::offlineSetMDNSName(mdns_n);
+  addDataToAssets((char *) "mdns_name", (char *) mdns_n);
+}
+
+/* *************************************** */
+
+void LocalHost::offlineSetDHCPName(const char *dhcp_n) {
+  Host::offlineSetDHCPName(dhcp_n);
+  addDataToAssets((char *) "dhcp_name", (char *) dhcp_n);
+}
+
+/* *************************************** */
+
+void LocalHost::offlineSetDhcpFingerprint(const char *fingerprint) {
+  if(fingerprint && (fingerprint[0] != '\0')) {
+    Mac *mac = getMac();
+
+    if(mac)
+      mac->setDHCPFingerprint(fingerprint);
+  }
 }
 
 /* *************************************** */
 
-#ifdef NTOPNG_PRO
-void LocalHost::dumpAssetInfo() {
-  char buf[64], mac_buf[32], *json_str = NULL, *ip = printMask(buf, sizeof(buf)), *mac_ptr;
-  ndpi_serializer device_json;
-  u_int32_t json_str_len = 0;
+void LocalHost::offlineSetMDNSTXTName(const char *mdns_n_txt) {
+  Host::offlineSetMDNSTXTName(mdns_n_txt);
+  addDataToAssets((char *) "mdns_txt_name", (char *) mdns_n_txt);
+}
 
-  ndpi_init_serializer(&device_json, ndpi_serialization_format_json);
+/* *************************************** */
 
-  mac_ptr = Utils::formatMac(getMac()->get_mac(), mac_buf, sizeof(mac_buf));
+void LocalHost::offlineSetNetbiosName(const char *netbios_n) {
+  Host::offlineSetNetbiosName(netbios_n);
+  addDataToAssets((char *) "netbios_name", (char *) netbios_n);
+}
 
-  if (getMac() && serializeByMac()) {
-    /* DHCP */
-    ndpi_serialize_string_string(&device_json, "key", mac_ptr);
+/* *************************************** */
 
-    ndpi_serialize_string_uint32(&device_json, "role", mac->getDeviceType());
-  } else {
-    /* IP */
-    ndpi_serialize_string_string(&device_json, "key", ip);
-    ndpi_serialize_string_uint32(&device_json, "role", getDeviceType());
+void LocalHost::offlineSetTLSName(const char *tls_n) {
+  Host::offlineSetHTTPName(tls_n);
+  addDataToAssets((char *) "tls_name", (char *) tls_n);
+}
+
+/* *************************************** */
+
+void LocalHost::offlineSetHTTPName(const char *http_n) {
+  Host::offlineSetHTTPName(http_n);
+  addDataToAssets((char *) "http_name", (char *) http_n);
+}
+
+/* *************************************** */
+
+void LocalHost::setServerName(const char *server_n) {
+  Host::setServerName(server_n);
+}
+
+/* *************************************** */
+
+void LocalHost::setResolvedName(const char *resolved_name) {
+  char buf[64];
+
+  if(strcmp(get_ip()->print(buf, sizeof(buf)), resolved_name)) {
+    Host::setResolvedName(resolved_name);
+    addDataToAssets((char *) "dns_name", (char *) resolved_name);
   }
+}
+
+/* *************************************** */
+
+void LocalHost::setTCPfingerprint(char *_tcp_fingerprint, ndpi_os os) {
+  if((tcp_fingerprint != NULL) && (strcmp(_tcp_fingerprint, tcp_fingerprint) == 0))
+    return; /* Already set */
 
-  ndpi_serialize_string_string(&device_json, "mac", mac_ptr);
-  if(mac->get_manufacturer())
-    ndpi_serialize_string_string(&device_json, "manufacturer", mac->get_manufacturer());
+  if (_tcp_fingerprint && _tcp_fingerprint[0] != '\0')
+    addDataToAssets((char *) "tcp_fingerprint", (char *) _tcp_fingerprint);
 
-  if(isIPv6())
-    ndpi_serialize_string_string(&device_json, "ipv6", ip);
-  else
-    ndpi_serialize_string_string(&device_json, "ipv4", ip);
+  if(tcp_fingerprint_host_os == ndpi_os_unknown) {
+    /* Not yet set the host fingerprint */
+    ndpi_os l_os_type = os;
 
-  ndpi_serialize_string_string(&device_json, "source", "traffic");
-  ndpi_serialize_string_uint32(&device_json, "first_seen", first_seen);
-  ndpi_serialize_string_uint32(&device_json, "last_seen", last_seen);
+    if(l_os_type != ndpi_os_unknown)
+      setOS(l_os_type, os_learning_tcp_fingerprint);
 
-  json_str = ndpi_serializer_get_buffer(&device_json, &json_str_len);
+    tcp_fingerprint_host_os = os;
 
-  if((json_str != NULL) && (json_str_len > 0)) {
-    char key[64];
-    snprintf(key, sizeof(key), ASSET_LIST_INSERTION_KEY, iface->get_id());
-    ntop->getRedis()->rpush(key, json_str, 1024);
+    if(tcp_fingerprint == NULL)
+      tcp_fingerprint = strdup(_tcp_fingerprint);
+  } else if((os != ndpi_os_unknown) && (tcp_fingerprint_host_os != os)) {
+    char buf[64];
+
+    ntop->getTrace()->traceEvent(TRACE_INFO, "Found OS inconsistency %s vs %s [%s][%s]",
+				 ndpi_print_os_hint(tcp_fingerprint_host_os),
+				 ndpi_print_os_hint(os),
+				 _tcp_fingerprint ? _tcp_fingerprint : "",
+				 get_ip()->print(buf, sizeof(buf)));
+
+    inconsistent_host_os = true;
   }
+}
+
+/* *************************************** */
 
-  ndpi_term_serializer(&device_json);
+bool LocalHost::setOS(ndpi_os _os, OSLearningMode mode) {
+  if((_os != ndpi_os_unknown) && (getOS() != _os)) {
+    if(Host::setOS(_os, mode)) {
+      char buf[8];
+
+      os_learning[mode] = _os;
+
+      snprintf(buf, sizeof(buf), "%d", _os);
+
+      addDataToAssets((char *) "os_type", buf);
+      return(true);
+    }
+  }
+
+  return(false);
+}
+
+/* *************************************** */
+
+void LocalHost::setDeviceType(DeviceType devtype) {
+  if(device_type == devtype)
+    return;
+
+  device_type = devtype;
+  asset_map_updated = true;
+  ntop->trackAssetChange("Host", "setDeviceType",
+			 NULL, NULL, this, NULL,
+			 (char*)Utils::deviceType2str(devtype));
+}
+
+/* *************************************** */
+
+void LocalHost::setMACmeaningful() {
+  if(!is_mac_meaningful) {
+    if(iface->isPacketInterface() && (!iface->isTrafficMirrored())) {
+      is_mac_meaningful = true;
+      asset_map_updated = true;
+    }
+  }
 }
-#endif
