@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2015-24 - ntop.org
+ * (C) 2015-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 
 /* *************************************** */
 
-NetworkStats::NetworkStats(NetworkInterface *iface, u_int16_t _network_id)
+NetworkStats::NetworkStats(NetworkInterface *iface, u_int32_t _network_id)
     : InterfaceMemberAlertableEntity(iface, alert_entity_network),
       GenericTrafficElement(),
       Score(iface) {
@@ -80,7 +80,7 @@ NetworkStats::~NetworkStats() {
 
 /* *************************************** */
 
-void NetworkStats::lua(lua_State *vm, bool diff) {
+void NetworkStats::lua(lua_State *vm, bool diff, bool fullStats) {
   int hits;
 
   lua_push_str_table_entry(vm, "network_key",
@@ -115,23 +115,25 @@ void NetworkStats::lua(lua_State *vm, bool diff) {
   lua_settable(vm, -3);
 
 #ifdef NTOPNG_PRO
-  lua_newtable(vm);
-
-  for (u_int16_t i = 0; i < ntop->getNumLocalNetworks(); i++) {
-    /* Safety check in case a local network is NULL */
-    if(!ntop->getLocalNetworkName(i))
-      continue;
-
+  if (fullStats) {
     lua_newtable(vm);
-    lua_push_uint64_table_entry(vm, "bytes_sent", network_matrix[i].bytes_sent);
-    lua_push_uint64_table_entry(vm, "bytes_rcvd", network_matrix[i].bytes_rcvd);
-    lua_pushstring(vm, ntop->getLocalNetworkName(i));
+
+    for (u_int32_t i = 0; i < ntop->getNumLocalNetworks(); i++) {
+      /* Safety check in case a local network is NULL */
+      if(!ntop->getLocalNetworkName(i))
+        continue;
+
+      lua_newtable(vm);
+      lua_push_uint64_table_entry(vm, "bytes_sent", network_matrix[i].bytes_sent);
+      lua_push_uint64_table_entry(vm, "bytes_rcvd", network_matrix[i].bytes_rcvd);
+      lua_pushstring(vm, ntop->getLocalNetworkName(i));
+      lua_insert(vm, -2);
+      lua_settable(vm, -3);
+    }
+    lua_pushstring(vm, "intranet_traffic");
     lua_insert(vm, -2);
     lua_settable(vm, -3);
   }
-  lua_pushstring(vm, "intranet_traffic");
-  lua_insert(vm, -2);
-  lua_settable(vm, -3);
 #endif
 
   tcp_packet_stats_ingress.lua(vm, "tcpPacketStats.ingress");
@@ -147,7 +149,9 @@ void NetworkStats::lua(lua_State *vm, bool diff) {
   if (syn_recvd_last_min > synack_sent_last_min)
     hits = syn_recvd_last_min - synack_sent_last_min;
   if (hits) lua_push_uint64_table_entry(vm, "hits.syn_scan_victim", hits);
-
+#ifdef NTOPNG_PRO
+  qoe_stats.lua_qoe_stats(vm);
+#endif
   GenericTrafficElement::lua(vm, true);
   Score::lua_get_score(vm);
   Score::lua_get_score_breakdown(vm);
@@ -239,10 +243,10 @@ void NetworkStats::updateStats(const struct timeval *tv) {
 
 /* ***************************************** */
 
-void NetworkStats::incTrafficBetweenNets(u_int16_t net_id, u_int32_t bytes_sent,
+void NetworkStats::incTrafficBetweenNets(u_int32_t net_id, u_int32_t bytes_sent,
                                          u_int32_t bytes_rcvd) {
 #ifdef NTOPNG_PRO
-  if (net_id < ntop->getNumLocalNetworks() && net_id != (u_int16_t)-1) {
+  if (net_id < ntop->getNumLocalNetworks() && net_id != (u_int32_t)-1) {
     network_matrix[net_id].bytes_sent += bytes_sent;
     network_matrix[net_id].bytes_rcvd += bytes_rcvd;
   }
@@ -253,7 +257,7 @@ void NetworkStats::incTrafficBetweenNets(u_int16_t net_id, u_int32_t bytes_sent,
 
 void NetworkStats::resetTrafficBetweenNets() {
 #ifdef NTOPNG_PRO
-  for (u_int16_t i = 0; i < ntop->getNumLocalNetworks(); i++) {
+  for (u_int32_t i = 0; i < ntop->getNumLocalNetworks(); i++) {
     network_matrix[i].bytes_sent = 0;
     network_matrix[i].bytes_rcvd = 0;
   }
