@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -37,6 +37,7 @@ Paginator::Paginator() {
   traffic_profile_filter = NULL;
   username_filter = NULL;
   pidname_filter = NULL;
+  wlan_ssid_filter = NULL;
 
   /* bool */
   a2z_sort_order = true;
@@ -73,7 +74,9 @@ Paginator::Paginator() {
   icmp_type = u_int8_t(-1);
   icmp_code = u_int8_t(-1);
   dscp_filter = (u_int8_t)-1;
-
+#ifdef NTOPNG_PRO
+  qoe_filter = (u_int8_t)-1;
+#endif
   details_level = details_normal;
   details_level_set = false;
 
@@ -90,6 +93,7 @@ Paginator::Paginator() {
 Paginator::~Paginator() {
   if (sort_column) free(sort_column);
   if (country_filter) free(country_filter);
+  if (wlan_ssid_filter) free(wlan_ssid_filter);
   if (host_filter) free(host_filter);
   if (client_filter) free(client_filter);
   if (server_filter) free(server_filter);
@@ -121,6 +125,8 @@ void Paginator::readOptions(lua_State* L, int index) {
           sort_column = strdup(lua_tostring(L, -1));
         } else if (!strcmp(key, "deviceIpFilter")) {
           deviceIP = ntohl(inet_addr(lua_tostring(L, -1)));
+        } else if (!strcmp(key, "wlanSSIDFilter")) {
+          wlan_ssid_filter = strdup(lua_tostring(L, -1));
         } else if (!strcmp(key, "countryFilter")) {
           if (country_filter) free(country_filter);
           country_filter = strdup(lua_tostring(L, -1));
@@ -229,7 +235,11 @@ void Paginator::readOptions(lua_State* L, int index) {
         else if (!strcmp(key, "icmp_code"))
           icmp_code = lua_tointeger(L, -1);
         else if (!strcmp(key, "dscpFilter"))
-          dscp_filter = lua_tointeger(L, -1);
+            dscp_filter = lua_tointeger(L, -1);
+    #ifdef NTOPNG_PRO
+        else if (!strcmp(key, "qoeFilter"))
+            qoe_filter = lua_tointeger(L, -1);
+    #endif
         else if (!strcmp(key, "ifaceIndex"))
           iface_index_filter = lua_tointeger(L, -1);
         else if (!strcmp(key, "statusFilter"))
