@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -38,7 +38,7 @@ ParsedFlow::ParsedFlow() : ParsedFlowCore(), ParsedeBPF() {
   external_alert = NULL;
   flow_risk_info = NULL;
   tls_cipher = tls_unsafe_cipher = http_ret_code = 0;
-  dns_query_type = dns_ret_code = 0;
+  dns_query_type = dns_ret_code = dns_query_id = 0;
   ndpi_flow_risk_bitmap = 0;
   ndpi_flow_risk_name = NULL;
   smtp_rcp_to = NULL;
@@ -53,8 +53,11 @@ ParsedFlow::ParsedFlow() : ParsedFlowCore(), ParsedeBPF() {
   src_ip_addr_pre_nat = dst_ip_addr_pre_nat =
     src_ip_addr_post_nat = dst_ip_addr_post_nat = 0;
   memset(&custom_app, 0, sizeof(custom_app));
-
+  wlan_ssid = NULL;
+  memset(&wtp_mac_address, 0, sizeof(wtp_mac_address));
+  l7_json = NULL;
   has_parsed_ebpf = false;
+  memset(&qoe, 0, sizeof(qoe));
 }
 
 /* *************************************** */
@@ -150,12 +153,25 @@ ParsedFlow::ParsedFlow(const ParsedFlow &pf) : ParsedFlowCore(pf), ParsedeBPF(pf
   else
     sip_call_id = NULL;
 
+  if(pf.wlan_ssid)
+    wlan_ssid = strdup(pf.wlan_ssid);
+  else
+    wlan_ssid = NULL;
+
+  if(pf.l7_json)
+    l7_json = strdup(pf.l7_json);
+  else
+    l7_json = NULL;
+
+  memcpy(&wtp_mac_address, &pf.wtp_mac_address, sizeof(wtp_mac_address));
+
   tls_cipher = pf.tls_cipher;
   tls_unsafe_cipher = pf.tls_unsafe_cipher;
   ndpi_flow_risk_bitmap = pf.ndpi_flow_risk_bitmap;
   http_ret_code = pf.http_ret_code;
   dns_query_type = pf.dns_query_type;
   dns_ret_code = pf.dns_ret_code;
+  dns_query_id = pf.dns_query_id;
   
   /* Only IPv4 supported, in case the ipv4 is 0 it's already handled inside IpAddress class */
   src_ip_addr_pre_nat = pf.src_ip_addr_pre_nat;
@@ -171,6 +187,8 @@ ParsedFlow::ParsedFlow(const ParsedFlow &pf) : ParsedFlowCore(pf), ParsedeBPF(pf
 
   memcpy(&custom_app, &pf.custom_app, sizeof(custom_app));
   has_parsed_ebpf = pf.has_parsed_ebpf;
+
+  memcpy(&qoe, &pf.qoe, sizeof(qoe));
 }
 
 /* *************************************** */
@@ -224,6 +242,9 @@ void ParsedFlow::fromLua(lua_State *L, int index) {
           last_switched = Utils::str2epoch(lua_tostring(L, -1));
         } else if (!strcmp(key, "l4_proto")) {
           l4_proto = Utils::l4name2proto(lua_tostring(L, -1));
+        } else if (!strcmp(key, "l7_json")) {
+          if (l7_json) free(l7_json);
+          l7_json = strdup(lua_tostring(L, -1));
         } else {
           addAdditionalField(key, json_object_new_string(lua_tostring(L, -1)));
           ntop->getTrace()->traceEvent(TRACE_DEBUG,
@@ -258,12 +279,18 @@ void ParsedFlow::fromLua(lua_State *L, int index) {
           out_pkts = lua_tonumber(L, -1);
         else if (!strcmp(key, "out_bytes"))
           out_bytes = lua_tonumber(L, -1);
+        else if (!strcmp(key, "master_protocol"))
+          l7_proto.proto.master_protocol = lua_tonumber(L, -1);
         else if (!strcmp(key, "app_protocol"))
-          l7_proto.app_protocol = lua_tonumber(L, -1);
+          l7_proto.proto.app_protocol = lua_tonumber(L, -1);
+        else if (!strcmp(key, "confidence"))
+          confidence = (ndpi_confidence_t) lua_tonumber(L, -1);
         else if (!strcmp(key, "dns_query_type"))
           dns_query_type = lua_tonumber(L, -1);
         else if (!strcmp(key, "dns_ret_code"))
           dns_ret_code = lua_tonumber(L, -1);
+        else if (!strcmp(key, "dns_query_id"))
+          dns_query_id = lua_tonumber(L, -1);
         else if (!strcmp(key, "http_ret_code"))
           http_ret_code = lua_tonumber(L, -1);
         else {
@@ -322,19 +349,41 @@ void ParsedFlow::freeMemory() {
   if (smtp_mail_from)       { free(smtp_mail_from); smtp_mail_from = NULL; }
   if (dhcp_client_name)     { free(dhcp_client_name); dhcp_client_name = NULL; }
   if (sip_call_id)          { free(sip_call_id); sip_call_id = NULL; }
+  if (wlan_ssid)            { free(wlan_ssid); wlan_ssid = NULL; }
+  if (l7_json)              { free(l7_json); l7_json = NULL; }
 }
 
 /* *************************************** */
 
 void ParsedFlow::swap() {
+  u_int8_t tmp_qoe_c2s, tmp_qoe_s2c;
+  
   ParsedFlowCore::swap();
   ParsedeBPF::swap();
+
+  tmp_qoe_c2s = qoe.src_to_dst, tmp_qoe_s2c = qoe.dst_to_src;
+  qoe.src_to_dst = tmp_qoe_s2c, qoe.dst_to_src = tmp_qoe_c2s;
   
   is_swapped = true;
 }
 
 /* *************************************** */
 
+u_int32_t ParsedFlow::get_private_flow_id() {
+  u_int32_t private_flow_id = 0;
+
+  if (getSIPCallId()) {
+    size_t len = strlen(getSIPCallId());
+    private_flow_id = ndpi_quick_hash((const unsigned char *) getSIPCallId(), len);
+  } else if (getDNSQueryId()) {
+    private_flow_id = getDNSQueryId();
+  }
+
+  return private_flow_id;
+}
+
+/* *************************************** */
+
 void ParsedFlow::print() {
   char buf1[32], buf2[32];
 
