@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -27,15 +27,17 @@
 
 ParserInterface::ParserInterface(const char *endpoint,
                                  const char *custom_interface_type)
-    : NetworkInterface(endpoint, custom_interface_type) {
-  if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
+  : NetworkInterface(endpoint, custom_interface_type) {
+  if (trace_new_delete)
+    ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
 
   num_companion_interfaces = 0;
-  companion_interfaces  = new (std::nothrow) NetworkInterface *[MAX_NUM_COMPANION_INTERFACES]();
+  companion_interfaces =
+      new (std::nothrow) NetworkInterface *[MAX_NUM_COMPANION_INTERFACES]();
 
 #ifdef NTOPNG_PRO
   flow_interfaces_stats = new (std::nothrow) FlowInterfacesStats();
-  
+
   if (!flow_interfaces_stats)
     ntop->getTrace()->traceEvent(TRACE_WARNING, "Memory allocation failure");
 #endif
@@ -53,18 +55,18 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
   bool src2dst_direction, new_flow;
   Flow *flow;
   time_t now;
+  bool update_seen = false;
   bpf_timeval now_tv = {0};
   Mac *srcMac = NULL, *dstMac = NULL;
   IpAddress srcIP, dstIP;
-  u_int32_t private_flow_id, unique_source_id = zflow->unique_source_id;
+  u_int32_t unique_source_id = zflow->unique_source_id;
   u_int32_t in_pkts, in_bytes, out_pkts, out_bytes;
-  
+
 #ifdef NTOPNG_PRO
-  if(!flow_interfaces_stats)
-    return false;
+  if (!flow_interfaces_stats) return false;
 #endif
-  
-  if(unique_source_id == 0)
+
+  if (unique_source_id == 0)
     unique_source_id = zflow->nprobe_ip + zflow->exporter_device_ip;
 
   now = time(NULL);
@@ -86,33 +88,6 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
   if ((zflow->vlan_id == 0) && ntop->getPrefs()->do_simulate_vlans())
     zflow->vlan_id = rand() % SIMULATE_VLANS_MAX_VALUE;
 
-#ifdef TRACE_EXPORTERS
-  ntop->getTrace()->traceEvent(TRACE_NORMAL,
-			       "[unique_source_id: %u];device_ip: %u][probe_ip: %u][iface: %u->%u]",
-			       unique_source_id, zflow->exporter_device_ip,
-			       zflow->nprobe_ip, zflow->inIndex, zflow->outIndex);
-#endif
-  
-#ifdef NTOPNG_PRO
-  if(unique_source_id != 0) {
-    if (!flow_interfaces_stats->checkExporters(unique_source_id,
-					       zflow->inIndex, zflow->outIndex,
-					       zflow->exporter_device_ip, zflow->nprobe_ip)) {
-      static bool shown = false;
-
-      if(!shown) {
-	ntop->getTrace()->traceEvent(TRACE_NORMAL,
-				     "Flow dropped due to limits to the license. Exporters limit: %d | Exporters Interfaces limit: %d",
-				     get_max_num_flow_exporters(), get_max_num_flow_exporters_interfaces());
-	ntop->getRedis()->set(EXPORTERS_EXCEEDED_LIMITS_KEY, "1");
-	shown = true;
-      }
-
-      return false;
-    }
-  }
-#endif
-
   if (!isSubInterface()) {
     bool processed = false;
 
@@ -158,9 +133,8 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
             break;
 
           case flowhashing_probe_ip_and_ingress_iface_idx:
-            virtual_observation_point_id =
-                ((((u_int64_t)zflow->exporter_device_ip) << 32) + zflow->inIndex) &
-                0xFFF /* 4096 */;
+            virtual_observation_point_id = ((((u_int64_t)zflow->exporter_device_ip) << 32) +
+					    zflow->inIndex) & 0xFFF /* 4096 */;
             break;
 
           case flowhashing_vrfid:
@@ -200,8 +174,7 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
           case flowhashing_probe_ip_and_ingress_iface_idx:
             // ntop->getTrace()->traceEvent(TRACE_NORMAL, "[IP: %u][inIndex:
             // %u]", zflow->exporter_device_ip, zflow->inIndex);
-            vIface = getDynInterface(
-                (((u_int64_t)zflow->exporter_device_ip) << 32) + zflow->inIndex, true);
+            vIface = getDynInterface((((u_int64_t)zflow->exporter_device_ip) << 32) + zflow->inIndex, true);
             break;
 
           case flowhashing_vrfid:
@@ -223,8 +196,7 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
         }
 
         if (vIfaceEgress) {
-          ParserInterface *vPIface =
-              dynamic_cast<ParserInterface *>(vIfaceEgress);
+          ParserInterface *vPIface = dynamic_cast<ParserInterface *>(vIfaceEgress);
 
           vPIface->processFlow(zflow);
         }
@@ -232,43 +204,102 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
         processed = true;
       }
 
-      if (processed && (!showDynamicInterfaceTraffic()))
-	return true;
+      if (processed && (!showDynamicInterfaceTraffic())) return true;
     }
   }
 
   if (!ntop->getPrefs()->do_ignore_macs()) {
-    srcMac = getMac((u_int8_t *)zflow->src_mac, true /* Create if missing */,
-                    true /* Inline call */);
-    dstMac = getMac((u_int8_t *)zflow->dst_mac, true /* Create if missing */,
-                    true /* Inline call */);
+    u_int8_t zero_mac[6] = { 0 };
+
+    if(memcmp(zflow->src_mac, zero_mac, 6)) {
+      srcMac = getMac((u_int8_t *)zflow->src_mac, true /* Create if missing */,
+		      true /* Inline call */);
+      dstMac = getMac((u_int8_t *)zflow->dst_mac, true /* Create if missing */,
+		      true /* Inline call */);
+    }
   }
 
-  srcIP.set(&zflow->src_ip), dstIP.set(&zflow->dst_ip);
+  if((zflow->src_ip.getVersion() == 0)
+     || (zflow->dst_ip.getVersion() == 0)) {
+    flow = NULL; /* Invalid IPs */
+  } else { 
+    srcIP.set(&zflow->src_ip), dstIP.set(&zflow->dst_ip);
+    
+    INTERFACE_PROFILING_SECTION_ENTER("NetworkInterface::processFlow: getFlow", 0);
+    
+    /* Updating Flow */
+    flow = getFlow(UNKNOWN_PKT_IFACE_IDX, srcMac, dstMac, zflow->vlan_id,
+		   zflow->observationPointId, zflow->get_private_flow_id(),
+		   zflow->exporter_device_ip, zflow->inIndex, zflow->outIndex,
+		   NULL /* ICMPinfo */, &srcIP, &dstIP, zflow->src_port,
+		   zflow->dst_port, zflow->l4_proto, &src2dst_direction,
+		   zflow->first_switched, zflow->last_switched, 0, &new_flow,
+		   true, (u_int8_t *)zflow->src_mac, (u_int8_t *)zflow->dst_mac);
 
-  INTERFACE_PROFILING_SECTION_ENTER("NetworkInterface::processFlow: getFlow", 0);
+    INTERFACE_PROFILING_SECTION_EXIT(0);
+  }
+  
+  if(flow) {
+    /* Fix interaface Id (if zero) */
 
-  if(zflow->getSIPCallId()) {
-    size_t len = strlen(zflow->getSIPCallId());
+    if(zflow->inIndex != 0) {
+      if(src2dst_direction)
+	flow->setFlowDeviceInIndex(zflow->inIndex);
+      else
+	flow->setFlowDeviceOutIndex(zflow->inIndex);
+    }
 
-    private_flow_id = ndpi_quick_hash((const unsigned char*)zflow->getSIPCallId(), len);
-  } else
-    private_flow_id = 0;
+    if(zflow->outIndex != 0) {
+      if(src2dst_direction)
+	flow->setFlowDeviceOutIndex(zflow->outIndex);
+      else
+	flow->setFlowDeviceInIndex(zflow->outIndex);
+    }
+  }
 
-  /* Updating Flow */
-  flow = getFlow(UNKNOWN_PKT_IFACE_IDX,
-		 srcMac, dstMac, zflow->vlan_id, zflow->observationPointId,
-                 private_flow_id, zflow->exporter_device_ip, zflow->inIndex,
-                 zflow->outIndex, NULL /* ICMPinfo */, &srcIP, &dstIP,
-                 zflow->src_port, zflow->dst_port, zflow->l4_proto,
-                 &src2dst_direction, zflow->first_switched,
-                 zflow->last_switched, 0, &new_flow, true,
-                 (u_int8_t *)zflow->src_mac, (u_int8_t *)zflow->dst_mac);
+#ifdef NTOPNG_PRO
+  if ((unique_source_id != 0)/* && (!isSubInterface())*/) {
 
-  INTERFACE_PROFILING_SECTION_EXIT(0);
+#if 0
+    ntop->getTrace()->traceEvent(TRACE_NORMAL, "unique_source_id=%u, inIndex=%u, outIndex=%u, exporter_device_ip=%u, nprobe_ip=%u [%u / %u]",
+				 unique_source_id,
+				 flow ? flow->getFlowDeviceInIndex()  : zflow->inIndex,
+				 flow ? flow->getFlowDeviceOutIndex() : zflow->outIndex,
+				 zflow->exporter_device_ip, zflow->nprobe_ip,
+				 zflow->inIndex, zflow->outIndex);
+#endif
 
-  if (flow == NULL)
-    return(false);
+    if (!flow_interfaces_stats->checkExporters(unique_source_id,
+					       flow ? flow->getFlowDeviceInIndex()  : zflow->inIndex,
+					       flow ? flow->getFlowDeviceOutIndex() : zflow->outIndex,
+					       zflow->exporter_device_ip, zflow->nprobe_ip)) {
+      static bool shown = false;
+
+      if (!shown) {
+        ntop->getTrace()->traceEvent(TRACE_NORMAL, "Flow dropped due to license limitations");
+
+        ntop->getTrace()->traceEvent(TRACE_NORMAL,
+				     "Exporters: %d/%d max | Exporter Interfaces: %d/%d max",
+				     ntop->getNumFlowExporters(), get_max_num_flow_exporters(),
+				     ntop->getNumFlowExportersInterfaces(),
+				     get_max_num_flow_exporters_interfaces());
+
+        ntop->getTrace()->traceEvent(TRACE_NORMAL,
+				     "Discarded [unique_source_id: %u];device_ip: %u][probe_ip: "
+				     "%u][iface: %u->%u]",
+				     unique_source_id, zflow->exporter_device_ip, zflow->nprobe_ip,
+				     zflow->inIndex, zflow->outIndex);
+
+        ntop->getRedis()->set(EXPORTERS_EXCEEDED_LIMITS_KEY, "1");
+        shown = true;
+      }
+
+      return false;
+    }
+  }
+#endif
+
+  if (flow == NULL) return (false);
 
   if (zflow->absolute_packet_octet_counters) {
     /* Ajdust bytes and packets counters if the zflow update contains absolute
@@ -300,6 +331,8 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
         zflow->in_pkts -= in_cur_pkts;
       else
         zflow->in_pkts = 0, out_of_sequence = true;
+
+      update_seen = true;
     }
 
     if (zflow->in_bytes) {
@@ -314,6 +347,8 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
         zflow->out_pkts -= out_cur_pkts;
       else
         zflow->out_pkts = 0, out_of_sequence = true;
+
+      update_seen = true;
     }
 
     if (zflow->out_bytes) {
@@ -340,28 +375,39 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
     }
   }
 
-  if (zflow->tcp.clientNwLatency.tv_sec || zflow->tcp.clientNwLatency.tv_usec)
-    flow->setFlowNwLatency(&zflow->tcp.clientNwLatency, src2dst_direction);
-
-  if (zflow->tcp.serverNwLatency.tv_sec || zflow->tcp.serverNwLatency.tv_usec)
-    flow->setFlowNwLatency(&zflow->tcp.serverNwLatency, !src2dst_direction);
-
+  if (zflow->tcp.clientNwLatency.tv_sec || zflow->tcp.clientNwLatency.tv_usec) {
+    /* As nProbe divides RTT by 2, we need to double it */
+    zflow->tcp.clientNwLatency.tv_sec *= 2, zflow->tcp.clientNwLatency.tv_usec *= 2;
+    flow->setFlowRTT(&zflow->tcp.clientNwLatency, src2dst_direction);
+  }
+  
+  if (zflow->tcp.serverNwLatency.tv_sec || zflow->tcp.serverNwLatency.tv_usec) {
+    /* As nProbe divides RTT by 2, we need to double it */
+    zflow->tcp.serverNwLatency.tv_sec *= 2, zflow->tcp.serverNwLatency.tv_usec *= 2;
+    flow->setFlowRTT(&zflow->tcp.serverNwLatency, !src2dst_direction);
+  }
+  
   flow->setEndReason(zflow->getEndReason());
   if (zflow->tcp.in_window)
     flow->setFlowTcpWindow(zflow->tcp.in_window, src2dst_direction);
   if (zflow->tcp.out_window)
     flow->setFlowTcpWindow(zflow->tcp.out_window, !src2dst_direction);
 
-  if (zflow->getFlowVerdict() == 2 /* DROP */) flow->setDropVerdict();
+  if (zflow->getFlowVerdict() == 2 /* DROP */) flow->setDropVerdict(DROP_REASON_PROBE_VERDICT);
 
   flow->setRisk(zflow->getRisk());
   flow->setTOS(zflow->src_tos, true), flow->setTOS(zflow->dst_tos, false);
-  flow->setRtt();
+  flow->setRTT();
 
-  if(zflow->getSIPCallId())
-    flow->setSIPCallId(zflow->getSIPCallId());
+  if (zflow->getWLANSSID())
+    flow->setWLANInfo(zflow->getWLANSSID(), zflow->getWTPMACAddress());
 
-  if(zflow->isSwapped()) flow->set_swap_done();
+  if (zflow->getL7JSON())
+    flow->setL7JSON(zflow->getL7JSON());
+
+  if (zflow->getSIPCallId()) flow->setSIPCallId(zflow->getSIPCallId());
+
+  if (zflow->isSwapped()) flow->set_swap_done();
 
   flow->setFlowSource(zflow->getFlowSource());
 
@@ -371,7 +417,9 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
   /* Update process and container info */
   if (zflow->hasParsedeBPF()) {
     bool swap_direction = ((ntohs(zflow->src_port) == flow->get_cli_port()) &&
-                           (ntohs(zflow->dst_port) == flow->get_srv_port())) ? false : true;
+                           (ntohs(zflow->dst_port) == flow->get_srv_port()))
+                              ? false
+                              : true;
 
     flow->setParsedeBPFInfo(zflow, swap_direction);
 
@@ -386,18 +434,18 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
 
 #ifdef MAC_DEBUG
   char bufm1[32], bufm2[32];
-  
+
   ntop->getTrace()->traceEvent(TRACE_NORMAL, "Processing Flow [src mac: %s][dst mac: %s][src2dst: %i]",
 			       Utils::formatMac(srcMac->get_mac(), bufm1, sizeof(bufm1)),
 			       Utils::formatMac(dstMac->get_mac(), bufm2, sizeof(bufm2)),
 			       (src2dst_direction) ? 1 : 0);
 #endif
 
-  in_pkts   = zflow->pkt_sampling_rate * zflow->in_pkts,
-    in_bytes  = zflow->pkt_sampling_rate * zflow->in_bytes,
-    out_pkts  = zflow->pkt_sampling_rate * zflow->out_pkts,
-    out_bytes = zflow->pkt_sampling_rate * zflow->out_bytes;
-    
+  in_pkts = zflow->pkt_sampling_rate * zflow->in_pkts,
+  in_bytes = zflow->pkt_sampling_rate * zflow->in_bytes,
+  out_pkts = zflow->pkt_sampling_rate * zflow->out_pkts,
+  out_bytes = zflow->pkt_sampling_rate * zflow->out_bytes;
+
   /* Update MAC stats
      Note: do not use src2dst_direction to inc the stats as
      in_bytes/in_pkts and out_bytes/out_pkts are already relative to the current
@@ -405,7 +453,7 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
   */
   if (likely(srcMac != NULL)) {
     srcMac->incSentStats(getTimeLastPktRcvd(), in_pkts, in_bytes);
-    srcMac->incRcvdStats(getTimeLastPktRcvd(),  out_pkts, out_bytes);
+    srcMac->incRcvdStats(getTimeLastPktRcvd(), out_pkts, out_bytes);
 
     srcMac->setSourceMac();
   }
@@ -420,61 +468,63 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
       /* There's a breadown between client and server TCP flags */
       if (zflow->tcp.client_tcp_flags)
         flow->updateTcpFlags(&now_tv, zflow->tcp.client_tcp_flags,
-                             src2dst_direction);
+                             src2dst_direction, new_flow);
 
       if (zflow->tcp.server_tcp_flags)
         flow->updateTcpFlags(&now_tv, zflow->tcp.server_tcp_flags,
-                             !src2dst_direction);
+                             !src2dst_direction, new_flow);
 
       if (zflow->tcp.tcp_flags && (zflow->tcp.client_tcp_flags == 0) &&
           (zflow->tcp.server_tcp_flags == 0)) {
-        /* TCP flags are cumulative and set only if client/server flags are zero */
-	
-        flow->updateTcpFlags(&now_tv, zflow->tcp.tcp_flags, src2dst_direction);
+        /* TCP flags are cumulative and set only if client/server flags are zero
+         */
+
+        flow->updateTcpFlags(&now_tv, zflow->tcp.tcp_flags, src2dst_direction,
+                             new_flow);
       }
     }
 
-    if (zflow->tcp.client_tcp_flags!=0 && zflow->tcp.server_tcp_flags != 0)
-      flow->calculateConnectionState(true);    
+    if (zflow->tcp.client_tcp_flags && zflow->tcp.server_tcp_flags)
+      flow->calculateConnectionState(true);
 
     flow->updateTcpSeqIssues(zflow);
 
-    Flow::incTcpBadStats(true, flow->get_cli_host(), flow->get_srv_host(), this,
+    flow->incTcpBadStats(true, flow->get_cli_host(), flow->get_srv_host(), this,
                          zflow->tcp.ooo_in_pkts, zflow->tcp.retr_in_pkts,
                          zflow->tcp.lost_in_pkts, 0 /* TODO: add keepalive */);
-    Flow::incTcpBadStats(false, flow->get_cli_host(), flow->get_srv_host(),
+    flow->incTcpBadStats(false, flow->get_cli_host(), flow->get_srv_host(),
                          this, zflow->tcp.ooo_out_pkts,
                          zflow->tcp.retr_out_pkts, zflow->tcp.lost_out_pkts,
                          0 /* TODO: add keepalive */);
   }
 
-  flow->addFlowStats(new_flow, src2dst_direction,
-                     in_pkts, in_bytes, 0,
-                     out_pkts, out_bytes, 0,
-                     zflow->pkt_sampling_rate * zflow->in_fragments,
-                     zflow->pkt_sampling_rate * zflow->out_fragments,
-                     zflow->first_switched, zflow->last_switched);
-
-  if(zflow->getPreNATSrcIp()) {
-    /* Add Pre-Post NAT src/dst IPv4 */
-    flow->addPrePostNATIPv4(zflow->getPreNATSrcIp(),
-			    zflow->getPreNATDstIp(),
-			    zflow->getPostNATSrcIp(),
-			    zflow->getPostNATDstIp());
-    
-    /* Add Pre-Post NAT src/dst Ports */
-    flow->addPrePostNATPort(zflow->getPreNATSrcPort(),
-			    zflow->getPreNATDstPort(),
-			    zflow->getPostNATSrcPort(),
-			    zflow->getPostNATDstPort());
+  if(flow->addFlowStats(new_flow, src2dst_direction, in_pkts, in_bytes, 0,
+			out_pkts, out_bytes, 0,
+			zflow->pkt_sampling_rate * zflow->in_fragments,
+			zflow->pkt_sampling_rate * zflow->out_fragments,
+			zflow->first_switched, zflow->last_switched) == false) {
+    if(update_seen) {
+      flow->updateSeen(zflow->last_switched);
+      flow->callFlowUpdate(zflow->last_switched);    
+    }
   }
-  
+
+  if (zflow->getPreNATSrcIp()) {
+    /* Add Pre-Post NAT src/dst IPv4 */
+    flow->addPrePostNATIPv4(zflow->getPreNATSrcIp(), zflow->getPreNATDstIp(),
+                            zflow->getPostNATSrcIp(), zflow->getPostNATDstIp());
+
+    /* Add Pre-Post NAT src/dst Ports */
+    flow->addPrePostNATPort(zflow->getPreNATSrcPort(), zflow->getPreNATDstPort(),
+			    zflow->getPostNATSrcPort(), zflow->getPostNATDstPort());
+  }
+
   if (!flow->isDetectionCompleted()) {
     ndpi_protocol p = Flow::ndpiUnknownProtocol;
     ndpi_protocol guessed_protocol = Flow::ndpiUnknownProtocol;
 
-    p.app_protocol = zflow->l7_proto.app_protocol;
-    p.master_protocol = zflow->l7_proto.master_protocol;
+    p.proto.app_protocol = zflow->l7_proto.proto.app_protocol;
+    p.proto.master_protocol = zflow->l7_proto.proto.master_protocol;
     p.category = NDPI_PROTOCOL_CATEGORY_UNSPECIFIED;
 
     /*
@@ -482,51 +532,23 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
       defined in ntopng will still be applied to the protocols detected by
       nprobe.
     */
-    if(zflow->src_ip.isIPv4()) {
-      guessed_protocol = ndpi_guess_undetected_protocol_v4(get_ndpi_struct(),
-							   flow->get_ndpi_flow(),
-							   flow->get_protocol(),
-							   ntohl(zflow->src_ip.get_ipv4()),
-							   ntohs(zflow->src_port),
-							   ntohl(zflow->dst_ip.get_ipv4()),
-							   ntohs(zflow->dst_port));
+    if (zflow->src_ip.isIPv4()) {
+      guessed_protocol = ndpi_guess_undetected_protocol_v4(
+          get_ndpi_struct(), flow->get_ndpi_flow(), flow->get_protocol(),
+          ntohl(zflow->src_ip.get_ipv4()), ntohs(zflow->src_port),
+          ntohl(zflow->dst_ip.get_ipv4()), ntohs(zflow->dst_port));
     } else {
       /* IPv6: use protcol guess only based on ports/protocol */
 
-      guessed_protocol = ndpi_guess_undetected_protocol_v4(get_ndpi_struct(),
-							   flow->get_ndpi_flow(),
-							   flow->get_protocol(),
-							   0, ntohs(zflow->src_port),
-							   0, ntohs(zflow->dst_port));
+      guessed_protocol = ndpi_guess_undetected_protocol_v4(
+          get_ndpi_struct(), flow->get_ndpi_flow(), flow->get_protocol(), 0,
+          ntohs(zflow->src_port), 0, ntohs(zflow->dst_port));
     }
 
-    guessed_protocol.app_protocol = ndpi_map_ndpi_id_to_user_proto_id(get_ndpi_struct(),
-								      guessed_protocol.app_protocol);
-    guessed_protocol.master_protocol = ndpi_map_ndpi_id_to_user_proto_id(get_ndpi_struct(),
-									 guessed_protocol.master_protocol);
-    
-#ifdef NTOPNG_PRO
-  if (unique_source_id) {
-      if (!flow_interfaces_stats)
-        flow_interfaces_stats = new (std::nothrow) FlowInterfacesStats();
-
-      if (flow_interfaces_stats) {
-	flow_interfaces_stats->incStats(now, unique_source_id, zflow->inIndex, flow->getStatsProtocol(),
-					out_pkts, out_bytes, in_pkts, in_bytes);
-
-	/* If the SNMP device is actually an host with an SNMP agent, then traffic
-	   can enter and leave it from the same interface (think to a management
-	   interface). For this reason it is important to check the outIndex and
-	   increase its counters only if it is different from inIndex to avoid
-	   double counting. */
-
-	if (zflow->outIndex != zflow->inIndex)
-	  flow_interfaces_stats->incStats(now, unique_source_id, zflow->outIndex,
-					  flow->getStatsProtocol(),
-					  in_pkts, in_bytes, out_pkts, out_bytes);
-      }
-  }
-#endif
+    guessed_protocol.proto.app_protocol = ndpi_map_ndpi_id_to_user_proto_id(
+        get_ndpi_struct(), guessed_protocol.proto.app_protocol);
+    guessed_protocol.proto.master_protocol = ndpi_map_ndpi_id_to_user_proto_id(
+        get_ndpi_struct(), guessed_protocol.proto.master_protocol);
 
     flow->setFlowVerdict(zflow->getFlowVerdict());
     flow->setJSONInfo(zflow->getAdditionalFieldsJSON());
@@ -545,8 +567,9 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
 
       if (custom_app_stats ||
           (custom_app_stats = new (std::nothrow) CustomAppStats(this))) {
-        custom_app_stats->incStats(zflow->getCustomApp().remapped_app_id,
-				   zflow->pkt_sampling_rate * (zflow->in_bytes + zflow->out_bytes));
+        custom_app_stats->incStats(
+            zflow->getCustomApp().remapped_app_id,
+            zflow->pkt_sampling_rate * (zflow->in_bytes + zflow->out_bytes));
       }
     }
 #endif
@@ -556,24 +579,22 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
       like "flow->updateDNS" as they check the actual protocol
      */
 
-    if (
-        /* If nprobe acts is in collector-passthrough mode L7_PROTO is not
+    if (/* If nprobe acts is in collector-passthrough mode L7_PROTO is not
            present, using the protocol guess on the ntopng side is desirable in
            this case */
-        ((zflow->l7_proto.app_protocol == NDPI_PROTOCOL_UNKNOWN)
-	 && (zflow->l7_proto.master_protocol == NDPI_PROTOCOL_UNKNOWN))
-	||
+        ((zflow->l7_proto.proto.app_protocol == NDPI_PROTOCOL_UNKNOWN) &&
+         (zflow->l7_proto.proto.master_protocol == NDPI_PROTOCOL_UNKNOWN)) ||
         /* If the protocol is greater than NDPI_MAX_SUPPORTED_PROTOCOLS, it
            means it is a custom protocol so the application protocol received
            from nprobe can be overridden */
-        (guessed_protocol.app_protocol >= NDPI_MAX_SUPPORTED_PROTOCOLS)) {
+        (guessed_protocol.proto.app_protocol >= NDPI_MAX_SUPPORTED_PROTOCOLS)) {
       p = guessed_protocol;
     }
 
     if (zflow->hasParsedeBPF()) {
       /* nProbe Agent does not perform nDPI detection*/
-      p.master_protocol = guessed_protocol.master_protocol;
-      p.app_protocol = guessed_protocol.app_protocol;
+      p.proto.master_protocol = guessed_protocol.proto.master_protocol;
+      p.proto.app_protocol = guessed_protocol.proto.app_protocol;
     }
 
     /* Now, depending on the q and on the zflow, there's an additional check
@@ -583,7 +604,7 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
 
     /* Here everything is setup and it is possible to set the actual protocol to
      * the flow */
-    flow->setDetectedProtocol(p);
+    flow->setDetectedProtocol(p, src2dst_direction);
 
     /*
       Parse flow info into the corresponding element (without overriding
@@ -592,16 +613,20 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
       - When nProbe has no plugins enabled, then nDPI data is taken
     */
     if (zflow->getL7Info() && zflow->getL7Info()[0]) {
-      if (flow->isDNS() && !zflow->getDNSQuery()) {
-        zflow->setDNSQuery(zflow->getL7Info());
-      } else if (flow->isHTTP() && !zflow->getHTTPsite()) {
-        zflow->setHTTPsite(zflow->getL7Info());
-        if (flow->get_cli_host())
-          flow->get_cli_host()->incrVisitedWebSite(zflow->getHTTPsite());
-      } else if (flow->isTLS() && !zflow->getTLSserverName()) {
-        zflow->setTLSserverName(zflow->getL7Info());
-        if (flow->get_cli_host())
-          flow->get_cli_host()->incrVisitedWebSite(zflow->getTLSserverName());
+      if (flow->isDNS()) {
+        if (!zflow->getDNSQuery()) zflow->setDNSQuery(zflow->getL7Info());
+      } else if (flow->isHTTP()) {
+        if (!zflow->getHTTPsite()) {
+          zflow->setHTTPsite(zflow->getL7Info());
+          if (flow->get_cli_host())
+            flow->get_cli_host()->incrVisitedWebSite(zflow->getHTTPsite());
+        }
+      } else if (flow->isTLS()) {
+        if (!zflow->getTLSserverName()) {
+          zflow->setTLSserverName(zflow->getL7Info());
+          if (flow->get_cli_host())
+            flow->get_cli_host()->incrVisitedWebSite(zflow->getTLSserverName());
+        }
       }
     }
 
@@ -609,36 +634,46 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
     flow->setConfidence(zflow->getConfidence());
     flow->setNdpiConfidence(zflow->getConfidence());
 
-    if (flow->isDNS())  flow->updateDNS(zflow);
+    if(flow->get_protocol() == IPPROTO_ICMP)
+      flow->setICMPTypeCode(zflow->icmp_type_code);
+    
+    if (flow->isDNS()) flow->updateDNS(zflow);
     if (flow->isHTTP()) flow->updateHTTP(zflow);
-    if (flow->isTLS())  flow->updateTLS(zflow);
+    if (flow->isTLS()) flow->updateTLS(zflow);
 
     if (flow->isSMTP()) {
       if (zflow->getSMTPMailFrom())
         flow->setSMTPMailFrom(zflow->getSMTPMailFrom());
-      if (zflow->getSMTPRcptTo())
-        flow->setSMTPRcptTo(zflow->getSMTPRcptTo());
+      if (zflow->getSMTPRcptTo()) flow->setSMTPRcptTo(zflow->getSMTPRcptTo());
     }
 
     if (flow->isDHCP()) {
-      if(zflow->getDHCPClientName()) {
-	flow->setDHCPHostName(zflow->getDHCPClientName());
+      if (zflow->getDHCPClientName()) {
+        flow->setDHCPHostName(zflow->getDHCPClientName());
       }
     }
 
-    if (zflow->getRiskName())
-      flow->setFlowRiskName(zflow->getRiskName());
+    if (zflow->getRiskName()) flow->setFlowRiskName(zflow->getRiskName());
 
     if (zflow->getBittorrentHash())
       flow->setBTHash(zflow->getBittorrentHash(true));
 
-    if (zflow->vrfId)  flow->setVRFid(zflow->vrfId);
+    if (zflow->vrfId) flow->setVRFid(zflow->vrfId);
     if (zflow->src_as) flow->setSrcAS(zflow->src_as);
     if (zflow->dst_as) flow->setDstAS(zflow->dst_as);
 
-    if (zflow->prev_adjacent_as) flow->setPrevAdjacentAS(zflow->prev_adjacent_as);
-    if (zflow->next_adjacent_as) flow->setNextAdjacentAS(zflow->next_adjacent_as);
+    if (zflow->prev_adjacent_as)
+      flow->setPrevAdjacentAS(zflow->prev_adjacent_as);
+    if (zflow->next_adjacent_as)
+      flow->setNextAdjacentAS(zflow->next_adjacent_as);
 
+    flow->setQoE(zflow->getQoESrc2Dst(), zflow->getQoEDst2Src());
+
+    if(zflow->getOSHint() != ndpi_os_unknown) {
+      if(flow->get_cli_host() != NULL)
+	flow->get_cli_host()->setnDPIOS(zflow->getOSHint());
+    }    
+    
     if (zflow->getJA4cHash()) flow->updateJA4C(zflow->getJA4cHash());
 
     if (zflow->getRiskInfo()) {
@@ -654,16 +689,15 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
         We use riskInfo to grab some flow attributes
         to enrich the memory flor representation
       */
-      if ((o = json_tokener_parse_verbose(zflow->getRiskInfo(), &jerr)) !=
-          NULL) {
+      if ((o = json_tokener_parse_verbose(zflow->getRiskInfo(), &jerr)) != NULL) {
         /* NOTE: keep in sync with  FlowRisk::ignoreRisk() */
         if (json_object_object_get_ex(o, "6" /* NDPI_TLS_SELFSIGNED_CERTIFICATE */, &obj)) {
           const char *issuerDN = json_object_get_string(obj);
-
-          if(flow->isTLS()) flow->setTLSCertificateIssuerDN((char *)issuerDN);
+	  
+          if (flow->isTLS()) flow->setTLSCertificateIssuerDN((char *)issuerDN);
         } else if (json_object_object_get_ex(o, "16" /* NDPI_SUSPICIOUS_DGA_DOMAIN */, &obj)) {
           const char *dgaDomain = json_object_get_string(obj);
-
+	  
           flow->setDGADomain((char *)dgaDomain);
         }
 
@@ -673,7 +707,8 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
 
     if (zflow->getExternalAlert()) {
       enum json_tokener_error jerr = json_tokener_success;
-      json_object *o = json_tokener_parse_verbose(zflow->getExternalAlert(), &jerr);
+      json_object *o =
+          json_tokener_parse_verbose(zflow->getExternalAlert(), &jerr);
 
       if (o) flow->setExternalAlert(o);
     }
@@ -681,6 +716,30 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
     flow->updateSuspiciousDGADomain();
   }
 
+#ifdef NTOPNG_PRO
+  if (unique_source_id) {
+    if (!flow_interfaces_stats)
+      flow_interfaces_stats = new (std::nothrow) FlowInterfacesStats();
+
+    if (flow_interfaces_stats) {
+      flow_interfaces_stats->incStats(now, unique_source_id, zflow->inIndex,
+                                      flow->getStatsProtocol(), out_pkts,
+                                      out_bytes, in_pkts, in_bytes);
+
+      /* If the SNMP device is actually an host with an SNMP agent, then traffic
+         can enter and leave it from the same interface (think to a management
+         interface). For this reason it is important to check the outIndex and
+         increase its counters only if it is different from inIndex to avoid
+         double counting. */
+
+      if (zflow->outIndex != zflow->inIndex)
+        flow_interfaces_stats->incStats(now, unique_source_id, zflow->outIndex,
+                                        flow->getStatsProtocol(), in_pkts,
+                                        in_bytes, out_pkts, out_bytes);
+    }
+  }
+#endif
+
   /* Do not put incStats before guessing the flow protocol */
   u_int16_t eth_type = srcIP.isIPv4() ? ETHERTYPE_IP : ETHERTYPE_IPV6;
 
@@ -694,10 +753,11 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
 #ifdef DEBUG
   char a[32], b[32];
 
-  ntop->getTrace()->traceEvent(TRACE_WARNING, "Direction: %u [ntop: %s][%s -> %s]", zflow->direction,
-			       flow->isLocalToRemote() ? "L->R" : "R->L",
-			       flow->get_cli_ip_addr()->print(a, sizeof(a)),
-			       flow->get_srv_ip_addr()->print(b, sizeof(b)));
+  ntop->getTrace()->traceEvent(
+      TRACE_WARNING, "Direction: %u [ntop: %s][%s -> %s]", zflow->direction,
+      flow->isLocalToRemote() ? "L->R" : "R->L",
+      flow->get_cli_ip_addr()->print(a, sizeof(a)),
+      flow->get_srv_ip_addr()->print(b, sizeof(b)));
 #endif
 
   if (zflow->direction == UNKNOWN_FLOW_DIRECTION) {
@@ -710,21 +770,21 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
   if (zflow->direction == 0 /* RX */) {
     if (zflow->in_pkts)
       incStats(true /* Ingress */, now, eth_type, flow->getStatsProtocol(),
-               flow->get_protocol_category(), zflow->l4_proto,
-               in_bytes, in_pkts);
+               flow->get_protocol_category(), zflow->l4_proto, in_bytes,
+               in_pkts);
     if (zflow->out_pkts)
       incStats(false /* Egress */, now, eth_type, flow->getStatsProtocol(),
-               flow->get_protocol_category(), zflow->l4_proto,
-               out_bytes, out_pkts);
+               flow->get_protocol_category(), zflow->l4_proto, out_bytes,
+               out_pkts);
   } else { /* TX */
     if (zflow->out_bytes)
       incStats(true /* Ingress */, now, eth_type, flow->getStatsProtocol(),
-               flow->get_protocol_category(), zflow->l4_proto,
-               out_bytes, out_pkts);
+               flow->get_protocol_category(), zflow->l4_proto, out_bytes,
+               out_pkts);
     if (zflow->in_pkts)
       incStats(false /* Egress */, now, eth_type, flow->getStatsProtocol(),
-               flow->get_protocol_category(), zflow->l4_proto,
-               in_bytes, in_pkts);
+               flow->get_protocol_category(), zflow->l4_proto, in_bytes,
+               in_pkts);
   }
 
 #ifdef NTOPNG_PRO
@@ -736,7 +796,7 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
        || ntop->get_export_interface()
 #endif
 #endif
-       )) {
+           )) {
     /* Dump flow */
     flow->dump(zflow->last_switched, true /* last dump before free */);
   }
@@ -745,7 +805,7 @@ bool ParserInterface::processFlow(ParsedFlow *zflow) {
   /* purge is actually performed at most one time every FLOW_PURGE_FREQUENCY */
   // purgeIdle(zflow->last_switched);
 
-  return(true);
+  return (true);
 }
 
 /* **************************************************** */
@@ -877,9 +937,10 @@ void ParserInterface::reloadCompanions() {
             }
           }
         } else
-          ntop->getTrace()->traceEvent(TRACE_ERROR,
-				       "Too many companion interfaces defined [interface: %s]",
-				       get_name());
+          ntop->getTrace()->traceEvent(
+              TRACE_ERROR,
+              "Too many companion interfaces defined [interface: %s]",
+              get_name());
       }
 
       free(companions[i]);
@@ -907,9 +968,9 @@ void ParserInterface::deliverFlowToCompanions(ParsedFlow *const flow) {
 
       if (!cur_companion) continue;
 
-      //ntop->getTrace()->traceEvent(TRACE_NORMAL,
-      //        "Trying to enqueue flow to companion interface [from: %s][to: %s]",
-      //        get_name(), cur_companion->get_name());
+      // ntop->getTrace()->traceEvent(TRACE_NORMAL,
+      //         "Trying to enqueue flow to companion interface [from: %s][to:
+      //         %s]", get_name(), cur_companion->get_name());
 
       if (cur_companion->isTrafficMirrored() ||
           !cur_companion->isPacketInterface()) {
