@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -207,7 +207,7 @@ void PcapInterface::cleanupPcapDumpDir() {
 static bool idle_flow_account(GenericHashEntry *h, void *user_data, bool *matched) {
   Flow *f = (Flow*)h;
   
-  f->accountFlowTraffic();
+  f->accountFlowTraffic(true);
 
   return(false);
 }
