@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -38,6 +38,7 @@ static activity_descr ad[] = {
     {FIVE_MINUTES_SCRIPT_DIR, 300, 300, false, false, true},
     {HOURLY_SCRIPT_DIR, 3600, 600, false, false, true},
     {DAILY_SCRIPT_DIR, 86400, 3600, true, false, true},
+    {MONTHLY_SCRIPT_DIR, 2592000, 3600, true, false, true},
 
     {NULL, 0, 0, false, false, false}};
 
@@ -99,11 +100,11 @@ void PeriodicActivities::run() {
     for (u_int16_t i = 0; i < num_sec_min_activities; i++)
       sec_min_activities[i]->schedule(this, now, false);
 
-    if(num_running_hour_day_activities == 0) {
-      /* At most only one concurrent activity */
-      for (u_int16_t i = 0; i < num_hour_day_activities; i++)
-	hour_day_activities[i]->schedule(this, now, true);
-    }
+    //if(num_running_hour_day_activities == 0) {
+    /* At most only one concurrent activity */
+    for (u_int16_t i = 0; i < num_hour_day_activities; i++)
+	    hour_day_activities[i]->schedule(this, now, true);
+    //}
     
     sleep(1);
   }
