@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -35,7 +35,7 @@ Radius::Radius(bool _use_chap) {
   
   result = 0, use_chap = _use_chap; /* true = CHAP, false = PAP */
   radiusAuthServer = radiusAcctServer = radiusSecret = radiusAdminGroup =
-    radiusUnprivCapabilitiesGroup = NULL;
+    radiusUnprivCapabilitiesGroup = authServer = NULL;
 
   /* Check if some information are already stored in redis */
   updateLoginInfo();
@@ -48,7 +48,8 @@ Radius::~Radius() {
   if (radiusUnprivCapabilitiesGroup) free(radiusUnprivCapabilitiesGroup);
   if (radiusAuthServer) free(radiusAuthServer);
   if (radiusAcctServer) free(radiusAcctServer);
-  if (radiusSecret) free(radiusSecret);
+  if (radiusSecret)     free(radiusSecret);
+  if (authServer)       free(authServer);
 }
 
 /* *************************************** */
