@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -50,8 +50,7 @@ RemoteHost::RemoteHost(NetworkInterface *_iface, int32_t _iface_idx,
 
 RemoteHost::~RemoteHost() {
   /* Decrease number of active hosts */
-  if(isUnicastHost())
-    iface->decNumHosts(isLocalHost(), is_rx_only);
+  iface->decNumHosts(this, is_rx_only);
 }
 
 /* *************************************** */
@@ -66,20 +65,21 @@ void RemoteHost::set_hash_entry_state_idle() {
 void RemoteHost::initialize() {
   char buf[64], host[96];
   char *strIP = ip.print(buf, sizeof(buf));
-  char rsp[256];
 
   snprintf(host, sizeof(host), "%s@%u", strIP, vlan_id);
   stats = allocateStats();
   updateHostPool(true /* inline with packet processing */,
                  true /* first inc */);
 
+#if 0  /* Redis won't cache remote hosts */
+  char rsp[256];
   if (ntop->getPrefs()->is_dns_resolution_enabled_for_all_hosts()) {
     /* Just ask ntopng to resolve the name. Actual name will be grabbed once
        needed using the getter.
     */
     ntop->getRedis()->getAddress(host, rsp, sizeof(rsp), true);
   }
-
-  if (isUnicastHost())
-    iface->incNumHosts(false /* isLocalHost() */, true /* Initialization: bytes are 0, considered RX only */);
+#endif
+  
+  iface->incNumHosts(this, true /* Initialization: bytes are 0, considered RX only */);
 }
