@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -133,7 +133,7 @@ void SNMP::handle_async_response(struct snmp_pdu *pdu, const char *agent_ip) {
       for (i = 0; i < len; i++) {
 	if((!isprint(vp->val.string[i]))
 	   && (!isspace(vp->val.string[i]))
-	   && (vp->val.string[i] < 191) /* Windows-1252 */
+	   // && (vp->val.string[i] < 191) /* Windows-1252 */
 	   ) {
 	  is_printable = false;
 	}
@@ -153,9 +153,9 @@ void SNMP::handle_async_response(struct snmp_pdu *pdu, const char *agent_ip) {
 	  int rc;
 
 	  if(left <= 2) break;
-	  rc = snprintf(&buf[idx], left, "%s%02X", (i == 0) ? "" : " ",
-			vp->val.string[i] & 0xFF);
 
+	  //rc = snprintf(&buf[idx], left, "%s%02X", (i == 0) ? "" : " ", vp->val.string[i] & 0xFF);
+	  rc = snprintf(&buf[idx], left, "%02X", vp->val.string[i] & 0xFF);
 	  if(rc <= 0)
 	    break;
 	  else
@@ -214,22 +214,36 @@ int asynch_response(int operation, struct snmp_session *sp, int reqid,
 
   switch (operation) {
   case NETSNMP_CALLBACK_OP_RECEIVED_MESSAGE:
-    if(pdu->command == SNMP_MSG_RESPONSE) {
-      sockaddr_in *sa = (sockaddr_in *)pdu->transport_data;
-      char buf[32], *peer = sp->peername;
+    switch(pdu->command) {
+    case SNMP_MSG_RESPONSE:
+    case SNMP_MSG_REPORT:
+      {
+	sockaddr_in *sa = (sockaddr_in *)pdu->transport_data;
+	char buf[32], *peer = sp->peername;
 
-      if(peer == NULL) {
-	if(sa->sin_family == 2) /* IPv4 */
-	  peer = Utils::intoaV4(ntohl(sa->sin_addr.s_addr), buf, sizeof(buf));
-	else
-	  ntop->getTrace()->traceEvent(TRACE_WARNING, "Missing IPv6 support");
+	if(peer == NULL) {
+	  if(sa->sin_family == 2) /* IPv4 */
+	    peer = Utils::intoaV4(ntohl(sa->sin_addr.s_addr), buf, sizeof(buf));
+	  else
+	    ntop->getTrace()->traceEvent(TRACE_WARNING, "Missing IPv6 support");
+	}
+
+	if(pdu->command == SNMP_MSG_RESPONSE) {
+	  s->handle_async_response(pdu, peer);
+	  rc = 1; /* SNMP_MSG_REPORT needs to be considered as an error */
+	} else {
+	  /* SNMP_MSG_REPORT */
+	  lua_pushnil(s->get_vm());
+	}
       }
+      break;
 
-      s->handle_async_response(pdu, peer), rc = 1;
-    } else
-      ntop->getTrace()->traceEvent(TRACE_WARNING, "Unhandled pdu command %d",
-				   pdu->command);
+    default:
+      ntop->getTrace()->traceEvent(TRACE_WARNING, "Unhandled pdu command %d", pdu->command);
+      break;
+    }
     break;
+
   case NETSNMP_CALLBACK_OP_TIMED_OUT:
     /* Reached when snmp_sess_timeout is called due to a timeout */
   default:
@@ -245,7 +259,7 @@ int asynch_response(int operation, struct snmp_session *sp, int reqid,
  * https://raw.githubusercontent.com/winlibs/net-snmp/master/snmplib/snmp_client.c
  */
 
-void SNMP::send_snmpv1v2c_request(char *agent_host, char *community,
+bool SNMP::send_snmpv1v2c_request(char *agent_host, char *community,
                                   snmp_pdu_primitive pduType, u_int version,
                                   char *_oid[SNMP_MAX_NUM_OIDS],
                                   bool _batch_mode) {
@@ -263,9 +277,8 @@ void SNMP::send_snmpv1v2c_request(char *agent_host, char *community,
       sessions.push_back(snmpSession);
       initSession = true;
     } catch (std::bad_alloc &ba) {
-      ntop->getTrace()->traceEvent(TRACE_WARNING,
-                                   "Unable to allocate SNMP session");
-      return;
+      ntop->getTrace()->traceEvent(TRACE_WARNING, "Unable to allocate SNMP session");
+      return(false);
     }
   } else {
     if(sessions.size() == 0) {
@@ -311,7 +324,7 @@ void SNMP::send_snmpv1v2c_request(char *agent_host, char *community,
 
   if((pdu = snmp_pdu_create(pdu_type)) == NULL) {
     ntop->getTrace()->traceEvent(TRACE_WARNING, "SNMP PDU create error");
-    return;
+    return(false);
   }
 
   if(pdu_type == SNMP_MSG_GETBULK) {
@@ -336,41 +349,48 @@ void SNMP::send_snmpv1v2c_request(char *agent_host, char *community,
     ntop->getTrace()->traceEvent(TRACE_WARNING, "SNMP send: no OID specified");
     snmp_free_pdu(pdu);
     snmp_perror("snmp_parse_oid");
+    return(false);
   } else {
     /* Send the request */
     if((rc = snmp_sess_send(snmpSession->session_ptr, pdu)) == 0) {
       snmp_free_pdu(pdu);
       snmp_perror("snmp_sess_send");
       ntop->getTrace()->traceEvent(TRACE_WARNING, "SNMP send error [rc: %d]", rc);
+      return(false);
     }
   }
 
   // snmp_free_pdu(pdu); /* TODO: this is apparently freed when we close the
   // session */
+
+  return(true);
 }
 
 /* ******************************************* */
 
-void SNMP::send_snmpv3_request(char *agent_host, char *level, char *username,
+bool SNMP::send_snmpv3_request(char *agent_host, char *level, char *username,
                                char *auth_protocol, char *auth_passphrase,
                                char *privacy_protocol, char *privacy_passphrase,
+			       char *contextName,
                                snmp_pdu_primitive pduType,
                                char *oid[SNMP_MAX_NUM_OIDS],
                                char value_types[SNMP_MAX_NUM_OIDS],
                                char *values[SNMP_MAX_NUM_OIDS],
                                bool _batch_mode) {
-  send_snmp_request(agent_host, 2 /* SNMPv3 */, NULL, level, username,
-                    auth_protocol, auth_passphrase, privacy_protocol,
-                    privacy_passphrase, pduType, oid, value_types, values,
-                    _batch_mode);
+  return(send_snmp_request(agent_host, 2 /* SNMPv3 */, NULL, level, username,
+			   auth_protocol, auth_passphrase, privacy_protocol,
+			   privacy_passphrase, contextName,
+			   pduType, oid, value_types, values,
+			   _batch_mode));
 }
 
 /* ******************************************* */
 
-void SNMP::send_snmp_request(char *agent_host, u_int version, char *community,
+bool SNMP::send_snmp_request(char *agent_host, u_int version, char *community,
                              char *level, char *username, char *auth_protocol,
                              char *auth_passphrase, char *privacy_protocol,
                              char *privacy_passphrase,
+			     char *contextName,
                              snmp_pdu_primitive pduType,
                              char *_oid[SNMP_MAX_NUM_OIDS],
                              char value_types[SNMP_MAX_NUM_OIDS],
@@ -390,9 +410,8 @@ void SNMP::send_snmp_request(char *agent_host, u_int version, char *community,
       sessions.push_back(snmpSession);
       initSession = true;
     } catch (std::bad_alloc &ba) {
-      ntop->getTrace()->traceEvent(TRACE_WARNING,
-                                   "Unable to allocate SNMP session");
-      return;
+      ntop->getTrace()->traceEvent(TRACE_WARNING, "Unable to allocate SNMP session");
+      return(false);
     }
   } else {
     if(sessions.size() == 0) {
@@ -419,52 +438,53 @@ void SNMP::send_snmp_request(char *agent_host, u_int version, char *community,
       /* SNMP v3 */
       snmpSession->session.version = SNMP_VERSION_3;
 
+      if(username && (username[0] == '\0'))
+	username = NULL;
+
       if(!strcasecmp(level, "noAuthNoPriv")) {
-        snmpSession->session.securityLevel = SNMP_SEC_LEVEL_NOAUTH;
-        username = NULL;
         auth_protocol = NULL;
         privacy_protocol = NULL;
-      } else {
-        /* set the SNMPv3 user name */
-        if(username) {
-          snmpSession->session.securityName = strdup(username);
-          snmpSession->session.securityNameLen =
-	    strlen(snmpSession->session.securityName);
-        } else {
-          ntop->getTrace()->traceEvent(TRACE_WARNING,
-                                       "SNMP PDU no username specified");
-          return;
-        }
 
+	snmpSession->session.securityModel = SNMP_SEC_MODEL_USM;  /* User-based Security Model (USM) */
+      } else {
         if((!strcasecmp(level, "authNoPriv")) ||
 	   (!strcasecmp(level, "authPriv"))) {
           if(!strcasecmp(auth_protocol, "md5")) {
-            snmpSession->session.securityAuthProto = usmHMACMD5AuthProtocol;
-            snmpSession->session.securityAuthProtoLen =
-	      sizeof(usmHMACMD5AuthProtocol) / sizeof(oid);
+            const int len = sizeof(usmHMACMD5AuthProtocol) / sizeof(oid);
+            snmpSession->session.securityAuthProto =
+              static_cast<oid *>(netsnmp_memdup(usmHMACMD5AuthProtocol, len));
+            snmpSession->session.securityAuthProtoLen = len;
             snmpSession->session.securityAuthKeyLen = USM_AUTH_KU_LEN;
           } else if(!strcasecmp(auth_protocol, "sha")) {
-            snmpSession->session.securityAuthProto = usmHMACSHA1AuthProtocol;
-            snmpSession->session.securityAuthProtoLen =
-	      sizeof(usmHMACSHA1AuthProtocol) / sizeof(oid);
-            snmpSession->session.securityAuthKeyLen =
-	      USM_AUTH_KU_LEN; /* CHECK */
+	    snmpSession->session.securityAuthProto = usmHMACSHA1AuthProtocol;
+	    snmpSession->session.securityAuthProtoLen = sizeof(usmHMACSHA1AuthProtocol) / sizeof(oid);
+#ifdef NETSNMP_USMAUTH_HMAC192SHA256
+          } else if(!strcasecmp(auth_protocol, "sha256")) {
+            snmpSession->session.securityAuthProto = usmHMAC192SHA256AuthProtocol;
+            snmpSession->session.securityAuthProtoLen = sizeof(usmHMAC192SHA256AuthProtocol) / sizeof(oid);
+          } else if(!strcasecmp(auth_protocol, "sha384")) {
+            snmpSession->session.securityAuthProto = usmHMAC256SHA384AuthProtocol;
+            snmpSession->session.securityAuthProtoLen = sizeof(usmHMAC256SHA384AuthProtocol) / sizeof(oid);
+          } else if(!strcasecmp(auth_protocol, "sha512")) {
+            snmpSession->session.securityAuthProto = usmHMAC384SHA512AuthProtocol;
+            snmpSession->session.securityAuthProtoLen = sizeof(usmHMAC384SHA512AuthProtocol) / sizeof(oid);
+#endif
           } else {
-            ntop->getTrace()->traceEvent(
-					 TRACE_WARNING, "SNMP PDU invalid authentication protocol [%s]",
+            ntop->getTrace()->traceEvent(TRACE_WARNING, "SNMP PDU invalid authentication protocol [%s]",
 					 auth_protocol);
-            return;
+            return(false);
           }
 
+	  snmpSession->session.securityAuthKeyLen = USM_AUTH_KU_LEN; /* CHECK */
+
           if(generate_Ku(snmpSession->session.securityAuthProto,
 			 snmpSession->session.securityAuthProtoLen,
 			 (u_char *)auth_passphrase, strlen(auth_passphrase),
 			 snmpSession->session.securityAuthKey,
-			 &snmpSession->session.securityAuthKeyLen) !=
-	     SNMPERR_SUCCESS) {
-            ntop->getTrace()->traceEvent(
-					 TRACE_WARNING, "SNMP PDU authentication pass phrase error");
-            return;
+			 &snmpSession->session.securityAuthKeyLen) != SNMPERR_SUCCESS) {
+	    /* snmp_perror(""); */
+            ntop->getTrace()->traceEvent(TRACE_WARNING, "SNMP PDU authentication pass phrase error");
+            return(false);
           }
 
           if(!strcasecmp(level, "authPriv")) {
@@ -472,17 +492,26 @@ void SNMP::send_snmp_request(char *agent_host, u_int version, char *community,
 
 #ifndef NETSNMP_DISABLE_DES
             if(!strcasecmp(privacy_protocol, "DES")) {
-              snmpSession->session.securityPrivProto = snmp_duplicate_objid(
-									    usmDESPrivProtocol, USM_PRIV_PROTO_DES_LEN);
-              snmpSession->session.securityPrivProtoLen =
-		USM_PRIV_PROTO_DES_LEN;
+              snmpSession->session.securityPrivProto = snmp_duplicate_objid(usmDESPrivProtocol, USM_PRIV_PROTO_DES_LEN);
+              snmpSession->session.securityPrivProtoLen = USM_PRIV_PROTO_DES_LEN;
             } else
 #endif
 	      if(!strncasecmp(privacy_protocol, "AES", 3)) {
-		snmpSession->session.securityPrivProto = snmp_duplicate_objid(
-									      usmAESPrivProtocol, USM_PRIV_PROTO_AES_LEN);
-		snmpSession->session.securityPrivProtoLen =
-                  USM_PRIV_PROTO_AES_LEN;
+		snmpSession->session.securityPrivProto = snmp_duplicate_objid(usmAESPrivProtocol, USM_PRIV_PROTO_AES_LEN);
+		snmpSession->session.securityPrivProtoLen = USM_PRIV_PROTO_AES_LEN;
+	      } else if(!strncasecmp(privacy_protocol, "AES128", 6)) {
+		snmpSession->session.securityPrivProto = snmp_duplicate_objid(usmAESPrivProtocol, USM_PRIV_PROTO_AES128_LEN);
+		snmpSession->session.securityPrivProtoLen = USM_PRIV_PROTO_AES128_LEN;
+#ifdef USM_PRIV_PROTO_AES256_LEN /* Just in case one day it twill be supported */
+		/*
+		   Note AES-256 is not supported by net-snmp
+		   See also https://snmp.com/snmpv3/snmpv3_aes256.shtml
+		*/
+
+	      } else if(!strncasecmp(privacy_protocol, "AES256", 6)) {
+		snmpSession->session.securityPrivProto = snmp_duplicate_objid(usmAESPrivProtocol, USM_PRIV_PROTO_AES256_LEN);
+		snmpSession->session.securityPrivProtoLen = USM_PRIV_PROTO_AES256_LEN;
+#endif
 	      }
 
             snmpSession->session.securityPrivKeyLen = USM_PRIV_KU_LEN;
@@ -491,16 +520,28 @@ void SNMP::send_snmp_request(char *agent_host, u_int version, char *community,
 			   (u_char *)privacy_passphrase,
 			   strlen(privacy_passphrase),
 			   snmpSession->session.securityPrivKey,
-			   &snmpSession->session.securityPrivKeyLen) !=
-	       SNMPERR_SUCCESS) {
-              ntop->getTrace()->traceEvent(TRACE_WARNING,
-                                           "SNMP PDU security privacy error");
-              return;
+			   &snmpSession->session.securityPrivKeyLen) != SNMPERR_SUCCESS) {
+              ntop->getTrace()->traceEvent(TRACE_WARNING, "SNMP PDU security privacy error");
+              return(false);
             }
           } else
             snmpSession->session.securityLevel = SNMP_SEC_LEVEL_AUTHNOPRIV;
         }
       }
+
+      if(username) {
+	/* SNMPv3 user name */
+	snmpSession->session.securityName = strdup(username);
+	snmpSession->session.securityNameLen = strlen(snmpSession->session.securityName);
+      }
+
+      if(snmpSession->session.securityLevel == 0)
+	snmpSession->session.securityLevel = SNMP_SEC_LEVEL_NOAUTH;
+    }
+
+    if((contextName != NULL) && (contextName[0] != '\0')) {
+      snmpSession->session.contextName = contextName;
+      snmpSession->session.contextNameLen = strlen(contextName);
     }
 
     snmpSession->session.callback = asynch_response;
@@ -525,7 +566,7 @@ void SNMP::send_snmp_request(char *agent_host, u_int version, char *community,
     pdu_type = SNMP_MSG_SET;
     if(values == NULL) {
       ntop->getTrace()->traceEvent(TRACE_WARNING, "SNMP PDU create error");
-      return;
+      return(false);
     }
     break;
   default:
@@ -537,7 +578,7 @@ void SNMP::send_snmp_request(char *agent_host, u_int version, char *community,
 
   if((pdu = snmp_pdu_create(pdu_type)) == NULL) {
     ntop->getTrace()->traceEvent(TRACE_WARNING, "SNMP PDU create error");
-    return;
+    return(false);
   }
 
   if(pdu_type == SNMP_MSG_GETBULK) {
@@ -565,15 +606,18 @@ void SNMP::send_snmp_request(char *agent_host, u_int version, char *community,
     snmp_free_pdu(pdu);
     snmp_perror("snmp_sess_send");
     ntop->getTrace()->traceEvent(TRACE_WARNING, "SNMP send error [rc: %d]", rc);
+    return(false);
   }
 
   // snmp_free_pdu(pdu); /* TODO: this is apparently freed when we close the
   // session */
+
+  return(true);
 }
 
 /* ******************************************* */
 
-void SNMP::send_snmp_set_request(char *agent_host, char *community,
+bool SNMP::send_snmp_set_request(char *agent_host, char *community,
                                  snmp_pdu_primitive pduType, u_int version,
                                  char *_oid[SNMP_MAX_NUM_OIDS],
                                  char value_types[SNMP_MAX_NUM_OIDS],
@@ -594,7 +638,7 @@ void SNMP::send_snmp_set_request(char *agent_host, char *community,
     } catch (std::bad_alloc &ba) {
       ntop->getTrace()->traceEvent(TRACE_WARNING,
                                    "Unable to allocate SNMP session");
-      return;
+      return(false);
     }
   } else {
     if(sessions.size() == 0) {
@@ -626,7 +670,7 @@ void SNMP::send_snmp_set_request(char *agent_host, char *community,
   /* Create the PDU */
   if((pdu = snmp_pdu_create(SNMP_MSG_SET)) == NULL) {
     ntop->getTrace()->traceEvent(TRACE_WARNING, "SNMP PDU create error");
-    return;
+    return(false);
   }
 
   for (u_int i = 0; i < SNMP_MAX_NUM_OIDS; i++) {
@@ -647,7 +691,10 @@ void SNMP::send_snmp_set_request(char *agent_host, char *community,
     snmp_free_pdu(pdu);
     snmp_perror("snmp_sess_send");
     ntop->getTrace()->traceEvent(TRACE_WARNING, "SNMP send error [rc: %d]", rc);
+    return(false);
   }
+
+  return(true);
 }
 
 /* ******************************************* */
@@ -683,14 +730,14 @@ void SNMP::snmp_fetch_responses(lua_State *_vm, u_int timeout) {
     */
 
     /* ntop->getTrace()->traceEvent(TRACE_WARNING, "%s() [timeout: %u][block: %u]", __FUNCTION__, timeout, block); */
-    
+
     if((timeout > 0 /* The caller is willing to wait up to a timeout */)
        || (block == 0 /* The caller doesn't want to wait so the select is only performed when it doesn't block */)) {
       /* ntop->getTrace()->traceEvent(TRACE_WARNING, "%s(timeout: %u)[count: %u]", __FUNCTION__, tvp.tv_sec, count); */
 
       if((timeout > 0) && (tvp.tv_sec == 0))
 	tvp.tv_sec = 1; /* Set a minimum timeout in case it has been cleared by snmp_sess_select_info */
-      
+
       count = select(numfds, &fdset, NULL, NULL, &tvp);
 
       if(count > 0) {
@@ -767,7 +814,7 @@ int SNMP::snmp_read_response(lua_State *vm, u_int timeout) {
 
 /* ******************************************* */
 
-void SNMP::send_snmpv1v2c_request(char *agent_host, char *community,
+bool SNMP::send_snmpv1v2c_request(char *agent_host, char *community,
                                   snmp_pdu_primitive pduType, u_int version,
                                   char *oid[SNMP_MAX_NUM_OIDS],
                                   bool _batch_mode) {
@@ -776,8 +823,8 @@ void SNMP::send_snmpv1v2c_request(char *agent_host, char *community,
   SNMPMessage *message;
   int len;
   u_char buf[1500];
-  int operation = (pduType == snmp_get_pdu) ? NTOP_SNMP_GET_REQUEST_TYPE
-    : NTOP_SNMP_GETNEXT_REQUEST_TYPE;
+  int operation = (pduType == snmp_get_pdu) ? NTOP_SNMP_GET_REQUEST_TYPE : NTOP_SNMP_GETNEXT_REQUEST_TYPE;
+  bool found = false;
 
   batch_mode = _batch_mode;
 
@@ -791,7 +838,7 @@ void SNMP::send_snmpv1v2c_request(char *agent_host, char *community,
 
     for (i = 0; i < SNMP_MAX_NUM_OIDS; i++) {
       if(oid[i] != NULL)
-        snmp_add_varbind_null(message, oid[i]);
+        snmp_add_varbind_null(message, oid[i]), found = true;
       else
         break;
     }
@@ -803,6 +850,8 @@ void SNMP::send_snmpv1v2c_request(char *agent_host, char *community,
 
     send_udp_datagram(buf, len, udp_sock, agent_host, agent_port);
   }
+
+  return(found);
 }
 
 /* ******************************************* */
@@ -928,7 +977,7 @@ int SNMP::set(lua_State *vm, bool skip_first_param) {
 int SNMP::snmpv3_get_fctn(lua_State *vm, snmp_pdu_primitive pduType,
                           bool skip_first_param, bool _batch_mode) {
   char *agent_host, *level, *username, *auth_protocol, *auth_passphrase,
-    *privacy_protocol, *privacy_passphrase;
+    *privacy_protocol, *privacy_passphrase, *context_name;
   u_int timeout = 5, oid_idx = 0, idx = skip_first_param ? 2 : 1;
   char *oid[SNMP_MAX_NUM_OIDS] = {NULL},
     value_types[SNMP_MAX_NUM_OIDS] = {'\0'},
@@ -962,6 +1011,10 @@ int SNMP::snmpv3_get_fctn(lua_State *vm, snmp_pdu_primitive pduType,
     return (CONST_LUA_ERROR);
   privacy_passphrase = (char *)lua_tostring(vm, idx++);
 
+  if(ntop_lua_check(vm, __FUNCTION__, idx, LUA_TSTRING) != CONST_LUA_OK)
+    return (CONST_LUA_ERROR);
+  context_name = (char *)lua_tostring(vm, idx++);
+
   if(ntop_lua_check(vm, __FUNCTION__, idx, LUA_TNUMBER) != CONST_LUA_OK)
     return (CONST_LUA_ERROR);
   timeout = min(timeout, (u_int)lua_tointeger(vm, idx));
@@ -999,7 +1052,7 @@ int SNMP::snmpv3_get_fctn(lua_State *vm, snmp_pdu_primitive pduType,
 
   send_snmpv3_request(agent_host, level, username, auth_protocol,
                       auth_passphrase, privacy_protocol, privacy_passphrase,
-                      pduType, oid, value_types, values, _batch_mode);
+                      context_name, pduType, oid, value_types, values, _batch_mode);
 
   if(skip_first_param)
     return (CONST_LUA_OK); /* This is an async call */
@@ -1052,7 +1105,7 @@ int SNMP::snmp_get_fctn(lua_State *vm, snmp_pdu_primitive pduType,
 	if(pduType == snmp_set_pdu) {
 	  /* SET */
 	  char *o = (char *)lua_tostring(vm, idx);
-	  
+
 	  /* Remove heading spaces */
 	  while(o[0] == ' ') o++;
 
@@ -1080,7 +1133,7 @@ int SNMP::snmp_get_fctn(lua_State *vm, snmp_pdu_primitive pduType,
 
 	  /* Remove heading spaces */
 	  while(o[0] == ' ') o++;
-	  
+
 	  oid[oid_idx++] = o;
 	  idx++;
 	}
@@ -1111,4 +1164,3 @@ int SNMP::snmp_get_fctn(lua_State *vm, snmp_pdu_primitive pduType,
 }
 
 /* ******************************************* */
-
