@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -35,7 +35,7 @@ ZMQCollectorInterface::ZMQCollectorInterface(const char *_endpoint) : ZMQParserI
   const char **topics = Utils::getMessagingTopics();
 
   if(trace_new_delete) ntop->getTrace()->traceEvent(TRACE_NORMAL, "[new] %s", __FILE__);
-  
+
   num_subscribers = 0;
   server_secret_key[0] = '\0';
   server_public_key[0] = '\0';
@@ -55,10 +55,9 @@ ZMQCollectorInterface::ZMQCollectorInterface(const char *_endpoint) : ZMQParserI
     if (strncmp(e, "zmq", 3) == 0) e[0] = 't', e[1] = 'c', e[2] = 'p';
 
     if (num_subscribers == MAX_ZMQ_SUBSCRIBERS) {
-      ntop->getTrace()->traceEvent(
-          TRACE_ERROR,
-          "Too many endpoints defined %u: skipping those in excess",
-          num_subscribers);
+      ntop->getTrace()->traceEvent(TRACE_ERROR,
+				   "Too many endpoints defined %u: skipping those in excess",
+				   num_subscribers);
       break;
     }
 
@@ -83,7 +82,7 @@ ZMQCollectorInterface::ZMQCollectorInterface(const char *_endpoint) : ZMQParserI
       }
 #else
       ntop->getTrace()->traceEvent(TRACE_ERROR,
-          "Unable to enable ZMQ CURVE encryption, ZMQ >= 4.1 is required");
+				   "Unable to enable ZMQ CURVE encryption, ZMQ >= 4.1 is required");
 #endif
     }
 
@@ -104,10 +103,9 @@ ZMQCollectorInterface::ZMQCollectorInterface(const char *_endpoint) : ZMQParserI
       if (zmq_bind(subscriber[num_subscribers].socket, e) != 0) {
         zmq_close(subscriber[num_subscribers].socket);
         zmq_ctx_destroy(context);
-        ntop->getTrace()->traceEvent(
-            TRACE_ERROR,
-            "Unable to bind to ZMQ endpoint %s [collector]: %s (%d)", e,
-            strerror(errno), errno);
+        ntop->getTrace()->traceEvent(TRACE_ERROR,
+				     "Unable to bind to ZMQ endpoint %s [collector]: %s (%d)", e,
+				     strerror(errno), errno);
         free(tmp);
         throw("Unable to bind to the specified ZMQ endpoint");
       }
@@ -115,23 +113,19 @@ ZMQCollectorInterface::ZMQCollectorInterface(const char *_endpoint) : ZMQParserI
       if (zmq_connect(subscriber[num_subscribers].socket, e) != 0) {
         zmq_close(subscriber[num_subscribers].socket);
         zmq_ctx_destroy(context);
-        ntop->getTrace()->traceEvent(
-            TRACE_ERROR,
-            "Unable to connect to ZMQ endpoint %s [probe]: %s (%d)", e,
-            strerror(errno), errno);
+        ntop->getTrace()->traceEvent(TRACE_ERROR,
+				     "Unable to connect to ZMQ endpoint %s [probe]: %s (%d)", e,
+				     strerror(errno), errno);
         free(tmp);
         throw("Unable to connect to the specified ZMQ endpoint");
       }
     }
 
     for (int i = 0; topics[i] != NULL; i++) {
-      if (zmq_setsockopt(subscriber[num_subscribers].socket, ZMQ_SUBSCRIBE,
-                         topics[i], strlen(topics[i])) != 0) {
+      if (zmq_setsockopt(subscriber[num_subscribers].socket, ZMQ_SUBSCRIBE, topics[i], strlen(topics[i])) != 0) {
         zmq_close(subscriber[num_subscribers].socket);
         zmq_ctx_destroy(context);
-        ntop->getTrace()->traceEvent(
-            TRACE_ERROR, "Unable to connect to subscribe to topic %s",
-            topics[i]);
+        ntop->getTrace()->traceEvent(TRACE_ERROR, "Unable to connect to subscribe to topic %s", topics[i]);
         free(tmp);
         throw("Unable to subscribe to the specified ZMQ endpoint");
       }
@@ -151,17 +145,16 @@ ZMQCollectorInterface::ZMQCollectorInterface(const char *_endpoint) : ZMQParserI
 
 ZMQCollectorInterface::~ZMQCollectorInterface() {
   map<u_int32_t, zmq_probe *>::iterator p;
-  
+
 #ifdef INTERFACE_PROFILING
   u_int64_t n = recvStats.num_flows;
 
   if (n > 0) {
     for (u_int i = 0; i < INTERFACE_PROFILING_NUM_SECTIONS; i++) {
       if (INTERFACE_PROFILING_SECTION_LABEL(i) != NULL)
-        ntop->getTrace()->traceEvent(
-            TRACE_NORMAL, "[PROFILING] Section #%d '%s': AVG %llu ticks", i,
-            INTERFACE_PROFILING_SECTION_LABEL(i),
-            INTERFACE_PROFILING_SECTION_AVG(i, n));
+        ntop->getTrace()->traceEvent(TRACE_NORMAL, "[PROFILING] Section #%d '%s': AVG %llu ticks", i,
+				     INTERFACE_PROFILING_SECTION_LABEL(i),
+				     INTERFACE_PROFILING_SECTION_AVG(i, n));
       ntop->getTrace()->traceEvent(TRACE_NORMAL,
                                    "[PROFILING] Section #%d '%s': %llu ticks",
                                    i, INTERFACE_PROFILING_SECTION_LABEL(i),
@@ -177,17 +170,18 @@ ZMQCollectorInterface::~ZMQCollectorInterface() {
 
   for (p = active_probes.begin(); p != active_probes.end(); p++) {
     zmq_probe *probe = p->second;
-    
+
     free(probe);
   }
-  
+
   zmq_ctx_destroy(context);
 }
 
 /* **************************************************** */
 
 #if ZMQ_VERSION >= ZMQ_MAKE_VERSION(4, 1, 0)
-char *ZMQCollectorInterface::findInterfaceEncryptionKeys(char *public_key, char *secret_key, int public_key_len, int secret_key_len) {
+char *ZMQCollectorInterface::findInterfaceEncryptionKeys(char *public_key, char *secret_key,
+							 int public_key_len, int secret_key_len) {
   char public_key_path[PATH_MAX], secret_key_path[PATH_MAX];
   bool rc = false;
 
@@ -197,7 +191,8 @@ char *ZMQCollectorInterface::findInterfaceEncryptionKeys(char *public_key, char
              ntop->get_working_dir(), get_id());
     snprintf(secret_key_path, sizeof(secret_key_path), "%s/%d/key.priv",
              ntop->get_working_dir(), get_id());
-    rc = ZMQUtils::readEncryptionKeysFromFile(public_key_path, secret_key_path, public_key, secret_key, public_key_len, secret_key_len);
+    rc = ZMQUtils::readEncryptionKeysFromFile(public_key_path, secret_key_path,
+					      public_key, secret_key, public_key_len, secret_key_len);
   }
 
   if (!rc) {
@@ -214,15 +209,15 @@ char *ZMQCollectorInterface::findInterfaceEncryptionKeys(char *public_key, char
 void ZMQCollectorInterface::checkPointCounters(bool drops_only) {
   if (!drops_only) {
     recvStatsCheckpoint.num_flows = recvStats.num_flows,
-    recvStatsCheckpoint.num_dropped_flows = recvStats.num_dropped_flows,
-    recvStatsCheckpoint.num_events = recvStats.num_events,
-    recvStatsCheckpoint.num_counters = recvStats.num_counters,
-    recvStatsCheckpoint.num_templates = recvStats.num_templates,
-    recvStatsCheckpoint.num_options = recvStats.num_options,
-    recvStatsCheckpoint.num_network_events = recvStats.num_network_events,
-    recvStatsCheckpoint.zmq_msg_rcvd = recvStats.zmq_msg_rcvd;
+      recvStatsCheckpoint.num_events = recvStats.num_events,
+      recvStatsCheckpoint.num_counters = recvStats.num_counters,
+      recvStatsCheckpoint.num_templates = recvStats.num_templates,
+      recvStatsCheckpoint.num_options = recvStats.num_options,
+      recvStatsCheckpoint.num_network_events = recvStats.num_network_events,
+      recvStatsCheckpoint.zmq_msg_rcvd = recvStats.zmq_msg_rcvd;
   }
 
+  recvStatsCheckpoint.num_dropped_flows = recvStats.num_dropped_flows;
   recvStatsCheckpoint.zmq_msg_drops = recvStats.zmq_msg_drops;
 
   NetworkInterface::checkPointCounters(drops_only);
@@ -244,17 +239,15 @@ void ZMQCollectorInterface::checkIdleProbes(time_t now) {
       free(probe);
     } else
       p++;
-  } 
+  }
 }
 
 /* **************************************************** */
 
 void ZMQCollectorInterface::collect_flows() {
   struct zmq_msg_hdr_v0 h0;
-  struct zmq_msg_hdr_v1 *h =
-      (struct zmq_msg_hdr_v1 *)&h0; /* NOTE: in network-byte-order format */
-  char *payload = NULL;
-  const u_int payload_len = 131072;
+  struct zmq_msg_hdr_v1 *h = (struct zmq_msg_hdr_v1 *)&h0; /* NOTE: in network-byte-order format */
+  char *zmq_payload = NULL;
   zmq_pollitem_t items[MAX_ZMQ_SUBSCRIBERS];
   u_int32_t zmq_max_num_polls_before_purge = MAX_ZMQ_POLLS_BEFORE_PURGE;
   u_int32_t now, next_purge_idle = (u_int32_t)time(NULL) + FLOW_PURGE_FREQUENCY;
@@ -262,7 +255,7 @@ void ZMQCollectorInterface::collect_flows() {
 
   ntop->getTrace()->traceEvent(TRACE_NORMAL, "Collecting flows on %s", ifname);
 
-  if ((payload = (char *)malloc(payload_len + 1 /* Leave a char for \0 */)) ==
+  if ((zmq_payload = (char *)malloc(CONST_ZMQ_PAYLOAD_LEN + 1 /* Leave a char for \0 */)) ==
       NULL) {
     ntop->getTrace()->traceEvent(TRACE_ERROR, "Out of memory");
     return;
@@ -276,14 +269,14 @@ void ZMQCollectorInterface::collect_flows() {
       if (ntop->getGlobals()->isShutdown()) {
         ntop->getTrace()->traceEvent(TRACE_NORMAL,
 				     "Flow collection on %s is over: ntop is shutting down", ifname);
-        free(payload);
+        free(zmq_payload);
         return;
       }
     }
 
     for (int i = 0; i < num_subscribers; i++)
       items[i].socket = subscriber[i].socket, items[i].fd = 0,
-      items[i].events = ZMQ_POLLIN, items[i].revents = 0;
+	items[i].events = ZMQ_POLLIN, items[i].revents = 0;
 
     do {
       rc = zmq_poll(items, num_subscribers, MAX_ZMQ_POLL_WAIT_MS);
@@ -292,7 +285,7 @@ void ZMQCollectorInterface::collect_flows() {
       zmq_max_num_polls_before_purge--;
 
       if (rc < 0 || !isRunning()) {
-        if (payload) free(payload);
+        if (zmq_payload) free(zmq_payload);
         ntop->getTrace()->traceEvent(TRACE_NORMAL,
 				     "Flow collection is over on %s: ntop is shutting down",
 				     ifname);
@@ -310,12 +303,14 @@ void ZMQCollectorInterface::collect_flows() {
     } while (rc == 0);
 
     for (int subscriber_id = 0; subscriber_id < num_subscribers; subscriber_id++) {
-
       if (items[subscriber_id].revents & ZMQ_POLLIN) {
         u_int32_t msg_id = 0, current_msg_id = 0;
         u_int32_t source_id = 0;
         u_int32_t publisher_version = 0;
+	u_int32_t received_compressed_size = 0;
         zmq_probe *probe = NULL;
+	bool tlv_encoding = false;
+	bool compressed = false;
 
         size = zmq_recv(items[subscriber_id].socket, &h0, sizeof(h0), 0);
 
@@ -324,17 +319,16 @@ void ZMQCollectorInterface::collect_flows() {
           publisher_version = h0.version;
         } else {
           /* safety checks */
-          if (((size != sizeof(struct zmq_msg_hdr_v1)) &&
-               (size != sizeof(struct zmq_msg_hdr_v2))) ||
-              ((h->version != ZMQ_MSG_VERSION) &&
-               (h->version != ZMQ_MSG_VERSION_TLV) &&
-               (h->version != ZMQ_COMPATIBILITY_MSG_VERSION))) {
-            ntop->getTrace()->traceEvent(
-                TRACE_WARNING,
-                "Unsupported publisher version: is your nProbe sender "
-                "outdated? [%u][%u][%u][%u][%u]",
-                size, sizeof(struct zmq_msg_hdr_v1), h->version,
-                ZMQ_MSG_VERSION, ZMQ_COMPATIBILITY_MSG_VERSION);
+          if (((size != sizeof(struct zmq_msg_hdr_v3)) &&
+               (size != sizeof(struct zmq_msg_hdr_v2)) &&
+	       (size != sizeof(struct zmq_msg_hdr_v1))
+	       ) ||
+              (h->version > ZMQ_MSG_VERSION)) {
+            ntop->getTrace()->traceEvent(TRACE_WARNING,
+					 "Unsupported publisher version: is your nProbe sender "
+					 "outdated? [%u][%u][%u][%u][%u]",
+					 size, sizeof(struct zmq_msg_hdr_v1), h->version,
+					 ZMQ_MSG_VERSION, ZMQ_COMPATIBILITY_MSG_VERSION);
             continue; /* skip message */
           }
 
@@ -344,8 +338,7 @@ void ZMQCollectorInterface::collect_flows() {
 #endif
 
 #ifdef ZMQ_DEBUG
-          ntop->getTrace()->traceEvent(TRACE_NORMAL, "[version: %u]",
-                                       h->version);
+          ntop->getTrace()->traceEvent(TRACE_NORMAL, "[version: %u]", h->version);
 #endif
 
           if (h->version == ZMQ_COMPATIBILITY_MSG_VERSION) {
@@ -359,6 +352,15 @@ void ZMQCollectorInterface::collect_flows() {
 
             source_id = h2->source_id, msg_id = ntohl(h2->msg_id);
             publisher_version = h2->version;
+	  } else if ((h->version == ZMQ_MSG_VERSION) && (size == sizeof(struct zmq_msg_hdr_v3))) {
+            struct zmq_msg_hdr_v3 *h3 = (struct zmq_msg_hdr_v3 *)&h0;
+
+            source_id = h3->source_id, msg_id = ntohl(h3->msg_id);
+            publisher_version = h3->version;
+	    received_compressed_size = h3->compressed_size;
+
+	    if(h3->flags & ZMQ_FLAG_IS_TLV)         tlv_encoding = true;
+	    if(h3->flags & ZMQ_FLAG_IS_COMPRESSED)  compressed   = true;
           }
         }
 
@@ -395,12 +397,11 @@ void ZMQCollectorInterface::collect_flows() {
             if (msg_id < probe->last_msg_id) {
               /* Start over (just reset active_probes) */
 #ifdef MSG_ID_DEBUG
-              ntop->getTrace()->traceEvent(
-                  TRACE_NORMAL,
-                  "ROLLBACK [subscriber_id: "
-                  "%u][msg_id=%u][last=%u][tot_msgs=%u][drops=%u]",
-                  subscriber_id, msg_id, probe->last_msg_id, recvStats.zmq_msg_rcvd,
-                  recvStats.zmq_msg_drops);
+              ntop->getTrace()->traceEvent(TRACE_NORMAL,
+					   "ROLLBACK [subscriber_id: "
+					   "%u][msg_id=%u][last=%u][tot_msgs=%u][drops=%u]",
+					   subscriber_id, msg_id, probe->last_msg_id, recvStats.zmq_msg_rcvd,
+					   recvStats.zmq_msg_drops);
 #endif
             } else {
               /* Compute delta (this message ID - last message ID) */
@@ -410,12 +411,11 @@ void ZMQCollectorInterface::collect_flows() {
                 /* Lost message detected */
                 recvStats.zmq_msg_drops += diff - 1;
 #ifdef MSG_ID_DEBUG
-                ntop->getTrace()->traceEvent(
-                    TRACE_NORMAL,
-                    "DROP [subscriber_id: "
-                    "%u][msg_id=%u][last=%u][tot_msgs=%u][drops=%u][+%u]",
-                    subscriber_id, msg_id, probe->last_msg_id, recvStats.zmq_msg_rcvd,
-                    recvStats.zmq_msg_drops, diff - 1);
+                ntop->getTrace()->traceEvent(TRACE_NORMAL,
+					     "DROP [subscriber_id: "
+					     "%u][msg_id=%u][last=%u][tot_msgs=%u][drops=%u][+%u]",
+					     subscriber_id, msg_id, probe->last_msg_id, recvStats.zmq_msg_rcvd,
+					     recvStats.zmq_msg_drops, diff - 1);
 #endif
               }
             }
@@ -441,38 +441,52 @@ void ZMQCollectorInterface::collect_flows() {
           function shall return -1 and set errno to one of the values defined
           below.
         */
-        size = zmq_recv(items[subscriber_id].socket, payload, payload_len, 0);
+        size = zmq_recv(items[subscriber_id].socket, zmq_payload, CONST_ZMQ_PAYLOAD_LEN, 0);
 
-        if (size > 0 && (u_int32_t)size > payload_len)
-          ntop->getTrace()->traceEvent(
-              TRACE_WARNING,
-              "ZMQ message truncated? [size: %u][payload_len: %u]", size,
-              payload_len);
+        if (size > 0 && (u_int32_t)size > CONST_ZMQ_PAYLOAD_LEN)
+          ntop->getTrace()->traceEvent(TRACE_WARNING,
+				       "ZMQ message truncated? [size: %u][CONST_ZMQ_PAYLOAD_LEN: %u]", size,
+				       CONST_ZMQ_PAYLOAD_LEN);
         else if (size > 0) {
           char *uncompressed = NULL;
           u_int uncompressed_len;
-          bool tlv_encoding = false;
-          bool compressed = false;
 
           recvStats.zmq_msg_rcvd++;
-          payload[size] = '\0';
+          zmq_payload[size] = '\0';
 
-          if (publisher_version == ZMQ_MSG_VERSION_TLV)
-            tlv_encoding = true;
-          else if (payload[0] == 0)
-            compressed = true;
+	  if(publisher_version != ZMQ_MSG_VERSION) {
+	    /* Compatibility mode */
+
+	    if (publisher_version == ZMQ_MSG_VERSION_TLV)
+	      tlv_encoding = true;
+	    else if(zmq_payload[0] == 0)
+	      compressed = true;
+	  }
 
           if (compressed /* Compressed traffic */) {
 #ifdef HAVE_ZLIB
             int err;
             uLongf uLen;
 
-            uLen = uncompressed_len = max(5 * size, MAX_ZMQ_FLOW_BUF);
+	    if(received_compressed_size == 0) /* Old nProbe: do the best to guess the size */
+	      uLen = uncompressed_len = ndpi_min(ndpi_max(10 * size, MAX_ZMQ_FLOW_BUF), MAX_ZMQ_FLOW_BUF/3); /* Compatibility mode */
+	    else
+	      uLen = uncompressed_len = received_compressed_size + 16; /* We know already the uncompressed size */
+
             uncompressed = (char *)malloc(uncompressed_len + 1);
-            if ((err = uncompress((Bytef *)uncompressed, &uLen,
-                                  (Bytef *)&payload[1], size - 1)) != Z_OK) {
-              ntop->getTrace()->traceEvent(
-                  TRACE_ERROR, "Uncompress error [%d][len: %u]", err, size);
+
+	    if(publisher_version == ZMQ_MSG_VERSION /* struct zmq_msg_hdr_v3 */)
+	      err = uncompress((Bytef *)uncompressed, &uLen, (Bytef *)zmq_payload, size);
+	    else
+	      err = uncompress((Bytef *)uncompressed, &uLen, (Bytef *)&zmq_payload[1], size - 1);
+
+	    if (err != Z_OK) {
+	      ntop->getTrace()->traceEvent(TRACE_ERROR, "[topic: %s][version: %u] Uncompress error %d [compressed len: %u][max decompress len: %u]",
+					   h->url, publisher_version, err, size, uncompressed_len);
+
+	      if(err == Z_BUF_ERROR)
+		ntop->getTrace()->traceEvent(TRACE_ERROR, "Internal error: decompression buffer too short");
+
               continue;
             }
 
@@ -484,21 +498,20 @@ void ZMQCollectorInterface::collect_flows() {
               ntop->getTrace()->traceEvent(TRACE_ERROR,
                                            "Unable to uncompress ZMQ traffic: "
                                            "ntopng compiled without zlib"),
-                  once = true;
+		once = true;
 
             continue;
 #endif
           } else if (tlv_encoding /* TLV encoding */) {
             // ntop->getTrace()->traceEvent(TRACE_NORMAL, "TLV message over
             // ZMQ");
-            uncompressed = payload, uncompressed_len = size;
+            uncompressed = zmq_payload, uncompressed_len = size;
           } else /* JSON string */
-            uncompressed = payload, uncompressed_len = size;
+            uncompressed = zmq_payload, uncompressed_len = size;
 
           if (ntop->getPrefs()->get_zmq_encryption_pwd())
-            Utils::xor_encdec(
-                (u_char *)uncompressed, uncompressed_len,
-                (u_char *)ntop->getPrefs()->get_zmq_encryption_pwd());
+            Utils::xor_encdec((u_char *)uncompressed, uncompressed_len,
+			      (u_char *)ntop->getPrefs()->get_zmq_encryption_pwd());
 
           if (false) {
             ntop->getTrace()->traceEvent(TRACE_NORMAL, "[url: %s]", h->url);
@@ -523,63 +536,69 @@ void ZMQCollectorInterface::collect_flows() {
             probe->last_msg_id = current_msg_id;
           }
 
-          /* Process the message */ 
+          /* Process the message */
           switch (h->url[0]) {
-            case 'e': /* event */
-              recvStats.num_events++;
-              parseEvent(uncompressed, uncompressed_len, source_id, msg_id,
-                         this);
-              break;
+	  case 'e': /* event */
+	    recvStats.num_events++;
+	    parseEvent(uncompressed, uncompressed_len, source_id, msg_id, this);
+	    break;
 
-            case 'f': /* flow */
-              if (tlv_encoding)
-                recvStats.num_flows +=
-                    parseTLVFlow(uncompressed, uncompressed_len, subscriber_id,
-                                 msg_id, this);
-              else {
-                uncompressed[uncompressed_len] = '\0';		
-                recvStats.num_flows += parseJSONFlow(uncompressed, uncompressed_len, subscriber_id, msg_id);
-              }
-              break;
+	  case 'f': /* flow */
+	    if (tlv_encoding)
+	      recvStats.num_flows += parseTLVFlow(uncompressed, uncompressed_len,
+						  subscriber_id, msg_id, this);
+	    else if(ntop->getPrefs()->is_pro_edition()) {
+	      uncompressed[uncompressed_len] = '\0';
+	      recvStats.num_flows += parseJSONFlow(uncompressed, uncompressed_len, subscriber_id, msg_id);
+	    }
+	    break;
 
-            case 'c': /* counter */
+	  case 'c': /* counter / custom-ie */
+	    if(h->url[1] == 'o') {
+	      /* counter */
               if (tlv_encoding)
                 parseTLVCounter(uncompressed, uncompressed_len);
               else
                 parseJSONCounter(uncompressed, uncompressed_len);
+
               recvStats.num_counters++;
-              break;
+	    } else {
+	      /* custom-ie (JSON only) */
 
-            case 't': /* template */
-              recvStats.num_templates++;
-              parseTemplate(uncompressed, uncompressed_len, subscriber_id,
-                            msg_id, this);
-              break;
+	      parseJSONCustomIE(uncompressed, uncompressed_len);
+	    }
+	    break;
 
-            case 'o': /* option */
-              recvStats.num_options++;
-              parseOption(uncompressed, uncompressed_len, subscriber_id, msg_id,
-                          this);
-              break;
+	  case 't': /* template */
+	    recvStats.num_templates++;
+	    parseTemplate(uncompressed, uncompressed_len, subscriber_id,
+			  msg_id, this);
+	    break;
 
-            case 'h': /* hello */
-              recvStats.num_hello++;
-              /* ntop->getTrace()->traceEvent(TRACE_NORMAL, "[HELLO] %s",
-               * uncompressed); */
-              ntop->askToRefreshIPSRules();
-              break;
+	  case 'o': /* option */
+	    recvStats.num_options++;
+	    parseOption(uncompressed, uncompressed_len, subscriber_id, msg_id,
+			this);
+	    break;
 
-            case 'l': /* listening-ports */
-              recvStats.num_listening_ports++;
-              parseListeningPorts(uncompressed, uncompressed_len, subscriber_id,
-                                  msg_id, this);
-              break;
+	  case 'h': /* hello */
+	    recvStats.num_hello++;
+	    /* ntop->getTrace()->traceEvent(TRACE_NORMAL, "[HELLO] %s",
+	     * uncompressed); */
+	    ntop->askToRefreshIPSRules();
+	    break;
 
-            case 's': /* snmp-ifaces */
-              recvStats.num_snmp_interfaces++;
-              parseSNMPIntefaces(uncompressed, uncompressed_len, subscriber_id,
-                                 msg_id, this);
-              break;
+	  case 'l': /* listening-ports */
+	    recvStats.num_listening_ports++;
+	    parseListeningPorts(uncompressed, uncompressed_len, subscriber_id,
+				msg_id, this);
+	    break;
+
+	  case 's': /* snmp-ifaces */
+	    recvStats.num_snmp_interfaces++;
+	    parseSNMPIntefaces(uncompressed, uncompressed_len, subscriber_id,
+			       msg_id, this);
+	    break;
           }
 
           /* ntop->getTrace()->traceEvent(TRACE_INFO, "[%s] %s", h->url,
@@ -596,7 +615,7 @@ void ZMQCollectorInterface::collect_flows() {
 
   ntop->getTrace()->traceEvent(TRACE_NORMAL, "Flow collection is over.");
 
-  if (payload) free(payload);
+  if (zmq_payload) free(zmq_payload);
 }
 
 /* **************************************************** */
@@ -623,8 +642,8 @@ void ZMQCollectorInterface::startPacketPolling() {
 
 bool ZMQCollectorInterface::set_packet_filter(char *filter) {
   ntop->getTrace()->traceEvent(
-      TRACE_ERROR, "No filter can be set on a collector interface. Ignored %s",
-      filter);
+			       TRACE_ERROR, "No filter can be set on a collector interface. Ignored %s",
+			       filter);
   return (false);
 }
 
@@ -645,7 +664,7 @@ void ZMQCollectorInterface::lua(lua_State *vm, bool fullStats) {
   lua_settable(vm, -3);
 
   /* ****************** */
-  
+
   lua_newtable(vm);
   lua_push_uint64_table_entry(vm, "flows", recvStats.num_flows - recvStatsCheckpoint.num_flows);
   lua_push_uint64_table_entry(vm, "dropped_flows",
