@@ -23,12 +23,11 @@
 
 ndpi_serializer* CustomFlowLuaScriptAlert::getAlertJSON(
     ndpi_serializer* serializer) {
-  /* Flow *f = getFlow(); */
 
-  if (serializer == NULL) return NULL;
-
-  if (msg.size() > 0)
-    ndpi_serialize_string_string(serializer, "alert.message", msg.c_str());
+  if (serializer) {
+    if (msg.size() > 0)
+      ndpi_serialize_string_string(serializer, "alert.message", msg.c_str());
+  }
 
   return serializer;
 }
