@@ -23,9 +23,10 @@
 
 ndpi_serializer* FlowRiskGenericAlert::getAlertJSON(
     ndpi_serializer* serializer) {
-  if (serializer == NULL) return NULL;
 
-  ndpi_serialize_string_int32(serializer, "risk_id", risk);
+  if (serializer) {
+    ndpi_serialize_string_int32(serializer, "risk_id", risk);
+  }
 
   return serializer;
 }
