@@ -23,16 +23,16 @@
 
 ndpi_serializer* FlowRiskTLSCertificateSelfSignedAlert::getAlertJSON(
     ndpi_serializer* serializer) {
-  Flow* f = getFlow();
+  Flow *f = getFlow();
   char* s;
 
-  if (!serializer) return (NULL);
+  if (serializer) {
+    if ((s = f->getTLSCertificateIssuerDN()) != NULL)
+      ndpi_serialize_string_string(serializer, "protos.tls.issuerDN", s);
 
-  if ((s = f->getTLSCertificateIssuerDN()) != NULL)
-    ndpi_serialize_string_string(serializer, "protos.tls.issuerDN", s);
-
-  if ((s = f->getTLSCertificateSubjectDN()) != NULL)
-    ndpi_serialize_string_string(serializer, "protos.tls.subjectDN", s);
+    if ((s = f->getTLSCertificateSubjectDN()) != NULL)
+      ndpi_serialize_string_string(serializer, "protos.tls.subjectDN", s);
+  }
 
   return (serializer);
 }
