@@ -26,18 +26,16 @@
 ndpi_serializer* PeriodicityChangedAlert::getAlertJSON(
     ndpi_serializer* serializer) {
 #ifdef NTOPNG_PRO
-  Flow* f = getFlow();
-#endif
+  Flow *f = getFlow();
 
-  if (serializer == NULL) return NULL;
-
-#ifdef NTOPNG_PRO
-  ndpi_serialize_string_boolean(
+  if (serializer) {
+    ndpi_serialize_string_boolean(
       serializer, "is_periodic",
       f->getPeriodicity() == periodicity_status_is_periodic);
-  ndpi_serialize_string_boolean(
+    ndpi_serialize_string_boolean(
       serializer, "is_aperiodic",
       f->getPeriodicity() == periodicity_status_is_aperiodic);
+  }
 #endif
 
   return serializer;
