@@ -30,7 +30,9 @@ void WebMining::protocolDetected(Flow *f) {
 
     computeCliSrvScore(ntop->getFlowAlertScore(alert_type.id), cli_score_pctg, &c_score, &s_score);
 
-    f->triggerAlertAsync(alert_type, c_score, s_score);
+    FlowAlert *alert = buildAlert(f);
+    alert->setCliSrvScores(c_score, s_score);
+    f->triggerAlert(alert);
   }
 }
 
