@@ -1,6 +1,6 @@
 /*
  *
- * (C) 2013-24 - ntop.org
+ * (C) 2013-25 - ntop.org
  *
  *
  * This program is free software; you can redistribute it and/or modify
@@ -75,9 +75,10 @@ void initWinsock32() {
 /* ******************************** */
 
 extern "C" {
-int ntop_main(int argc, char *argv[])
+  int ntop_main(int argc, char *argv[])
 #else
-int main(int argc, char *argv[])
+
+    int main(int argc, char *argv[])
 #endif
 {
   Prefs *prefs = NULL;
@@ -88,7 +89,9 @@ int main(int argc, char *argv[])
   char *core_id_s = NULL;
   int core_id;
   char path[2 * MAX_PATH];
+#ifdef NTOPNG_PRO
   bool has_view_all = false;
+#endif
   FILE *fd;
   ThreadedActivity *boot_activity;
 
@@ -108,7 +111,7 @@ int main(int argc, char *argv[])
     printf("Unable to set SQLITE_CONFIG_MULTITHREAD for sqlite, exiting.");
     exit(1);
   }
-  
+
   sqlite3_initialize();
 #endif
 
@@ -206,7 +209,7 @@ int main(int argc, char *argv[])
         else
           endpoint = ifName;
 
-        
+
 #ifdef HAVE_ZMQ
         iface = new (std::nothrow) ZMQCollectorInterface(endpoint);
 #endif
@@ -234,17 +237,20 @@ int main(int argc, char *argv[])
           ntop->getTrace()->traceEvent(TRACE_WARNING,
                                        "Inline/bridge capabilities have now "
                                        "been moved in ntopng Edge (nEdge)");
-          ntop->getTrace()->traceEvent(
-              TRACE_WARNING, "For more information and free migration see:");
-          ntop->getTrace()->traceEvent(
-              TRACE_WARNING,
-              "https://www.ntop.org/support/faq/"
-              "migration-of-ntopng-inline-pro-enterprises-licenses-to-ntopng-"
-              "edge-nedge/");
+          ntop->getTrace()->traceEvent(TRACE_WARNING, "For more information and free migration see:");
+          ntop->getTrace()->traceEvent(TRACE_WARNING,
+				       "https://www.ntop.org/support/faq/"
+				       "migration-of-ntopng-inline-pro-enterprises-licenses-to-ntopng-"
+				       "edge-nedge/");
           ntop->getTrace()->traceEvent(TRACE_WARNING, "\n");
         }
 #endif
 
+#if !defined(HAVE_NEDGE)
+	if (iface == NULL && strncmp(ifName, "sflow:", 6) == 0)
+          iface = new (std::nothrow) sFlowPktInterface(ifName);
+#endif
+	
 #if defined(HAVE_NEDGE)
         if (iface == NULL && strncmp(ifName, "nf:", 3) == 0)
           iface = new (std::nothrow) NetfilterInterface(ifName);
@@ -271,9 +277,8 @@ int main(int argc, char *argv[])
       if (iface) delete iface;
       iface = NULL;
     } catch (...) {
-      ntop->getTrace()->traceEvent(
-          TRACE_NORMAL, "Unable to open interface %s. Falling back to pcap.",
-          ifName);
+      ntop->getTrace()->traceEvent(TRACE_NORMAL, "Unable to open interface %s. Falling back to pcap.",
+				   ifName);
       if (iface) delete iface;
       iface = NULL;
     }
@@ -284,9 +289,8 @@ int main(int argc, char *argv[])
         errno = 0;
         iface = new PcapInterface(ifName, i, false);
       } catch (int err) {
-        ntop->getTrace()->traceEvent(
-            TRACE_ERROR, "Unable to open interface %s with pcap [%d]: %s",
-            ifName, err, strerror(err));
+        ntop->getTrace()->traceEvent(TRACE_ERROR, "Unable to open interface %s with pcap [%d]: %s",
+				     ifName, err, strerror(err));
         if (iface) delete iface;
         iface = NULL;
       }
@@ -319,9 +323,10 @@ int main(int argc, char *argv[])
   } /* for */
 
   /* Instantiated deferred view interfaces */
+#ifdef NTOPNG_PRO
   for (int i = 0; i < MAX_NUM_INTERFACE_IDS; i++) {
     NetworkInterface *iface = NULL;
-
+    
     if ((ifName = ntop->get_if_name(i)) == NULL || strncmp(ifName, "view:", 5))
       continue;
 
@@ -341,7 +346,8 @@ int main(int argc, char *argv[])
     if ((iface = new (std::nothrow) ViewInterface("view:all")))
       ntop->registerInterface(iface);
   }
-
+#endif
+  
   if (ntop->getFirstInterface() == NULL) {
 #ifdef WIN32
     ntop->getTrace()->traceEvent(TRACE_ERROR,
@@ -391,19 +397,31 @@ int main(int argc, char *argv[])
   ntop->loadMacManufacturers(prefs->get_docs_dir());
   ntop->loadTrackers();
 #ifdef HAVE_SNMP_TRAP
-  ntop->initSNMPTrapCollector();
+  if (prefs->isSNMPTrapEnabled())
+    ntop->toggleSNMPTrapCollector(true);
 #endif
 
-  /* Register the HTTP server before dropping the privileges. This is required
-   * in order to possibly bind the HTTP server to privileged ports (< 1024) */
-  ntop->registerHTTPserver(new (std::nothrow) HTTPserver(
-      prefs->get_docs_dir(), prefs->get_scripts_dir()));
-
+#ifndef __linux__
+  /*
+     On non-Linux platforms (no capabilites) we need to register the HTTP server before
+     dropping the privileges. This is required in order to possibly
+     bind the HTTP server to privileged ports (< 1024)
+  */
+  ntop->registerHTTPserver(new (std::nothrow) HTTPserver(prefs->get_docs_dir(), prefs->get_scripts_dir()));
+#endif
+  
   /* Drop the privileges before initializing the network interfaces. This
    * is necessary as the initialization may create files/directories, which
    * should not be created as root. */
   if (prefs->do_change_user()) Utils::dropPrivileges();
 
+#ifdef __linux__
+  /*
+    On Linux the HTTP server is started after dropping privileges as we can use capabilities
+ */
+  ntop->registerHTTPserver(new (std::nothrow) HTTPserver(prefs->get_docs_dir(), prefs->get_scripts_dir()));
+#endif
+
   /* initInterface writes DB data on disk, keep it after changing user */
   for (int i = 0; i < MAX_NUM_INTERFACE_IDS; i++) {
     NetworkInterface *iface;
@@ -479,7 +497,7 @@ int main(int argc, char *argv[])
   ntop->getTrace()->traceEvent(TRACE_NORMAL, "Terminating...");
 
   ntop->getGlobals()->requestShutdown();
-  
+
   /* Perform all the necessary cleanup (purge all flows, hosts, etc)
    * and wait for other threads termination */
   ntop->shutdownAll();
@@ -518,3 +536,40 @@ int main(int argc, char *argv[])
 #ifdef WIN32
 }
 #endif
+
+/* ******************************** */
+/* ******************************** */
+
+// #define CUSTOM_ALLOCATOR
+
+#ifdef CUSTOM_ALLOCATOR
+
+static std::map <void*, std::size_t> _allocator;
+static u_int64_t _tot_memory = 0;
+
+void *operator new[](std::size_t s) {
+  void *m = (void*)malloc(s);
+
+  _allocator[m] = s, _tot_memory += s;
+
+  printf("[NEW] [size: %u][tot: %lu]\n", (unsigned int)s, (unsigned long)_tot_memory);
+  return m;
+ }
+
+void operator delete[](void *p) throw() {
+  std::map <void*, std::size_t>::iterator i = _allocator.find(p);
+
+  if(i == _allocator.end()) {
+    /* Not found */
+  } else {
+    _tot_memory -= i->second;
+    
+    printf("[DELETE] [size: %u][tot: %lu]\n",
+	   (unsigned int)i->second, (unsigned long)_tot_memory);
+
+    _allocator.erase(i);
+    free(p);
+  }
+ }
+
+#endif
